import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface AccessContextManagerAccessLevelConfig extends TerraformMetaArguments {
    /** Description of the AccessLevel and its use. Does not affect behavior. */
    readonly description?: string;
    /** Resource name for the Access Level. The short_name component must begin
  with a letter and only include alphanumeric and '_'.
  Format: accessPolicies/{policy_id}/accessLevels/{short_name} */
    readonly name: string;
    /** The AccessPolicy this AccessLevel lives in.
  Format: accessPolicies/{policy_id} */
    readonly parent: string;
    /** Human readable title. Must be unique within the Policy. */
    readonly title: string;
    /** basic block */
    readonly basic?: AccessContextManagerAccessLevelBasic[];
    /** custom block */
    readonly custom?: AccessContextManagerAccessLevelCustom[];
    /** timeouts block */
    readonly timeouts?: AccessContextManagerAccessLevelTimeouts;
}
export interface AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraints {
    /** The minimum allowed OS version. If not set, any version
  of this OS satisfies the constraint.
  Format: "major.minor.patch" such as "10.5.301", "9.2.1". */
    readonly minimumVersion?: string;
    /** The operating system type of the device. Possible values: ["OS_UNSPECIFIED", "DESKTOP_MAC", "DESKTOP_WINDOWS", "DESKTOP_LINUX", "DESKTOP_CHROME_OS"] */
    readonly osType: string;
}
export interface AccessContextManagerAccessLevelBasicConditionsDevicePolicy {
    /** A list of allowed device management levels.
  An empty list allows all management levels. Possible values: ["MANAGEMENT_UNSPECIFIED", "NONE", "BASIC", "COMPLETE"] */
    readonly allowedDeviceManagementLevels?: string[];
    /** A list of allowed encryptions statuses.
  An empty list allows all statuses. Possible values: ["ENCRYPTION_UNSPECIFIED", "ENCRYPTION_UNSUPPORTED", "UNENCRYPTED", "ENCRYPTED"] */
    readonly allowedEncryptionStatuses?: string[];
    /** Whether the device needs to be approved by the customer admin. */
    readonly requireAdminApproval?: boolean;
    /** Whether the device needs to be corp owned. */
    readonly requireCorpOwned?: boolean;
    /** Whether or not screenlock is required for the DevicePolicy
  to be true. Defaults to false. */
    readonly requireScreenLock?: boolean;
    /** os_constraints block */
    readonly osConstraints?: AccessContextManagerAccessLevelBasicConditionsDevicePolicyOsConstraints[];
}
export interface AccessContextManagerAccessLevelBasicConditions {
    /** A list of CIDR block IP subnetwork specification. May be IPv4
  or IPv6.
  Note that for a CIDR IP address block, the specified IP address
  portion must be properly truncated (i.e. all the host bits must
  be zero) or the input is considered malformed. For example,
  "192.0.2.0/24" is accepted but "192.0.2.1/24" is not. Similarly,
  for IPv6, "2001:db8::/32" is accepted whereas "2001:db8::1/32"
  is not. The originating IP of a request must be in one of the
  listed subnets in order for this Condition to be true.
  If empty, all IP addresses are allowed. */
    readonly ipSubnetworks?: string[];
    /** An allowed list of members (users, service accounts).
  Using groups is not supported yet.
  
  The signed-in user originating the request must be a part of one
  of the provided members. If not specified, a request may come
  from any user (logged in/not logged in, not present in any
  groups, etc.).
  Formats: 'user:{emailid}', 'serviceAccount:{emailid}' */
    readonly members?: string[];
    /** Whether to negate the Condition. If true, the Condition becomes
  a NAND over its non-empty fields, each field must be false for
  the Condition overall to be satisfied. Defaults to false. */
    readonly negate?: boolean;
    /** The request must originate from one of the provided
  countries/regions.
  Format: A valid ISO 3166-1 alpha-2 code. */
    readonly regions?: string[];
    /** A list of other access levels defined in the same Policy,
  referenced by resource name. Referencing an AccessLevel which
  does not exist is an error. All access levels listed must be
  granted for the Condition to be true.
  Format: accessPolicies/{policy_id}/accessLevels/{short_name} */
    readonly requiredAccessLevels?: string[];
    /** device_policy block */
    readonly devicePolicy?: AccessContextManagerAccessLevelBasicConditionsDevicePolicy[];
}
export interface AccessContextManagerAccessLevelBasic {
    /** How the conditions list should be combined to determine if a request
  is granted this AccessLevel. If AND is used, each Condition in
  conditions must be satisfied for the AccessLevel to be applied. If
  OR is used, at least one Condition in conditions must be satisfied
  for the AccessLevel to be applied. Default value: "AND" Possible values: ["AND", "OR"] */
    readonly combiningFunction?: string;
    /** conditions block */
    readonly conditions: AccessContextManagerAccessLevelBasicConditions[];
}
export interface AccessContextManagerAccessLevelCustomExpr {
    /** Description of the expression */
    readonly description?: string;
    /** Textual representation of an expression in Common Expression Language syntax. */
    readonly expression: string;
    /** String indicating the location of the expression for error reporting, e.g. a file name and a position in the file */
    readonly location?: string;
    /** Title for the expression, i.e. a short string describing its purpose. */
    readonly title?: string;
}
export interface AccessContextManagerAccessLevelCustom {
    /** expr block */
    readonly expr: AccessContextManagerAccessLevelCustomExpr[];
}
export interface AccessContextManagerAccessLevelTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class AccessContextManagerAccessLevel extends TerraformResource {
    constructor(scope: Construct, id: string, config: AccessContextManagerAccessLevelConfig);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _parent;
    get parent(): string;
    set parent(value: string);
    private _title;
    get title(): string;
    set title(value: string);
    private _basic?;
    get basic(): AccessContextManagerAccessLevelBasic[] | undefined;
    set basic(value: AccessContextManagerAccessLevelBasic[] | undefined);
    private _custom?;
    get custom(): AccessContextManagerAccessLevelCustom[] | undefined;
    set custom(value: AccessContextManagerAccessLevelCustom[] | undefined);
    private _timeouts?;
    get timeouts(): AccessContextManagerAccessLevelTimeouts | undefined;
    set timeouts(value: AccessContextManagerAccessLevelTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
