import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ActiveDirectoryDomainTrustConfig extends TerraformMetaArguments {
    /** The fully qualified domain name. e.g. mydomain.myorganization.com, with the restrictions,
  https://cloud.google.com/managed-microsoft-ad/reference/rest/v1/projects.locations.global.domains. */
    readonly domain: string;
    readonly project?: string;
    /** Whether the trusted side has forest/domain wide access or selective access to an approved set of resources. */
    readonly selectiveAuthentication?: boolean;
    /** The target DNS server IP addresses which can resolve the remote domain involved in the trust. */
    readonly targetDnsIpAddresses: string[];
    /** The fully qualified target domain name which will be in trust with the current domain. */
    readonly targetDomainName: string;
    /** The trust direction, which decides if the current domain is trusted, trusting, or both. Possible values: ["INBOUND", "OUTBOUND", "BIDIRECTIONAL"] */
    readonly trustDirection: string;
    /** The trust secret used for the handshake with the target domain. This will not be stored. */
    readonly trustHandshakeSecret: string;
    /** The type of trust represented by the trust resource. Possible values: ["FOREST", "EXTERNAL"] */
    readonly trustType: string;
    /** timeouts block */
    readonly timeouts?: ActiveDirectoryDomainTrustTimeouts;
}
export interface ActiveDirectoryDomainTrustTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ActiveDirectoryDomainTrust extends TerraformResource {
    constructor(scope: Construct, id: string, config: ActiveDirectoryDomainTrustConfig);
    private _domain;
    get domain(): string;
    set domain(value: string);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _selectiveAuthentication?;
    get selectiveAuthentication(): boolean | undefined;
    set selectiveAuthentication(value: boolean | undefined);
    private _targetDnsIpAddresses;
    get targetDnsIpAddresses(): string[];
    set targetDnsIpAddresses(value: string[]);
    private _targetDomainName;
    get targetDomainName(): string;
    set targetDomainName(value: string);
    private _trustDirection;
    get trustDirection(): string;
    set trustDirection(value: string);
    private _trustHandshakeSecret;
    get trustHandshakeSecret(): string;
    set trustHandshakeSecret(value: string);
    private _trustType;
    get trustType(): string;
    set trustType(value: string);
    private _timeouts?;
    get timeouts(): ActiveDirectoryDomainTrustTimeouts | undefined;
    set timeouts(value: ActiveDirectoryDomainTrustTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
