import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
export interface AppEngineApplicationConfig extends TerraformMetaArguments {
    /** The domain to authenticate users with when using App Engine's User API. */
    readonly authDomain?: string;
    readonly databaseType?: string;
    /** The location to serve the app from. */
    readonly locationId: string;
    /** The project ID to create the application under. */
    readonly project?: string;
    /** The serving status of the app. */
    readonly servingStatus?: string;
    /** feature_settings block */
    readonly featureSettings?: AppEngineApplicationFeatureSettings[];
    /** iap block */
    readonly iap?: AppEngineApplicationIap[];
    /** timeouts block */
    readonly timeouts?: AppEngineApplicationTimeouts;
}
export declare class AppEngineApplicationUrlDispatchRule extends ComplexComputedList {
    get domain(): string;
    get path(): string;
    get service(): string;
}
export interface AppEngineApplicationFeatureSettings {
    readonly splitHealthChecks: boolean;
}
export interface AppEngineApplicationIap {
    /** Adapted for use with the app */
    readonly enabled?: boolean;
    /** OAuth2 client ID to use for the authentication flow. */
    readonly oauth2ClientId: string;
    /** OAuth2 client secret to use for the authentication flow. The SHA-256 hash of the value is returned in the oauth2ClientSecretSha256 field. */
    readonly oauth2ClientSecret: string;
}
export interface AppEngineApplicationTimeouts {
    readonly create?: string;
    readonly update?: string;
}
export declare class AppEngineApplication extends TerraformResource {
    constructor(scope: Construct, id: string, config: AppEngineApplicationConfig);
    get appId(): string;
    private _authDomain?;
    get authDomain(): string | undefined;
    set authDomain(value: string | undefined);
    get codeBucket(): string;
    private _databaseType?;
    get databaseType(): string | undefined;
    set databaseType(value: string | undefined);
    get defaultBucket(): string;
    get defaultHostname(): string;
    get gcrDomain(): string;
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _locationId;
    get locationId(): string;
    set locationId(value: string);
    get name(): string;
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _servingStatus?;
    get servingStatus(): string | undefined;
    set servingStatus(value: string | undefined);
    urlDispatchRule(index: string): AppEngineApplicationUrlDispatchRule;
    private _featureSettings?;
    get featureSettings(): AppEngineApplicationFeatureSettings[] | undefined;
    set featureSettings(value: AppEngineApplicationFeatureSettings[] | undefined);
    private _iap?;
    get iap(): AppEngineApplicationIap[] | undefined;
    set iap(value: AppEngineApplicationIap[] | undefined);
    private _timeouts?;
    get timeouts(): AppEngineApplicationTimeouts | undefined;
    set timeouts(value: AppEngineApplicationTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
