import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
export interface AppEngineDomainMappingConfig extends TerraformMetaArguments {
    /** Relative name of the domain serving the application. Example: example.com. */
    readonly domainName: string;
    /** Whether the domain creation should override any existing mappings for this domain.
  By default, overrides are rejected. Default value: "STRICT" Possible values: ["STRICT", "OVERRIDE"] */
    readonly overrideStrategy?: string;
    readonly project?: string;
    /** ssl_settings block */
    readonly sslSettings?: AppEngineDomainMappingSslSettings[];
    /** timeouts block */
    readonly timeouts?: AppEngineDomainMappingTimeouts;
}
export declare class AppEngineDomainMappingResourceRecords extends ComplexComputedList {
    get name(): string;
    get rrdata(): string;
    get type(): string;
}
export interface AppEngineDomainMappingSslSettings {
    /** ID of the AuthorizedCertificate resource configuring SSL for the application. Clearing this field will
  remove SSL support.
  By default, a managed certificate is automatically created for every domain mapping. To omit SSL support
  or to configure SSL manually, specify 'SslManagementType.MANUAL' on a 'CREATE' or 'UPDATE' request. You must be
  authorized to administer the 'AuthorizedCertificate' resource to manually map it to a DomainMapping resource.
  Example: 12345. */
    readonly certificateId?: string;
    /** SSL management type for this domain. If 'AUTOMATIC', a managed certificate is automatically provisioned.
  If 'MANUAL', 'certificateId' must be manually specified in order to configure SSL for this domain. Possible values: ["AUTOMATIC", "MANUAL"] */
    readonly sslManagementType: string;
}
export interface AppEngineDomainMappingTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class AppEngineDomainMapping extends TerraformResource {
    constructor(scope: Construct, id: string, config: AppEngineDomainMappingConfig);
    private _domainName;
    get domainName(): string;
    set domainName(value: string);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get name(): string;
    private _overrideStrategy?;
    get overrideStrategy(): string | undefined;
    set overrideStrategy(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    resourceRecords(index: string): AppEngineDomainMappingResourceRecords;
    private _sslSettings?;
    get sslSettings(): AppEngineDomainMappingSslSettings[] | undefined;
    set sslSettings(value: AppEngineDomainMappingSslSettings[] | undefined);
    private _timeouts?;
    get timeouts(): AppEngineDomainMappingTimeouts | undefined;
    set timeouts(value: AppEngineDomainMappingTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
