import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface AppEngineServiceSplitTrafficConfig extends TerraformMetaArguments {
    /** If set to true traffic will be migrated to this version. */
    readonly migrateTraffic?: boolean;
    readonly project?: string;
    /** The name of the service these settings apply to. */
    readonly service: string;
    /** split block */
    readonly split: AppEngineServiceSplitTrafficSplit[];
    /** timeouts block */
    readonly timeouts?: AppEngineServiceSplitTrafficTimeouts;
}
export interface AppEngineServiceSplitTrafficSplit {
    /** Mapping from version IDs within the service to fractional (0.000, 1] allocations of traffic for that version. Each version can be specified only once, but some versions in the service may not have any traffic allocation. Services that have traffic allocated cannot be deleted until either the service is deleted or their traffic allocation is removed. Allocations must sum to 1. Up to two decimal place precision is supported for IP-based splits and up to three decimal places is supported for cookie-based splits. */
    readonly allocations: {
        [key: string]: string;
    };
    /** Mechanism used to determine which version a request is sent to. The traffic selection algorithm will be stable for either type until allocations are changed. Possible values: ["UNSPECIFIED", "COOKIE", "IP", "RANDOM"] */
    readonly shardBy?: string;
}
export interface AppEngineServiceSplitTrafficTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class AppEngineServiceSplitTraffic extends TerraformResource {
    constructor(scope: Construct, id: string, config: AppEngineServiceSplitTrafficConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _migrateTraffic?;
    get migrateTraffic(): boolean | undefined;
    set migrateTraffic(value: boolean | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _service;
    get service(): string;
    set service(value: string);
    private _split;
    get split(): AppEngineServiceSplitTrafficSplit[];
    set split(value: AppEngineServiceSplitTrafficSplit[]);
    private _timeouts?;
    get timeouts(): AppEngineServiceSplitTrafficTimeouts | undefined;
    set timeouts(value: AppEngineServiceSplitTrafficTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
