import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface BigqueryDataTransferConfigConfig extends TerraformMetaArguments {
    /** The number of days to look back to automatically refresh the data.
  For example, if dataRefreshWindowDays = 10, then every day BigQuery
  reingests data for [today-10, today-1], rather than ingesting data for
  just [today-1]. Only valid if the data source supports the feature.
  Set the value to 0 to use the default value. */
    readonly dataRefreshWindowDays?: number;
    /** The data source id. Cannot be changed once the transfer config is created. */
    readonly dataSourceId: string;
    /** The BigQuery target dataset id. */
    readonly destinationDatasetId: string;
    /** When set to true, no runs are scheduled for a given transfer. */
    readonly disabled?: boolean;
    /** The user specified display name for the transfer config. */
    readonly displayName: string;
    /** The geographic location where the transfer config should reside.
  Examples: US, EU, asia-northeast1. The default value is US. */
    readonly location?: string;
    /** Pub/Sub topic where notifications will be sent after transfer runs
  associated with this transfer config finish. */
    readonly notificationPubsubTopic?: string;
    /** These parameters are specific to each data source. */
    readonly params: {
        [key: string]: string;
    };
    readonly project?: string;
    /** Data transfer schedule. If the data source does not support a custom
  schedule, this should be empty. If it is empty, the default value for
  the data source will be used. The specified times are in UTC. Examples
  of valid format: 1st,3rd monday of month 15:30, every wed,fri of jan,
  jun 13:15, and first sunday of quarter 00:00. See more explanation
  about the format here:
  https://cloud.google.com/appengine/docs/flexible/python/scheduling-jobs-with-cron-yaml#the_schedule_format
  NOTE: the granularity should be at least 8 hours, or less frequent. */
    readonly schedule?: string;
    /** Optional service account name. If this field is set, transfer config will
  be created with this service account credentials. It requires that
  requesting user calling this API has permissions to act as this service account. */
    readonly serviceAccountName?: string;
    /** timeouts block */
    readonly timeouts?: BigqueryDataTransferConfigTimeouts;
}
export interface BigqueryDataTransferConfigTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class BigqueryDataTransferConfig extends TerraformResource {
    constructor(scope: Construct, id: string, config: BigqueryDataTransferConfigConfig);
    private _dataRefreshWindowDays?;
    get dataRefreshWindowDays(): number | undefined;
    set dataRefreshWindowDays(value: number | undefined);
    private _dataSourceId;
    get dataSourceId(): string;
    set dataSourceId(value: string);
    private _destinationDatasetId;
    get destinationDatasetId(): string;
    set destinationDatasetId(value: string);
    private _disabled?;
    get disabled(): boolean | undefined;
    set disabled(value: boolean | undefined);
    private _displayName;
    get displayName(): string;
    set displayName(value: string);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _location?;
    get location(): string | undefined;
    set location(value: string | undefined);
    get name(): string;
    private _notificationPubsubTopic?;
    get notificationPubsubTopic(): string | undefined;
    set notificationPubsubTopic(value: string | undefined);
    private _params;
    get params(): {
        [key: string]: string;
    };
    set params(value: {
        [key: string]: string;
    });
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _schedule?;
    get schedule(): string | undefined;
    set schedule(value: string | undefined);
    private _serviceAccountName?;
    get serviceAccountName(): string | undefined;
    set serviceAccountName(value: string | undefined);
    private _timeouts?;
    get timeouts(): BigqueryDataTransferConfigTimeouts | undefined;
    set timeouts(value: BigqueryDataTransferConfigTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
