import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface BigqueryDatasetAccessAConfig extends TerraformMetaArguments {
    /** A unique ID for this dataset, without the project name. The ID
  must contain only letters (a-z, A-Z), numbers (0-9), or
  underscores (_). The maximum length is 1,024 characters. */
    readonly datasetId: string;
    /** A domain to grant access to. Any users signed in with the
  domain specified will be granted the specified access */
    readonly domain?: string;
    /** An email address of a Google Group to grant access to. */
    readonly groupByEmail?: string;
    /** Some other type of member that appears in the IAM Policy but isn't a user,
  group, domain, or special group. For example: 'allUsers' */
    readonly iamMember?: string;
    readonly project?: string;
    /** Describes the rights granted to the user specified by the other
  member of the access object. Primitive, Predefined and custom
  roles are supported. Predefined roles that have equivalent
  primitive roles are swapped by the API to their Primitive
  counterparts, and will show a diff post-create. See
  [official docs](https://cloud.google.com/bigquery/docs/access-control). */
    readonly role?: string;
    /** A special group to grant access to. Possible values include:
  
  
  * 'projectOwners': Owners of the enclosing project.
  
  
  * 'projectReaders': Readers of the enclosing project.
  
  
  * 'projectWriters': Writers of the enclosing project.
  
  
  * 'allAuthenticatedUsers': All authenticated BigQuery users. */
    readonly specialGroup?: string;
    /** An email address of a user to grant access to. For example:
  fred@example.com */
    readonly userByEmail?: string;
    /** timeouts block */
    readonly timeouts?: BigqueryDatasetAccessTimeouts;
    /** view block */
    readonly view?: BigqueryDatasetAccessViewA[];
}
export interface BigqueryDatasetAccessTimeouts {
    readonly create?: string;
    readonly delete?: string;
}
export interface BigqueryDatasetAccessViewA {
    /** The ID of the dataset containing this table. */
    readonly datasetId: string;
    /** The ID of the project containing this table. */
    readonly projectId: string;
    /** The ID of the table. The ID must contain only letters (a-z,
  A-Z), numbers (0-9), or underscores (_). The maximum length
  is 1,024 characters. */
    readonly tableId: string;
}
export declare class BigqueryDatasetAccessA extends TerraformResource {
    constructor(scope: Construct, id: string, config: BigqueryDatasetAccessAConfig);
    get apiUpdatedMember(): boolean;
    private _datasetId;
    get datasetId(): string;
    set datasetId(value: string);
    private _domain?;
    get domain(): string | undefined;
    set domain(value: string | undefined);
    private _groupByEmail?;
    get groupByEmail(): string | undefined;
    set groupByEmail(value: string | undefined);
    private _iamMember?;
    get iamMember(): string | undefined;
    set iamMember(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _role?;
    get role(): string | undefined;
    set role(value: string | undefined);
    private _specialGroup?;
    get specialGroup(): string | undefined;
    set specialGroup(value: string | undefined);
    private _userByEmail?;
    get userByEmail(): string | undefined;
    set userByEmail(value: string | undefined);
    private _timeouts?;
    get timeouts(): BigqueryDatasetAccessTimeouts | undefined;
    set timeouts(value: BigqueryDatasetAccessTimeouts | undefined);
    private _view?;
    get view(): BigqueryDatasetAccessViewA[] | undefined;
    set view(value: BigqueryDatasetAccessViewA[] | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
