import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface BigqueryDatasetConfig extends TerraformMetaArguments {
    /** A unique ID for this dataset, without the project name. The ID
  must contain only letters (a-z, A-Z), numbers (0-9), or
  underscores (_). The maximum length is 1,024 characters. */
    readonly datasetId: string;
    /** The default partition expiration for all partitioned tables in
  the dataset, in milliseconds.
  
  
  Once this property is set, all newly-created partitioned tables in
  the dataset will have an 'expirationMs' property in the 'timePartitioning'
  settings set to this value, and changing the value will only
  affect new tables, not existing ones. The storage in a partition will
  have an expiration time of its partition time plus this value.
  Setting this property overrides the use of 'defaultTableExpirationMs'
  for partitioned tables: only one of 'defaultTableExpirationMs' and
  'defaultPartitionExpirationMs' will be used for any new partitioned
  table. If you provide an explicit 'timePartitioning.expirationMs' when
  creating or updating a partitioned table, that value takes precedence
  over the default partition expiration time indicated by this property. */
    readonly defaultPartitionExpirationMs?: number;
    /** The default lifetime of all tables in the dataset, in milliseconds.
  The minimum value is 3600000 milliseconds (one hour).
  
  
  Once this property is set, all newly-created tables in the dataset
  will have an 'expirationTime' property set to the creation time plus
  the value in this property, and changing the value will only affect
  new tables, not existing ones. When the 'expirationTime' for a given
  table is reached, that table will be deleted automatically.
  If a table's 'expirationTime' is modified or removed before the
  table expires, or if you provide an explicit 'expirationTime' when
  creating a table, that value takes precedence over the default
  expiration time indicated by this property. */
    readonly defaultTableExpirationMs?: number;
    readonly deleteContentsOnDestroy?: boolean;
    /** A user-friendly description of the dataset */
    readonly description?: string;
    /** A descriptive name for the dataset */
    readonly friendlyName?: string;
    /** The labels associated with this dataset. You can use these to
  organize and group your datasets */
    readonly labels?: {
        [key: string]: string;
    };
    /** The geographic location where the dataset should reside.
  See [official docs](https://cloud.google.com/bigquery/docs/dataset-locations).
  
  
  There are two types of locations, regional or multi-regional. A regional
  location is a specific geographic place, such as Tokyo, and a multi-regional
  location is a large geographic area, such as the United States, that
  contains at least two geographic places.
  
  
  Possible regional values include: 'asia-east1', 'asia-northeast1',
  'asia-southeast1', 'australia-southeast1', 'europe-north1',
  'europe-west2' and 'us-east4'.
  
  
  Possible multi-regional values: 'EU' and 'US'.
  
  
  The default value is multi-regional location 'US'.
  Changing this forces a new resource to be created. */
    readonly location?: string;
    readonly project?: string;
    /** access block */
    readonly access?: BigqueryDatasetAccess[];
    /** default_encryption_configuration block */
    readonly defaultEncryptionConfiguration?: BigqueryDatasetDefaultEncryptionConfiguration[];
    /** timeouts block */
    readonly timeouts?: BigqueryDatasetTimeouts;
}
export interface BigqueryDatasetAccessView {
    /** The ID of the dataset containing this table. */
    readonly datasetId: string;
    /** The ID of the project containing this table. */
    readonly projectId: string;
    /** The ID of the table. The ID must contain only letters (a-z,
  A-Z), numbers (0-9), or underscores (_). The maximum length
  is 1,024 characters. */
    readonly tableId: string;
}
export interface BigqueryDatasetAccess {
    /** A domain to grant access to. Any users signed in with the
  domain specified will be granted the specified access */
    readonly domain?: string;
    /** An email address of a Google Group to grant access to. */
    readonly groupByEmail?: string;
    /** Describes the rights granted to the user specified by the other
  member of the access object. Primitive, Predefined and custom
  roles are supported. Predefined roles that have equivalent
  primitive roles are swapped by the API to their Primitive
  counterparts. See
  [official docs](https://cloud.google.com/bigquery/docs/access-control). */
    readonly role?: string;
    /** A special group to grant access to. Possible values include:
  
  
  * 'projectOwners': Owners of the enclosing project.
  
  
  * 'projectReaders': Readers of the enclosing project.
  
  
  * 'projectWriters': Writers of the enclosing project.
  
  
  * 'allAuthenticatedUsers': All authenticated BigQuery users. */
    readonly specialGroup?: string;
    /** An email address of a user to grant access to. For example:
  fred@example.com */
    readonly userByEmail?: string;
    /** view block */
    readonly view?: BigqueryDatasetAccessView[];
}
export interface BigqueryDatasetDefaultEncryptionConfiguration {
    /** Describes the Cloud KMS encryption key that will be used to protect destination
  BigQuery table. The BigQuery Service Account associated with your project requires
  access to this encryption key. */
    readonly kmsKeyName: string;
}
export interface BigqueryDatasetTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class BigqueryDataset extends TerraformResource {
    constructor(scope: Construct, id: string, config: BigqueryDatasetConfig);
    get creationTime(): number;
    private _datasetId;
    get datasetId(): string;
    set datasetId(value: string);
    private _defaultPartitionExpirationMs?;
    get defaultPartitionExpirationMs(): number | undefined;
    set defaultPartitionExpirationMs(value: number | undefined);
    private _defaultTableExpirationMs?;
    get defaultTableExpirationMs(): number | undefined;
    set defaultTableExpirationMs(value: number | undefined);
    private _deleteContentsOnDestroy?;
    get deleteContentsOnDestroy(): boolean | undefined;
    set deleteContentsOnDestroy(value: boolean | undefined);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    get etag(): string;
    private _friendlyName?;
    get friendlyName(): string | undefined;
    set friendlyName(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    get lastModifiedTime(): number;
    private _location?;
    get location(): string | undefined;
    set location(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    private _access?;
    get access(): BigqueryDatasetAccess[] | undefined;
    set access(value: BigqueryDatasetAccess[] | undefined);
    private _defaultEncryptionConfiguration?;
    get defaultEncryptionConfiguration(): BigqueryDatasetDefaultEncryptionConfiguration[] | undefined;
    set defaultEncryptionConfiguration(value: BigqueryDatasetDefaultEncryptionConfiguration[] | undefined);
    private _timeouts?;
    get timeouts(): BigqueryDatasetTimeouts | undefined;
    set timeouts(value: BigqueryDatasetTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
