import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface BigtableAppProfileConfig extends TerraformMetaArguments {
    /** The unique name of the app profile in the form '[_a-zA-Z0-9][-_.a-zA-Z0-9]*'. */
    readonly appProfileId: string;
    /** Long form description of the use case for this app profile. */
    readonly description?: string;
    /** If true, ignore safety checks when deleting/updating the app profile. */
    readonly ignoreWarnings?: boolean;
    /** The name of the instance to create the app profile within. */
    readonly instance?: string;
    /** If true, read/write requests are routed to the nearest cluster in the instance, and will fail over to the nearest cluster that is available
  in the event of transient errors or delays. Clusters in a region are considered equidistant. Choosing this option sacrifices read-your-writes
  consistency to improve availability. */
    readonly multiClusterRoutingUseAny?: boolean;
    readonly project?: string;
    /** single_cluster_routing block */
    readonly singleClusterRouting?: BigtableAppProfileSingleClusterRouting[];
    /** timeouts block */
    readonly timeouts?: BigtableAppProfileTimeouts;
}
export interface BigtableAppProfileSingleClusterRouting {
    /** If true, CheckAndMutateRow and ReadModifyWriteRow requests are allowed by this app profile.
  It is unsafe to send these requests to the same table/row/column in multiple clusters. */
    readonly allowTransactionalWrites?: boolean;
    /** The cluster to which read/write requests should be routed. */
    readonly clusterId: string;
}
export interface BigtableAppProfileTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class BigtableAppProfile extends TerraformResource {
    constructor(scope: Construct, id: string, config: BigtableAppProfileConfig);
    private _appProfileId;
    get appProfileId(): string;
    set appProfileId(value: string);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _ignoreWarnings?;
    get ignoreWarnings(): boolean | undefined;
    set ignoreWarnings(value: boolean | undefined);
    private _instance?;
    get instance(): string | undefined;
    set instance(value: string | undefined);
    private _multiClusterRoutingUseAny?;
    get multiClusterRoutingUseAny(): boolean | undefined;
    set multiClusterRoutingUseAny(value: boolean | undefined);
    get name(): string;
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _singleClusterRouting?;
    get singleClusterRouting(): BigtableAppProfileSingleClusterRouting[] | undefined;
    set singleClusterRouting(value: BigtableAppProfileSingleClusterRouting[] | undefined);
    private _timeouts?;
    get timeouts(): BigtableAppProfileTimeouts | undefined;
    set timeouts(value: BigtableAppProfileTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
