import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface BigtableInstanceConfig extends TerraformMetaArguments {
    /** Whether or not to allow Terraform to destroy the instance. Unless this field is set to false in Terraform state, a terraform destroy or terraform apply that would delete the instance will fail. */
    readonly deletionProtection?: boolean;
    /** The human-readable display name of the Bigtable instance. Defaults to the instance name. */
    readonly displayName?: string;
    /** The instance type to create. One of "DEVELOPMENT" or "PRODUCTION". Defaults to "PRODUCTION". */
    readonly instanceType?: string;
    /** A mapping of labels to assign to the resource. */
    readonly labels?: {
        [key: string]: string;
    };
    /** The name (also called Instance Id in the Cloud Console) of the Cloud Bigtable instance. */
    readonly name: string;
    /** The ID of the project in which the resource belongs. If it is not provided, the provider project is used. */
    readonly project?: string;
    /** cluster block */
    readonly cluster?: BigtableInstanceCluster[];
}
export interface BigtableInstanceCluster {
    /** The ID of the Cloud Bigtable cluster. */
    readonly clusterId: string;
    /** The number of nodes in your Cloud Bigtable cluster. Required, with a minimum of 1 for a PRODUCTION instance. Must be left unset for a DEVELOPMENT instance. */
    readonly numNodes?: number;
    /** The storage type to use. One of "SSD" or "HDD". Defaults to "SSD". */
    readonly storageType?: string;
    /** The zone to create the Cloud Bigtable cluster in. Each cluster must have a different zone in the same region. Zones that support Bigtable instances are noted on the Cloud Bigtable locations page. */
    readonly zone: string;
}
export declare class BigtableInstance extends TerraformResource {
    constructor(scope: Construct, id: string, config: BigtableInstanceConfig);
    private _deletionProtection?;
    get deletionProtection(): boolean | undefined;
    set deletionProtection(value: boolean | undefined);
    private _displayName?;
    get displayName(): string | undefined;
    set displayName(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _instanceType?;
    get instanceType(): string | undefined;
    set instanceType(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _cluster?;
    get cluster(): BigtableInstanceCluster[] | undefined;
    set cluster(value: BigtableInstanceCluster[] | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
