import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface BinaryAuthorizationAttestorConfig extends TerraformMetaArguments {
    /** A descriptive comment. This field may be updated. The field may be
  displayed in chooser dialogs. */
    readonly description?: string;
    /** The resource name. */
    readonly name: string;
    readonly project?: string;
    /** attestation_authority_note block */
    readonly attestationAuthorityNote: BinaryAuthorizationAttestorAttestationAuthorityNote[];
    /** timeouts block */
    readonly timeouts?: BinaryAuthorizationAttestorTimeouts;
}
export interface BinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKey {
    /** A PEM-encoded public key, as described in
  'https://tools.ietf.org/html/rfc7468#section-13' */
    readonly publicKeyPem?: string;
    /** The signature algorithm used to verify a message against
  a signature using this key. These signature algorithm must
  match the structure and any object identifiers encoded in
  publicKeyPem (i.e. this algorithm must match that of the
  public key). */
    readonly signatureAlgorithm?: string;
}
export interface BinaryAuthorizationAttestorAttestationAuthorityNotePublicKeys {
    /** ASCII-armored representation of a PGP public key, as the
  entire output by the command
  'gpg --export --armor foo@example.com' (either LF or CRLF
  line endings). When using this field, id should be left
  blank. The BinAuthz API handlers will calculate the ID
  and fill it in automatically. BinAuthz computes this ID
  as the OpenPGP RFC4880 V4 fingerprint, represented as
  upper-case hex. If id is provided by the caller, it will
  be overwritten by the API-calculated ID. */
    readonly asciiArmoredPgpPublicKey?: string;
    /** A descriptive comment. This field may be updated. */
    readonly comment?: string;
    /** The ID of this public key. Signatures verified by BinAuthz
  must include the ID of the public key that can be used to
  verify them, and that ID must match the contents of this
  field exactly. Additional restrictions on this field can
  be imposed based on which public key type is encapsulated.
  See the documentation on publicKey cases below for details. */
    readonly id?: string;
    /** pkix_public_key block */
    readonly pkixPublicKey?: BinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKey[];
}
export interface BinaryAuthorizationAttestorAttestationAuthorityNote {
    /** The resource name of a ATTESTATION_AUTHORITY Note, created by the
  user. If the Note is in a different project from the Attestor, it
  should be specified in the format 'projects/*\/notes/*' (or the legacy
  'providers/*\/notes/*'). This field may not be updated.
  An attestation by this attestor is stored as a Container Analysis
  ATTESTATION_AUTHORITY Occurrence that names a container image
  and that links to this Note. */
    readonly noteReference: string;
    /** public_keys block */
    readonly publicKeys?: BinaryAuthorizationAttestorAttestationAuthorityNotePublicKeys[];
}
export interface BinaryAuthorizationAttestorTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class BinaryAuthorizationAttestor extends TerraformResource {
    constructor(scope: Construct, id: string, config: BinaryAuthorizationAttestorConfig);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _attestationAuthorityNote;
    get attestationAuthorityNote(): BinaryAuthorizationAttestorAttestationAuthorityNote[];
    set attestationAuthorityNote(value: BinaryAuthorizationAttestorAttestationAuthorityNote[]);
    private _timeouts?;
    get timeouts(): BinaryAuthorizationAttestorTimeouts | undefined;
    set timeouts(value: BinaryAuthorizationAttestorTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
