import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface CloudAssetOrganizationFeedConfig extends TerraformMetaArguments {
    /** A list of the full names of the assets to receive updates. You must specify either or both of
  assetNames and assetTypes. Only asset updates matching specified assetNames and assetTypes are
  exported to the feed. For example: //compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1.
  See https://cloud.google.com/apis/design/resourceNames#fullResourceName for more info. */
    readonly assetNames?: string[];
    /** A list of types of the assets to receive updates. You must specify either or both of assetNames
  and assetTypes. Only asset updates matching specified assetNames and assetTypes are exported to
  the feed. For example: "compute.googleapis.com/Disk"
  See https://cloud.google.com/asset-inventory/docs/supported-asset-types for a list of all
  supported asset types. */
    readonly assetTypes?: string[];
    /** The project whose identity will be used when sending messages to the
  destination pubsub topic. It also specifies the project for API
  enablement check, quota, and billing. */
    readonly billingProject: string;
    /** Asset content type. If not specified, no content but the asset name and type will be returned. Possible values: ["CONTENT_TYPE_UNSPECIFIED", "RESOURCE", "IAM_POLICY", "ORG_POLICY", "ACCESS_POLICY"] */
    readonly contentType?: string;
    /** This is the client-assigned asset feed identifier and it needs to be unique under a specific parent. */
    readonly feedId: string;
    /** The organization this feed should be created in. */
    readonly orgId: string;
    /** feed_output_config block */
    readonly feedOutputConfig: CloudAssetOrganizationFeedFeedOutputConfig[];
    /** timeouts block */
    readonly timeouts?: CloudAssetOrganizationFeedTimeouts;
}
export interface CloudAssetOrganizationFeedFeedOutputConfigPubsubDestination {
    /** Destination on Cloud Pubsub topic. */
    readonly topic: string;
}
export interface CloudAssetOrganizationFeedFeedOutputConfig {
    /** pubsub_destination block */
    readonly pubsubDestination: CloudAssetOrganizationFeedFeedOutputConfigPubsubDestination[];
}
export interface CloudAssetOrganizationFeedTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class CloudAssetOrganizationFeed extends TerraformResource {
    constructor(scope: Construct, id: string, config: CloudAssetOrganizationFeedConfig);
    private _assetNames?;
    get assetNames(): string[] | undefined;
    set assetNames(value: string[] | undefined);
    private _assetTypes?;
    get assetTypes(): string[] | undefined;
    set assetTypes(value: string[] | undefined);
    private _billingProject;
    get billingProject(): string;
    set billingProject(value: string);
    private _contentType?;
    get contentType(): string | undefined;
    set contentType(value: string | undefined);
    private _feedId;
    get feedId(): string;
    set feedId(value: string);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get name(): string;
    private _orgId;
    get orgId(): string;
    set orgId(value: string);
    private _feedOutputConfig;
    get feedOutputConfig(): CloudAssetOrganizationFeedFeedOutputConfig[];
    set feedOutputConfig(value: CloudAssetOrganizationFeedFeedOutputConfig[]);
    private _timeouts?;
    get timeouts(): CloudAssetOrganizationFeedTimeouts | undefined;
    set timeouts(value: CloudAssetOrganizationFeedTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
