import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
export interface CloudRunDomainMappingConfig extends TerraformMetaArguments {
    /** The location of the cloud run instance. eg us-central1 */
    readonly location: string;
    /** Name should be a verified domain */
    readonly name: string;
    readonly project?: string;
    /** metadata block */
    readonly metadata: CloudRunDomainMappingMetadata[];
    /** spec block */
    readonly spec: CloudRunDomainMappingSpec[];
    /** timeouts block */
    readonly timeouts?: CloudRunDomainMappingTimeouts;
}
export declare class CloudRunDomainMappingStatusConditions extends ComplexComputedList {
    get message(): string;
    get reason(): string;
    get status(): string;
    get type(): string;
}
export declare class CloudRunDomainMappingStatusResourceRecords extends ComplexComputedList {
    get name(): string;
    get rrdata(): string;
    get type(): string;
}
export declare class CloudRunDomainMappingStatus extends ComplexComputedList {
    get conditions(): any;
    get mappedRouteName(): string;
    get observedGeneration(): number;
    get resourceRecords(): any;
}
export interface CloudRunDomainMappingMetadata {
    /** Annotations is a key value map stored with a resource that
  may be set by external tools to store and retrieve arbitrary metadata. More
  info: http://kubernetes.io/docs/user-guide/annotations */
    readonly annotations?: {
        [key: string]: string;
    };
    /** Map of string keys and values that can be used to organize and categorize
  (scope and select) objects. May match selectors of replication controllers
  and routes.
  More info: http://kubernetes.io/docs/user-guide/labels */
    readonly labels?: {
        [key: string]: string;
    };
    /** In Cloud Run the namespace must be equal to either the
  project ID or project number. */
    readonly namespace: string;
}
export interface CloudRunDomainMappingSpec {
    /** The mode of the certificate. Default value: "AUTOMATIC" Possible values: ["NONE", "AUTOMATIC"] */
    readonly certificateMode?: string;
    /** If set, the mapping will override any mapping set before this spec was set.
  It is recommended that the user leaves this empty to receive an error
  warning about a potential conflict and only set it once the respective UI
  has given such a warning. */
    readonly forceOverride?: boolean;
    /** The name of the Cloud Run Service that this DomainMapping applies to.
  The route must exist. */
    readonly routeName: string;
}
export interface CloudRunDomainMappingTimeouts {
    readonly create?: string;
    readonly delete?: string;
}
export declare class CloudRunDomainMapping extends TerraformResource {
    constructor(scope: Construct, id: string, config: CloudRunDomainMappingConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _location;
    get location(): string;
    set location(value: string);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    status(index: string): CloudRunDomainMappingStatus;
    private _metadata;
    get metadata(): CloudRunDomainMappingMetadata[];
    set metadata(value: CloudRunDomainMappingMetadata[]);
    private _spec;
    get spec(): CloudRunDomainMappingSpec[];
    set spec(value: CloudRunDomainMappingSpec[]);
    private _timeouts?;
    get timeouts(): CloudRunDomainMappingTimeouts | undefined;
    set timeouts(value: CloudRunDomainMappingTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
