import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface CloudbuildTriggerConfig extends TerraformMetaArguments {
    /** Human-readable description of the trigger. */
    readonly description?: string;
    /** Whether the trigger is disabled or not. If true, the trigger will never result in a build. */
    readonly disabled?: boolean;
    /** Path, from the source root, to a file whose contents is used for the template. Either a filename or build template must be provided. */
    readonly filename?: string;
    /** ignoredFiles and includedFiles are file glob matches using https://golang.org/pkg/path/filepath/#Match
  extended with support for '**'.
  
  If ignoredFiles and changed files are both empty, then they are not
  used to determine whether or not to trigger a build.
  
  If ignoredFiles is not empty, then we ignore any files that match any
  of the ignored_file globs. If the change has no files that are outside
  of the ignoredFiles globs, then we do not trigger a build. */
    readonly ignoredFiles?: string[];
    /** ignoredFiles and includedFiles are file glob matches using https://golang.org/pkg/path/filepath/#Match
  extended with support for '**'.
  
  If any of the files altered in the commit pass the ignoredFiles filter
  and includedFiles is empty, then as far as this filter is concerned, we
  should trigger the build.
  
  If any of the files altered in the commit pass the ignoredFiles filter
  and includedFiles is not empty, then we make sure that at least one of
  those files matches a includedFiles glob. If not, then we do not trigger
  a build. */
    readonly includedFiles?: string[];
    /** Name of the trigger. Must be unique within the project. */
    readonly name?: string;
    readonly project?: string;
    /** Substitutions data for Build resource. */
    readonly substitutions?: {
        [key: string]: string;
    };
    /** Tags for annotation of a BuildTrigger */
    readonly tags?: string[];
    /** build block */
    readonly buildAttribute?: CloudbuildTriggerBuild[];
    /** timeouts block */
    readonly timeouts?: CloudbuildTriggerTimeouts;
    /** trigger_template block */
    readonly triggerTemplate?: CloudbuildTriggerTriggerTemplate[];
}
export interface CloudbuildTriggerBuildSecret {
    /** Cloud KMS key name to use to decrypt these envs. */
    readonly kmsKeyName: string;
    /** Map of environment variable name to its encrypted value.
  Secret environment variables must be unique across all of a build's secrets,
  and must be used by at least one build step. Values can be at most 64 KB in size.
  There can be at most 100 secret values across all of a build's secrets. */
    readonly secretEnv?: {
        [key: string]: string;
    };
}
export interface CloudbuildTriggerBuildSourceRepoSource {
    /** Regex matching branches to build. Exactly one a of branch name, tag, or commit SHA must be provided.
  The syntax of the regular expressions accepted is the syntax accepted by RE2 and
  described at https://github.com/google/re2/wiki/Syntax */
    readonly branchName?: string;
    /** Explicit commit SHA to build. Exactly one a of branch name, tag, or commit SHA must be provided. */
    readonly commitSha?: string;
    /** Directory, relative to the source root, in which to run the build.
  This must be a relative path. If a step's dir is specified and is an absolute path,
  this value is ignored for that step's execution. */
    readonly dir?: string;
    /** Only trigger a build if the revision regex does NOT match the revision regex. */
    readonly invertRegex?: boolean;
    /** ID of the project that owns the Cloud Source Repository.
  If omitted, the project ID requesting the build is assumed. */
    readonly projectId?: string;
    /** Name of the Cloud Source Repository. */
    readonly repoName: string;
    /** Substitutions to use in a triggered build. Should only be used with triggers.run */
    readonly substitutions?: {
        [key: string]: string;
    };
    /** Regex matching tags to build. Exactly one a of branch name, tag, or commit SHA must be provided.
  The syntax of the regular expressions accepted is the syntax accepted by RE2 and
  described at https://github.com/google/re2/wiki/Syntax */
    readonly tagName?: string;
}
export interface CloudbuildTriggerBuildSourceStorageSource {
    /** Google Cloud Storage bucket containing the source. */
    readonly bucket: string;
    /** Google Cloud Storage generation for the object.
  If the generation is omitted, the latest generation will be used */
    readonly generation?: string;
    /** Google Cloud Storage object containing the source.
  This object must be a gzipped archive file (.tar.gz) containing source to build. */
    readonly object: string;
}
export interface CloudbuildTriggerBuildSource {
    /** repo_source block */
    readonly repoSource?: CloudbuildTriggerBuildSourceRepoSource[];
    /** storage_source block */
    readonly storageSource?: CloudbuildTriggerBuildSourceStorageSource[];
}
export interface CloudbuildTriggerBuildStepVolumes {
    /** Name of the volume to mount.
  
  Volume names must be unique per build step and must be valid names for
  Docker volumes. Each named volume must be used by at least two build steps. */
    readonly name: string;
    /** Path at which to mount the volume.
  
  Paths must be absolute and cannot conflict with other volume paths on
  the same build step or with certain reserved volume paths. */
    readonly path: string;
}
export interface CloudbuildTriggerBuildStep {
    /** A list of arguments that will be presented to the step when it is started.
  
  If the image used to run the step's container has an entrypoint, the args
  are used as arguments to that entrypoint. If the image does not define an
  entrypoint, the first element in args is used as the entrypoint, and the
  remainder will be used as arguments. */
    readonly args?: string[];
    /** Working directory to use when running this step's container.
  
  If this value is a relative path, it is relative to the build's working
  directory. If this value is absolute, it may be outside the build's working
  directory, in which case the contents of the path may not be persisted
  across build step executions, unless a 'volume' for that path is specified.
  
  If the build specifies a 'RepoSource' with 'dir' and a step with a
  'dir',
  which specifies an absolute path, the 'RepoSource' 'dir' is ignored
  for the step's execution. */
    readonly dir?: string;
    /** Entrypoint to be used instead of the build step image's
  default entrypoint.
  If unset, the image's default entrypoint is used */
    readonly entrypoint?: string;
    /** A list of environment variable definitions to be used when
  running a step.
  
  The elements are of the form "KEY=VALUE" for the environment variable
  "KEY" being given the value "VALUE". */
    readonly env?: string[];
    /** Unique identifier for this build step, used in 'wait_for' to
  reference this build step as a dependency. */
    readonly id?: string;
    /** The name of the container image that will run this particular build step.
  
  If the image is available in the host's Docker daemon's cache, it will be
  run directly. If not, the host will attempt to pull the image first, using
  the builder service account's credentials if necessary.
  
  The Docker daemon's cache will already have the latest versions of all of
  the officially supported build steps (https://github.com/GoogleCloudPlatform/cloud-builders).
  The Docker daemon will also have cached many of the layers for some popular
  images, like "ubuntu", "debian", but they will be refreshed at the time
  you attempt to use them.
  
  If you built an image in a previous build step, it will be stored in the
  host's Docker daemon's cache and is available to use as the name for a
  later build step. */
    readonly name: string;
    /** A list of environment variables which are encrypted using
  a Cloud Key
  Management Service crypto key. These values must be specified in
  the build's 'Secret'. */
    readonly secretEnv?: string[];
    /** Time limit for executing this build step. If not defined,
  the step has no
  time limit and will be allowed to continue to run until either it
  completes or the build itself times out. */
    readonly timeout?: string;
    /** Output only. Stores timing information for executing this
  build step. */
    readonly timing?: string;
    /** The ID(s) of the step(s) that this build step depends on.
  
  This build step will not start until all the build steps in 'wait_for'
  have completed successfully. If 'wait_for' is empty, this build step
  will start when all previous build steps in the 'Build.Steps' list
  have completed successfully. */
    readonly waitFor?: string[];
    /** volumes block */
    readonly volumes?: CloudbuildTriggerBuildStepVolumes[];
}
export interface CloudbuildTriggerBuild {
    /** A list of images to be pushed upon the successful completion of all build steps.
  The images are pushed using the builder service account's credentials.
  The digests of the pushed images will be stored in the Build resource's results field.
  If any of the images fail to be pushed, the build status is marked FAILURE. */
    readonly images?: string[];
    /** Google Cloud Storage bucket where logs should be written.
  Logs file names will be of the format ${logsBucket}/log-${build_id}.txt. */
    readonly logsBucket?: string;
    /** TTL in queue for this build. If provided and the build is enqueued longer than this value,
  the build will expire and the build status will be EXPIRED.
  The TTL starts ticking from createTime.
  A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s". */
    readonly queueTtl?: string;
    /** Substitutions data for Build resource. */
    readonly substitutions?: {
        [key: string]: string;
    };
    /** Tags for annotation of a Build. These are not docker tags. */
    readonly tags?: string[];
    /** Amount of time that this build should be allowed to run, to second granularity.
  If this amount of time elapses, work on the build will cease and the build status will be TIMEOUT.
  This timeout must be equal to or greater than the sum of the timeouts for build steps within the build.
  The expected format is the number of seconds followed by s.
  Default time is ten minutes (600s). */
    readonly timeout?: string;
    /** secret block */
    readonly secret?: CloudbuildTriggerBuildSecret[];
    /** source block */
    readonly source?: CloudbuildTriggerBuildSource[];
    /** step block */
    readonly step: CloudbuildTriggerBuildStep[];
}
export interface CloudbuildTriggerTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export interface CloudbuildTriggerTriggerTemplate {
    /** Name of the branch to build. Exactly one a of branch name, tag, or commit SHA must be provided.
  This field is a regular expression. */
    readonly branchName?: string;
    /** Explicit commit SHA to build. Exactly one of a branch name, tag, or commit SHA must be provided. */
    readonly commitSha?: string;
    /** Directory, relative to the source root, in which to run the build.
  
  This must be a relative path. If a step's dir is specified and
  is an absolute path, this value is ignored for that step's
  execution. */
    readonly dir?: string;
    /** Only trigger a build if the revision regex does NOT match the revision regex. */
    readonly invertRegex?: boolean;
    /** ID of the project that owns the Cloud Source Repository. If
  omitted, the project ID requesting the build is assumed. */
    readonly projectId?: string;
    /** Name of the Cloud Source Repository. If omitted, the name "default" is assumed. */
    readonly repoName?: string;
    /** Name of the tag to build. Exactly one of a branch name, tag, or commit SHA must be provided.
  This field is a regular expression. */
    readonly tagName?: string;
}
export declare class CloudbuildTrigger extends TerraformResource {
    constructor(scope: Construct, id: string, config?: CloudbuildTriggerConfig);
    get createTime(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _disabled?;
    get disabled(): boolean | undefined;
    set disabled(value: boolean | undefined);
    private _filename?;
    get filename(): string | undefined;
    set filename(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _ignoredFiles?;
    get ignoredFiles(): string[] | undefined;
    set ignoredFiles(value: string[] | undefined);
    private _includedFiles?;
    get includedFiles(): string[] | undefined;
    set includedFiles(value: string[] | undefined);
    private _name?;
    get name(): string | undefined;
    set name(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _substitutions?;
    get substitutions(): {
        [key: string]: string;
    } | undefined;
    set substitutions(value: {
        [key: string]: string;
    } | undefined);
    private _tags?;
    get tags(): string[] | undefined;
    set tags(value: string[] | undefined);
    get triggerId(): string;
    private _build?;
    get buildAttribute(): CloudbuildTriggerBuild[] | undefined;
    set buildAttribute(value: CloudbuildTriggerBuild[] | undefined);
    private _timeouts?;
    get timeouts(): CloudbuildTriggerTimeouts | undefined;
    set timeouts(value: CloudbuildTriggerTimeouts | undefined);
    private _triggerTemplate?;
    get triggerTemplate(): CloudbuildTriggerTriggerTemplate[] | undefined;
    set triggerTemplate(value: CloudbuildTriggerTriggerTemplate[] | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
