import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface CloudfunctionsFunctionConfig extends TerraformMetaArguments {
    /** Memory (in MB), available to the function. Default value is 256MB. Allowed values are: 128MB, 256MB, 512MB, 1024MB, and 2048MB. */
    readonly availableMemoryMb?: number;
    /** Description of the function. */
    readonly description?: string;
    /** Name of the function that will be executed when the Google Cloud Function is triggered. */
    readonly entryPoint?: string;
    /** A set of key/value environment variable pairs to assign to the function. */
    readonly environmentVariables?: {
        [key: string]: string;
    };
    /** URL which triggers function execution. Returned only if trigger_http is used. */
    readonly httpsTriggerUrl?: string;
    /** String value that controls what traffic can reach the function. Allowed values are ALLOW_ALL and ALLOW_INTERNAL_ONLY. Changes to this field will recreate the cloud function. */
    readonly ingressSettings?: string;
    /** A set of key/value label pairs to assign to the function. Label keys must follow the requirements at https://cloud.google.com/resource-manager/docs/creating-managing-labels#requirements. */
    readonly labels?: {
        [key: string]: string;
    };
    /** The limit on the maximum number of function instances that may coexist at a given time. */
    readonly maxInstances?: number;
    /** A user-defined name of the function. Function names must be unique globally. */
    readonly name: string;
    /** Project of the function. If it is not provided, the provider project is used. */
    readonly project?: string;
    /** Region of function. Currently can be only "us-central1". If it is not provided, the provider region is used. */
    readonly region?: string;
    /** The runtime in which the function is going to run. Eg. "nodejs8", "nodejs10", "python37", "go111". */
    readonly runtime: string;
    /**  If provided, the self-provided service account to run the function with. */
    readonly serviceAccountEmail?: string;
    /** The GCS bucket containing the zip archive which contains the function. */
    readonly sourceArchiveBucket?: string;
    /** The source archive object (file) in archive bucket. */
    readonly sourceArchiveObject?: string;
    /** Timeout (in seconds) for the function. Default value is 60 seconds. Cannot be more than 540 seconds. */
    readonly timeout?: number;
    /** Boolean variable. Any HTTP request (of a supported type) to the endpoint will trigger function execution. Supported HTTP request types are: POST, PUT, GET, DELETE, and OPTIONS. Endpoint is returned as https_trigger_url. Cannot be used with trigger_bucket and trigger_topic. */
    readonly triggerHttp?: boolean;
    /** The VPC Network Connector that this cloud function can connect to. It can be either the fully-qualified URI, or the short name of the network connector resource. The format of this field is projects/*\/locations/*\/connectors/*. */
    readonly vpcConnector?: string;
    /** The egress settings for the connector, controlling what traffic is diverted through it. Allowed values are ALL_TRAFFIC and PRIVATE_RANGES_ONLY. Defaults to PRIVATE_RANGES_ONLY. If unset, this field preserves the previously set value. */
    readonly vpcConnectorEgressSettings?: string;
    /** event_trigger block */
    readonly eventTrigger?: CloudfunctionsFunctionEventTrigger[];
    /** source_repository block */
    readonly sourceRepository?: CloudfunctionsFunctionSourceRepository[];
    /** timeouts block */
    readonly timeouts?: CloudfunctionsFunctionTimeouts;
}
export interface CloudfunctionsFunctionEventTriggerFailurePolicy {
    /** Whether the function should be retried on failure. Defaults to false. */
    readonly retry: boolean;
}
export interface CloudfunctionsFunctionEventTrigger {
    /** The type of event to observe. For example: "google.storage.object.finalize". See the documentation on calling Cloud Functions for a full reference of accepted triggers. */
    readonly eventType: string;
    /** The name or partial URI of the resource from which to observe events. For example, "myBucket" or "projects/my-project/topics/my-topic" */
    readonly resource: string;
    /** failure_policy block */
    readonly failurePolicy?: CloudfunctionsFunctionEventTriggerFailurePolicy[];
}
export interface CloudfunctionsFunctionSourceRepository {
    /** The URL pointing to the hosted repository where the function is defined. */
    readonly url: string;
}
export interface CloudfunctionsFunctionTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class CloudfunctionsFunction extends TerraformResource {
    constructor(scope: Construct, id: string, config: CloudfunctionsFunctionConfig);
    private _availableMemoryMb?;
    get availableMemoryMb(): number | undefined;
    set availableMemoryMb(value: number | undefined);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _entryPoint?;
    get entryPoint(): string | undefined;
    set entryPoint(value: string | undefined);
    private _environmentVariables?;
    get environmentVariables(): {
        [key: string]: string;
    } | undefined;
    set environmentVariables(value: {
        [key: string]: string;
    } | undefined);
    private _httpsTriggerUrl?;
    get httpsTriggerUrl(): string | undefined;
    set httpsTriggerUrl(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _ingressSettings?;
    get ingressSettings(): string | undefined;
    set ingressSettings(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _maxInstances?;
    get maxInstances(): number | undefined;
    set maxInstances(value: number | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _region?;
    get region(): string | undefined;
    set region(value: string | undefined);
    private _runtime;
    get runtime(): string;
    set runtime(value: string);
    private _serviceAccountEmail?;
    get serviceAccountEmail(): string | undefined;
    set serviceAccountEmail(value: string | undefined);
    private _sourceArchiveBucket?;
    get sourceArchiveBucket(): string | undefined;
    set sourceArchiveBucket(value: string | undefined);
    private _sourceArchiveObject?;
    get sourceArchiveObject(): string | undefined;
    set sourceArchiveObject(value: string | undefined);
    private _timeout?;
    get timeout(): number | undefined;
    set timeout(value: number | undefined);
    private _triggerHttp?;
    get triggerHttp(): boolean | undefined;
    set triggerHttp(value: boolean | undefined);
    private _vpcConnector?;
    get vpcConnector(): string | undefined;
    set vpcConnector(value: string | undefined);
    private _vpcConnectorEgressSettings?;
    get vpcConnectorEgressSettings(): string | undefined;
    set vpcConnectorEgressSettings(value: string | undefined);
    private _eventTrigger?;
    get eventTrigger(): CloudfunctionsFunctionEventTrigger[] | undefined;
    set eventTrigger(value: CloudfunctionsFunctionEventTrigger[] | undefined);
    private _sourceRepository?;
    get sourceRepository(): CloudfunctionsFunctionSourceRepository[] | undefined;
    set sourceRepository(value: CloudfunctionsFunctionSourceRepository[] | undefined);
    private _timeouts?;
    get timeouts(): CloudfunctionsFunctionTimeouts | undefined;
    set timeouts(value: CloudfunctionsFunctionTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
