import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
export interface CloudiotDeviceConfig extends TerraformMetaArguments {
    /** If a device is blocked, connections or requests from this device will fail. */
    readonly blocked?: boolean;
    /** The logging verbosity for device activity. Possible values: ["NONE", "ERROR", "INFO", "DEBUG"] */
    readonly logLevel?: string;
    /** The metadata key-value pairs assigned to the device. */
    readonly metadata?: {
        [key: string]: string;
    };
    /** A unique name for the resource. */
    readonly name: string;
    /** The name of the device registry where this device should be created. */
    readonly registry: string;
    /** credentials block */
    readonly credentials?: CloudiotDeviceCredentials[];
    /** gateway_config block */
    readonly gatewayConfig?: CloudiotDeviceGatewayConfig[];
    /** timeouts block */
    readonly timeouts?: CloudiotDeviceTimeouts;
}
export declare class CloudiotDeviceConfigA extends ComplexComputedList {
    get binaryData(): string;
    get cloudUpdateTime(): string;
    get deviceAckTime(): string;
    get version(): string;
}
export declare class CloudiotDeviceLastErrorStatus extends ComplexComputedList {
    get details(): any;
    get message(): string;
    get number(): number;
}
export declare class CloudiotDeviceState extends ComplexComputedList {
    get binaryData(): string;
    get updateTime(): string;
}
export interface CloudiotDeviceCredentialsPublicKey {
    /** The format of the key. Possible values: ["RSA_PEM", "RSA_X509_PEM", "ES256_PEM", "ES256_X509_PEM"] */
    readonly format: string;
    /** The key data. */
    readonly key: string;
}
export interface CloudiotDeviceCredentials {
    /** The time at which this credential becomes invalid. */
    readonly expirationTime?: string;
    /** public_key block */
    readonly publicKey: CloudiotDeviceCredentialsPublicKey[];
}
export interface CloudiotDeviceGatewayConfig {
    /** Indicates whether the device is a gateway. Possible values: ["ASSOCIATION_ONLY", "DEVICE_AUTH_TOKEN_ONLY", "ASSOCIATION_AND_DEVICE_AUTH_TOKEN"] */
    readonly gatewayAuthMethod?: string;
    /** Indicates whether the device is a gateway. Default value: "NON_GATEWAY" Possible values: ["GATEWAY", "NON_GATEWAY"] */
    readonly gatewayType?: string;
}
export interface CloudiotDeviceTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class CloudiotDevice extends TerraformResource {
    constructor(scope: Construct, id: string, config: CloudiotDeviceConfig);
    private _blocked?;
    get blocked(): boolean | undefined;
    set blocked(value: boolean | undefined);
    config(index: string): CloudiotDeviceConfigA;
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get lastConfigAckTime(): string;
    get lastConfigSendTime(): string;
    lastErrorStatus(index: string): CloudiotDeviceLastErrorStatus;
    get lastErrorTime(): string;
    get lastEventTime(): string;
    get lastHeartbeatTime(): string;
    get lastStateTime(): string;
    private _logLevel?;
    get logLevel(): string | undefined;
    set logLevel(value: string | undefined);
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    } | undefined;
    set metadata(value: {
        [key: string]: string;
    } | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    get numId(): string;
    private _registry;
    get registry(): string;
    set registry(value: string);
    state(index: string): CloudiotDeviceState;
    private _credentials?;
    get credentials(): CloudiotDeviceCredentials[] | undefined;
    set credentials(value: CloudiotDeviceCredentials[] | undefined);
    private _gatewayConfig?;
    get gatewayConfig(): CloudiotDeviceGatewayConfig[] | undefined;
    set gatewayConfig(value: CloudiotDeviceGatewayConfig[] | undefined);
    private _timeouts?;
    get timeouts(): CloudiotDeviceTimeouts | undefined;
    set timeouts(value: CloudiotDeviceTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
