import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface CloudiotRegistryConfig extends TerraformMetaArguments {
    /** Activate or deactivate HTTP. */
    readonly httpConfig?: {
        [key: string]: string;
    };
    /** The default logging verbosity for activity from devices in this
  registry. Specifies which events should be written to logs. For
  example, if the LogLevel is ERROR, only events that terminate in
  errors will be logged. LogLevel is inclusive; enabling INFO logging
  will also enable ERROR logging. Default value: "NONE" Possible values: ["NONE", "ERROR", "INFO", "DEBUG"] */
    readonly logLevel?: string;
    /** Activate or deactivate MQTT. */
    readonly mqttConfig?: {
        [key: string]: string;
    };
    /** A unique name for the resource, required by device registry. */
    readonly name: string;
    readonly project?: string;
    /** The region in which the created registry should reside.
  If it is not provided, the provider region is used. */
    readonly region?: string;
    /** A PubSub topic to publish device state updates. */
    readonly stateNotificationConfig?: {
        [key: string]: string;
    };
    /** credentials block */
    readonly credentials?: CloudiotRegistryCredentials[];
    /** event_notification_configs block */
    readonly eventNotificationConfigs?: CloudiotRegistryEventNotificationConfigs[];
    /** timeouts block */
    readonly timeouts?: CloudiotRegistryTimeouts;
}
export interface CloudiotRegistryCredentials {
    /** A public key certificate format and data. */
    readonly publicKeyCertificate: {
        [key: string]: string;
    };
}
export interface CloudiotRegistryEventNotificationConfigs {
    /** PubSub topic name to publish device events. */
    readonly pubsubTopicName: string;
    /** If the subfolder name matches this string exactly, this
  configuration will be used. The string must not include the
  leading '/' character. If empty, all strings are matched. Empty
  value can only be used for the last 'event_notification_configs'
  item. */
    readonly subfolderMatches?: string;
}
export interface CloudiotRegistryTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class CloudiotRegistry extends TerraformResource {
    constructor(scope: Construct, id: string, config: CloudiotRegistryConfig);
    private _httpConfig?;
    get httpConfig(): {
        [key: string]: string;
    } | undefined;
    set httpConfig(value: {
        [key: string]: string;
    } | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _logLevel?;
    get logLevel(): string | undefined;
    set logLevel(value: string | undefined);
    private _mqttConfig?;
    get mqttConfig(): {
        [key: string]: string;
    } | undefined;
    set mqttConfig(value: {
        [key: string]: string;
    } | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _region?;
    get region(): string | undefined;
    set region(value: string | undefined);
    private _stateNotificationConfig?;
    get stateNotificationConfig(): {
        [key: string]: string;
    } | undefined;
    set stateNotificationConfig(value: {
        [key: string]: string;
    } | undefined);
    private _credentials?;
    get credentials(): CloudiotRegistryCredentials[] | undefined;
    set credentials(value: CloudiotRegistryCredentials[] | undefined);
    private _eventNotificationConfigs?;
    get eventNotificationConfigs(): CloudiotRegistryEventNotificationConfigs[] | undefined;
    set eventNotificationConfigs(value: CloudiotRegistryEventNotificationConfigs[] | undefined);
    private _timeouts?;
    get timeouts(): CloudiotRegistryTimeouts | undefined;
    set timeouts(value: CloudiotRegistryTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
