import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeAddressConfig extends TerraformMetaArguments {
    /** The static external IP address represented by this resource. Only
  IPv4 is supported. An address may only be specified for INTERNAL
  address types. The IP address must be inside the specified subnetwork,
  if any. */
    readonly address?: string;
    /** The type of address to reserve. Default value: "EXTERNAL" Possible values: ["INTERNAL", "EXTERNAL"] */
    readonly addressType?: string;
    /** An optional description of this resource. */
    readonly description?: string;
    /** Name of the resource. The name must be 1-63 characters long, and
  comply with RFC1035. Specifically, the name must be 1-63 characters
  long and match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?'
  which means the first character must be a lowercase letter, and all
  following characters must be a dash, lowercase letter, or digit,
  except the last character, which cannot be a dash. */
    readonly name: string;
    /** The networking tier used for configuring this address. If this field is not
  specified, it is assumed to be PREMIUM. Possible values: ["PREMIUM", "STANDARD"] */
    readonly networkTier?: string;
    readonly project?: string;
    /** The purpose of this resource, which can be one of the following values:
  
  - GCE_ENDPOINT for addresses that are used by VM instances, alias IP ranges, internal load balancers, and similar resources.
  
  This should only be set when using an Internal address. Possible values: ["GCE_ENDPOINT"] */
    readonly purpose?: string;
    /** The Region in which the created address should reside.
  If it is not provided, the provider region is used. */
    readonly region?: string;
    /** The URL of the subnetwork in which to reserve the address. If an IP
  address is specified, it must be within the subnetwork's IP range.
  This field can only be used with INTERNAL type with
  GCE_ENDPOINT/DNS_RESOLVER purposes. */
    readonly subnetwork?: string;
    /** timeouts block */
    readonly timeouts?: ComputeAddressTimeouts;
}
export interface ComputeAddressTimeouts {
    readonly create?: string;
    readonly delete?: string;
}
export declare class ComputeAddress extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeAddressConfig);
    private _address?;
    get address(): string | undefined;
    set address(value: string | undefined);
    private _addressType?;
    get addressType(): string | undefined;
    set addressType(value: string | undefined);
    get creationTimestamp(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _networkTier?;
    get networkTier(): string | undefined;
    set networkTier(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _purpose?;
    get purpose(): string | undefined;
    set purpose(value: string | undefined);
    private _region?;
    get region(): string | undefined;
    set region(value: string | undefined);
    get selfLink(): string;
    private _subnetwork?;
    get subnetwork(): string | undefined;
    set subnetwork(value: string | undefined);
    get users(): string[];
    private _timeouts?;
    get timeouts(): ComputeAddressTimeouts | undefined;
    set timeouts(value: ComputeAddressTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
