import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeAttachedDiskConfig extends TerraformMetaArguments {
    /** Specifies a unique device name of your choice that is reflected into the /dev/disk/by-id/google-* tree of a Linux operating system running within the instance. This name can be used to reference the device for mounting, resizing, and so on, from within the instance. If not specified, the server chooses a default device name to apply to this disk, in the form persistent-disks-x, where x is a number assigned by Google Compute Engine. */
    readonly deviceName?: string;
    /** name or self_link of the disk that will be attached. */
    readonly disk: string;
    /** name or self_link of the compute instance that the disk will be attached to. If the self_link is provided then zone and project are extracted from the self link. If only the name is used then zone and project must be defined as properties on the resource or provider. */
    readonly instance: string;
    /** The mode in which to attach this disk, either READ_WRITE or READ_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode. */
    readonly mode?: string;
    /** The project that the referenced compute instance is a part of. If instance is referenced by its self_link the project defined in the link will take precedence. */
    readonly project?: string;
    /** The zone that the referenced compute instance is located within. If instance is referenced by its self_link the zone defined in the link will take precedence. */
    readonly zone?: string;
    /** timeouts block */
    readonly timeouts?: ComputeAttachedDiskTimeouts;
}
export interface ComputeAttachedDiskTimeouts {
    readonly create?: string;
    readonly delete?: string;
}
export declare class ComputeAttachedDisk extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeAttachedDiskConfig);
    private _deviceName?;
    get deviceName(): string | undefined;
    set deviceName(value: string | undefined);
    private _disk;
    get disk(): string;
    set disk(value: string);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _instance;
    get instance(): string;
    set instance(value: string);
    private _mode?;
    get mode(): string | undefined;
    set mode(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _zone?;
    get zone(): string | undefined;
    set zone(value: string | undefined);
    private _timeouts?;
    get timeouts(): ComputeAttachedDiskTimeouts | undefined;
    set timeouts(value: ComputeAttachedDiskTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
