import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeAutoscalerConfig extends TerraformMetaArguments {
    /** An optional description of this resource. */
    readonly description?: string;
    /** Name of the resource. The name must be 1-63 characters long and match
  the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
  first character must be a lowercase letter, and all following
  characters must be a dash, lowercase letter, or digit, except the last
  character, which cannot be a dash. */
    readonly name: string;
    readonly project?: string;
    /** URL of the managed instance group that this autoscaler will scale. */
    readonly target: string;
    /** URL of the zone where the instance group resides. */
    readonly zone?: string;
    /** autoscaling_policy block */
    readonly autoscalingPolicy: ComputeAutoscalerAutoscalingPolicy[];
    /** timeouts block */
    readonly timeouts?: ComputeAutoscalerTimeouts;
}
export interface ComputeAutoscalerAutoscalingPolicyCpuUtilization {
    /** The target CPU utilization that the autoscaler should maintain.
  Must be a float value in the range (0, 1]. If not specified, the
  default is 0.6.
  
  If the CPU level is below the target utilization, the autoscaler
  scales down the number of instances until it reaches the minimum
  number of instances you specified or until the average CPU of
  your instances reaches the target utilization.
  
  If the average CPU is above the target utilization, the autoscaler
  scales up until it reaches the maximum number of instances you
  specified or until the average utilization reaches the target
  utilization. */
    readonly target: number;
}
export interface ComputeAutoscalerAutoscalingPolicyLoadBalancingUtilization {
    /** Fraction of backend capacity utilization (set in HTTP(s) load
  balancing configuration) that autoscaler should maintain. Must
  be a positive float value. If not defined, the default is 0.8. */
    readonly target: number;
}
export interface ComputeAutoscalerAutoscalingPolicyMetric {
    /** The identifier (type) of the Stackdriver Monitoring metric.
  The metric cannot have negative values.
  
  The metric must have a value type of INT64 or DOUBLE. */
    readonly name: string;
    /** The target value of the metric that autoscaler should
  maintain. This must be a positive value. A utilization
  metric scales number of virtual machines handling requests
  to increase or decrease proportionally to the metric.
  
  For example, a good metric to use as a utilizationTarget is
  www.googleapis.com/compute/instance/network/received_bytes_count.
  The autoscaler will work to keep this value constant for each
  of the instances. */
    readonly target?: number;
    /** Defines how target utilization value is expressed for a
  Stackdriver Monitoring metric. Possible values: ["GAUGE", "DELTA_PER_SECOND", "DELTA_PER_MINUTE"] */
    readonly type?: string;
}
export interface ComputeAutoscalerAutoscalingPolicy {
    /** The number of seconds that the autoscaler should wait before it
  starts collecting information from a new instance. This prevents
  the autoscaler from collecting information when the instance is
  initializing, during which the collected usage would not be
  reliable. The default time autoscaler waits is 60 seconds.
  
  Virtual machine initialization times might vary because of
  numerous factors. We recommend that you test how long an
  instance may take to initialize. To do this, create an instance
  and time the startup process. */
    readonly cooldownPeriod?: number;
    /** The maximum number of instances that the autoscaler can scale up
  to. This is required when creating or updating an autoscaler. The
  maximum number of replicas should not be lower than minimal number
  of replicas. */
    readonly maxReplicas: number;
    /** The minimum number of replicas that the autoscaler can scale down
  to. This cannot be less than 0. If not provided, autoscaler will
  choose a default value depending on maximum number of instances
  allowed. */
    readonly minReplicas: number;
    /** Defines operating mode for this policy. Default value: "ON" Possible values: ["OFF", "ONLY_UP", "ON"] */
    readonly mode?: string;
    /** cpu_utilization block */
    readonly cpuUtilization?: ComputeAutoscalerAutoscalingPolicyCpuUtilization[];
    /** load_balancing_utilization block */
    readonly loadBalancingUtilization?: ComputeAutoscalerAutoscalingPolicyLoadBalancingUtilization[];
    /** metric block */
    readonly metric?: ComputeAutoscalerAutoscalingPolicyMetric[];
}
export interface ComputeAutoscalerTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeAutoscaler extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeAutoscalerConfig);
    get creationTimestamp(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    private _target;
    get target(): string;
    set target(value: string);
    private _zone?;
    get zone(): string | undefined;
    set zone(value: string | undefined);
    private _autoscalingPolicy;
    get autoscalingPolicy(): ComputeAutoscalerAutoscalingPolicy[];
    set autoscalingPolicy(value: ComputeAutoscalerAutoscalingPolicy[]);
    private _timeouts?;
    get timeouts(): ComputeAutoscalerTimeouts | undefined;
    set timeouts(value: ComputeAutoscalerTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
