import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeBackendBucketConfig extends TerraformMetaArguments {
    /** Cloud Storage bucket name. */
    readonly bucketName: string;
    /** An optional textual description of the resource; provided by the
  client when the resource is created. */
    readonly description?: string;
    /** If true, enable Cloud CDN for this BackendBucket. */
    readonly enableCdn?: boolean;
    /** Name of the resource. Provided by the client when the resource is
  created. The name must be 1-63 characters long, and comply with
  RFC1035.  Specifically, the name must be 1-63 characters long and
  match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means
  the first character must be a lowercase letter, and all following
  characters must be a dash, lowercase letter, or digit, except the
  last character, which cannot be a dash. */
    readonly name: string;
    readonly project?: string;
    /** cdn_policy block */
    readonly cdnPolicy?: ComputeBackendBucketCdnPolicy[];
    /** timeouts block */
    readonly timeouts?: ComputeBackendBucketTimeouts;
}
export interface ComputeBackendBucketCdnPolicy {
    /** Maximum number of seconds the response to a signed URL request will
  be considered fresh. After this time period,
  the response will be revalidated before being served.
  When serving responses to signed URL requests,
  Cloud CDN will internally behave as though
  all responses from this backend had a "Cache-Control: public,
  max-age=[TTL]" header, regardless of any existing Cache-Control
  header. The actual headers served in responses will not be altered. */
    readonly signedUrlCacheMaxAgeSec: number;
}
export interface ComputeBackendBucketTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeBackendBucket extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeBackendBucketConfig);
    private _bucketName;
    get bucketName(): string;
    set bucketName(value: string);
    get creationTimestamp(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _enableCdn?;
    get enableCdn(): boolean | undefined;
    set enableCdn(value: boolean | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    private _cdnPolicy?;
    get cdnPolicy(): ComputeBackendBucketCdnPolicy[] | undefined;
    set cdnPolicy(value: ComputeBackendBucketCdnPolicy[] | undefined);
    private _timeouts?;
    get timeouts(): ComputeBackendBucketTimeouts | undefined;
    set timeouts(value: ComputeBackendBucketTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
