import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeGlobalAddressConfig extends TerraformMetaArguments {
    /** The IP address or beginning of the address range represented by this
  resource. This can be supplied as an input to reserve a specific
  address or omitted to allow GCP to choose a valid one for you. */
    readonly address?: string;
    /** The type of the address to reserve.
  
  * EXTERNAL indicates public/external single IP address.
  * INTERNAL indicates internal IP ranges belonging to some network. Default value: "EXTERNAL" Possible values: ["EXTERNAL", "INTERNAL"] */
    readonly addressType?: string;
    /** An optional description of this resource. */
    readonly description?: string;
    /** The IP Version that will be used by this address. The default value is 'IPV4'. Possible values: ["IPV4", "IPV6"] */
    readonly ipVersion?: string;
    /** Name of the resource. Provided by the client when the resource is
  created. The name must be 1-63 characters long, and comply with
  RFC1035.  Specifically, the name must be 1-63 characters long and
  match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means
  the first character must be a lowercase letter, and all following
  characters must be a dash, lowercase letter, or digit, except the last
  character, which cannot be a dash. */
    readonly name: string;
    /** The URL of the network in which to reserve the IP range. The IP range
  must be in RFC1918 space. The network cannot be deleted if there are
  any reserved IP ranges referring to it.
  
  This should only be set when using an Internal address. */
    readonly network?: string;
    /** The prefix length of the IP range. If not present, it means the
  address field is a single IP address.
  
  This field is not applicable to addresses with addressType=EXTERNAL. */
    readonly prefixLength?: number;
    readonly project?: string;
    /** The purpose of the resource. For global internal addresses it can be
  
  * VPC_PEERING - for peer networks
  
  This should only be set when using an Internal address. Possible values: ["VPC_PEERING"] */
    readonly purpose?: string;
    /** timeouts block */
    readonly timeouts?: ComputeGlobalAddressTimeouts;
}
export interface ComputeGlobalAddressTimeouts {
    readonly create?: string;
    readonly delete?: string;
}
export declare class ComputeGlobalAddress extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeGlobalAddressConfig);
    private _address?;
    get address(): string | undefined;
    set address(value: string | undefined);
    private _addressType?;
    get addressType(): string | undefined;
    set addressType(value: string | undefined);
    get creationTimestamp(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _ipVersion?;
    get ipVersion(): string | undefined;
    set ipVersion(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _network?;
    get network(): string | undefined;
    set network(value: string | undefined);
    private _prefixLength?;
    get prefixLength(): number | undefined;
    set prefixLength(value: number | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _purpose?;
    get purpose(): string | undefined;
    set purpose(value: string | undefined);
    get selfLink(): string;
    private _timeouts?;
    get timeouts(): ComputeGlobalAddressTimeouts | undefined;
    set timeouts(value: ComputeGlobalAddressTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
