import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeHealthCheckConfig extends TerraformMetaArguments {
    /** How often (in seconds) to send a health check. The default value is 5
  seconds. */
    readonly checkIntervalSec?: number;
    /** An optional description of this resource. Provide this property when
  you create the resource. */
    readonly description?: string;
    /** A so-far unhealthy instance will be marked healthy after this many
  consecutive successes. The default value is 2. */
    readonly healthyThreshold?: number;
    /** Name of the resource. Provided by the client when the resource is
  created. The name must be 1-63 characters long, and comply with
  RFC1035.  Specifically, the name must be 1-63 characters long and
  match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means
  the first character must be a lowercase letter, and all following
  characters must be a dash, lowercase letter, or digit, except the
  last character, which cannot be a dash. */
    readonly name: string;
    readonly project?: string;
    /** How long (in seconds) to wait before claiming failure.
  The default value is 5 seconds.  It is invalid for timeoutSec to have
  greater value than checkIntervalSec. */
    readonly timeoutSec?: number;
    /** A so-far healthy instance will be marked unhealthy after this many
  consecutive failures. The default value is 2. */
    readonly unhealthyThreshold?: number;
    /** grpc_health_check block */
    readonly grpcHealthCheck?: ComputeHealthCheckGrpcHealthCheck[];
    /** http2_health_check block */
    readonly http2HealthCheck?: ComputeHealthCheckHttp2HealthCheck[];
    /** http_health_check block */
    readonly httpHealthCheck?: ComputeHealthCheckHttpHealthCheck[];
    /** https_health_check block */
    readonly httpsHealthCheck?: ComputeHealthCheckHttpsHealthCheck[];
    /** ssl_health_check block */
    readonly sslHealthCheck?: ComputeHealthCheckSslHealthCheck[];
    /** tcp_health_check block */
    readonly tcpHealthCheck?: ComputeHealthCheckTcpHealthCheck[];
    /** timeouts block */
    readonly timeouts?: ComputeHealthCheckTimeouts;
}
export interface ComputeHealthCheckGrpcHealthCheck {
    /** The gRPC service name for the health check.
  The value of grpcServiceName has the following meanings by convention:
    - Empty serviceName means the overall status of all services at the backend.
    - Non-empty serviceName means the health of that gRPC service, as defined by the owner of the service.
  The grpcServiceName can only be ASCII. */
    readonly grpcServiceName?: string;
    /** The port number for the health check request.
  Must be specified if portName and portSpecification are not set
  or if port_specification is USE_FIXED_PORT. Valid values are 1 through 65535. */
    readonly port?: number;
    /** Port name as defined in InstanceGroup#NamedPort#name. If both port and
  port_name are defined, port takes precedence. */
    readonly portName?: string;
    /** Specifies how port is selected for health checking, can be one of the
  following values:
  
    * 'USE_FIXED_PORT': The port number in 'port' is used for health checking.
  
    * 'USE_NAMED_PORT': The 'portName' is used for health checking.
  
    * 'USE_SERVING_PORT': For NetworkEndpointGroup, the port specified for each
    network endpoint is used for health checking. For other backends, the
    port or named port specified in the Backend Service is used for health
    checking.
  
  If not specified, gRPC health check follows behavior specified in 'port' and
  'portName' fields. Possible values: ["USE_FIXED_PORT", "USE_NAMED_PORT", "USE_SERVING_PORT"] */
    readonly portSpecification?: string;
}
export interface ComputeHealthCheckHttp2HealthCheck {
    /** The value of the host header in the HTTP2 health check request.
  If left empty (default value), the public IP on behalf of which this health
  check is performed will be used. */
    readonly host?: string;
    /** The TCP port number for the HTTP2 health check request.
  The default value is 443. */
    readonly port?: number;
    /** Port name as defined in InstanceGroup#NamedPort#name. If both port and
  port_name are defined, port takes precedence. */
    readonly portName?: string;
    /** Specifies how port is selected for health checking, can be one of the
  following values:
  
    * 'USE_FIXED_PORT': The port number in 'port' is used for health checking.
  
    * 'USE_NAMED_PORT': The 'portName' is used for health checking.
  
    * 'USE_SERVING_PORT': For NetworkEndpointGroup, the port specified for each
    network endpoint is used for health checking. For other backends, the
    port or named port specified in the Backend Service is used for health
    checking.
  
  If not specified, HTTP2 health check follows behavior specified in 'port' and
  'portName' fields. Possible values: ["USE_FIXED_PORT", "USE_NAMED_PORT", "USE_SERVING_PORT"] */
    readonly portSpecification?: string;
    /** Specifies the type of proxy header to append before sending data to the
  backend. Default value: "NONE" Possible values: ["NONE", "PROXY_V1"] */
    readonly proxyHeader?: string;
    /** The request path of the HTTP2 health check request.
  The default value is /. */
    readonly requestPath?: string;
    /** The bytes to match against the beginning of the response data. If left empty
  (the default value), any response will indicate health. The response data
  can only be ASCII. */
    readonly response?: string;
}
export interface ComputeHealthCheckHttpHealthCheck {
    /** The value of the host header in the HTTP health check request.
  If left empty (default value), the public IP on behalf of which this health
  check is performed will be used. */
    readonly host?: string;
    /** The TCP port number for the HTTP health check request.
  The default value is 80. */
    readonly port?: number;
    /** Port name as defined in InstanceGroup#NamedPort#name. If both port and
  port_name are defined, port takes precedence. */
    readonly portName?: string;
    /** Specifies how port is selected for health checking, can be one of the
  following values:
  
    * 'USE_FIXED_PORT': The port number in 'port' is used for health checking.
  
    * 'USE_NAMED_PORT': The 'portName' is used for health checking.
  
    * 'USE_SERVING_PORT': For NetworkEndpointGroup, the port specified for each
    network endpoint is used for health checking. For other backends, the
    port or named port specified in the Backend Service is used for health
    checking.
  
  If not specified, HTTP health check follows behavior specified in 'port' and
  'portName' fields. Possible values: ["USE_FIXED_PORT", "USE_NAMED_PORT", "USE_SERVING_PORT"] */
    readonly portSpecification?: string;
    /** Specifies the type of proxy header to append before sending data to the
  backend. Default value: "NONE" Possible values: ["NONE", "PROXY_V1"] */
    readonly proxyHeader?: string;
    /** The request path of the HTTP health check request.
  The default value is /. */
    readonly requestPath?: string;
    /** The bytes to match against the beginning of the response data. If left empty
  (the default value), any response will indicate health. The response data
  can only be ASCII. */
    readonly response?: string;
}
export interface ComputeHealthCheckHttpsHealthCheck {
    /** The value of the host header in the HTTPS health check request.
  If left empty (default value), the public IP on behalf of which this health
  check is performed will be used. */
    readonly host?: string;
    /** The TCP port number for the HTTPS health check request.
  The default value is 443. */
    readonly port?: number;
    /** Port name as defined in InstanceGroup#NamedPort#name. If both port and
  port_name are defined, port takes precedence. */
    readonly portName?: string;
    /** Specifies how port is selected for health checking, can be one of the
  following values:
  
    * 'USE_FIXED_PORT': The port number in 'port' is used for health checking.
  
    * 'USE_NAMED_PORT': The 'portName' is used for health checking.
  
    * 'USE_SERVING_PORT': For NetworkEndpointGroup, the port specified for each
    network endpoint is used for health checking. For other backends, the
    port or named port specified in the Backend Service is used for health
    checking.
  
  If not specified, HTTPS health check follows behavior specified in 'port' and
  'portName' fields. Possible values: ["USE_FIXED_PORT", "USE_NAMED_PORT", "USE_SERVING_PORT"] */
    readonly portSpecification?: string;
    /** Specifies the type of proxy header to append before sending data to the
  backend. Default value: "NONE" Possible values: ["NONE", "PROXY_V1"] */
    readonly proxyHeader?: string;
    /** The request path of the HTTPS health check request.
  The default value is /. */
    readonly requestPath?: string;
    /** The bytes to match against the beginning of the response data. If left empty
  (the default value), any response will indicate health. The response data
  can only be ASCII. */
    readonly response?: string;
}
export interface ComputeHealthCheckSslHealthCheck {
    /** The TCP port number for the SSL health check request.
  The default value is 443. */
    readonly port?: number;
    /** Port name as defined in InstanceGroup#NamedPort#name. If both port and
  port_name are defined, port takes precedence. */
    readonly portName?: string;
    /** Specifies how port is selected for health checking, can be one of the
  following values:
  
    * 'USE_FIXED_PORT': The port number in 'port' is used for health checking.
  
    * 'USE_NAMED_PORT': The 'portName' is used for health checking.
  
    * 'USE_SERVING_PORT': For NetworkEndpointGroup, the port specified for each
    network endpoint is used for health checking. For other backends, the
    port or named port specified in the Backend Service is used for health
    checking.
  
  If not specified, SSL health check follows behavior specified in 'port' and
  'portName' fields. Possible values: ["USE_FIXED_PORT", "USE_NAMED_PORT", "USE_SERVING_PORT"] */
    readonly portSpecification?: string;
    /** Specifies the type of proxy header to append before sending data to the
  backend. Default value: "NONE" Possible values: ["NONE", "PROXY_V1"] */
    readonly proxyHeader?: string;
    /** The application data to send once the SSL connection has been
  established (default value is empty). If both request and response are
  empty, the connection establishment alone will indicate health. The request
  data can only be ASCII. */
    readonly request?: string;
    /** The bytes to match against the beginning of the response data. If left empty
  (the default value), any response will indicate health. The response data
  can only be ASCII. */
    readonly response?: string;
}
export interface ComputeHealthCheckTcpHealthCheck {
    /** The TCP port number for the TCP health check request.
  The default value is 443. */
    readonly port?: number;
    /** Port name as defined in InstanceGroup#NamedPort#name. If both port and
  port_name are defined, port takes precedence. */
    readonly portName?: string;
    /** Specifies how port is selected for health checking, can be one of the
  following values:
  
    * 'USE_FIXED_PORT': The port number in 'port' is used for health checking.
  
    * 'USE_NAMED_PORT': The 'portName' is used for health checking.
  
    * 'USE_SERVING_PORT': For NetworkEndpointGroup, the port specified for each
    network endpoint is used for health checking. For other backends, the
    port or named port specified in the Backend Service is used for health
    checking.
  
  If not specified, TCP health check follows behavior specified in 'port' and
  'portName' fields. Possible values: ["USE_FIXED_PORT", "USE_NAMED_PORT", "USE_SERVING_PORT"] */
    readonly portSpecification?: string;
    /** Specifies the type of proxy header to append before sending data to the
  backend. Default value: "NONE" Possible values: ["NONE", "PROXY_V1"] */
    readonly proxyHeader?: string;
    /** The application data to send once the TCP connection has been
  established (default value is empty). If both request and response are
  empty, the connection establishment alone will indicate health. The request
  data can only be ASCII. */
    readonly request?: string;
    /** The bytes to match against the beginning of the response data. If left empty
  (the default value), any response will indicate health. The response data
  can only be ASCII. */
    readonly response?: string;
}
export interface ComputeHealthCheckTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeHealthCheck extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeHealthCheckConfig);
    private _checkIntervalSec?;
    get checkIntervalSec(): number | undefined;
    set checkIntervalSec(value: number | undefined);
    get creationTimestamp(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _healthyThreshold?;
    get healthyThreshold(): number | undefined;
    set healthyThreshold(value: number | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    private _timeoutSec?;
    get timeoutSec(): number | undefined;
    set timeoutSec(value: number | undefined);
    get type(): string;
    private _unhealthyThreshold?;
    get unhealthyThreshold(): number | undefined;
    set unhealthyThreshold(value: number | undefined);
    private _grpcHealthCheck?;
    get grpcHealthCheck(): ComputeHealthCheckGrpcHealthCheck[] | undefined;
    set grpcHealthCheck(value: ComputeHealthCheckGrpcHealthCheck[] | undefined);
    private _http2HealthCheck?;
    get http2HealthCheck(): ComputeHealthCheckHttp2HealthCheck[] | undefined;
    set http2HealthCheck(value: ComputeHealthCheckHttp2HealthCheck[] | undefined);
    private _httpHealthCheck?;
    get httpHealthCheck(): ComputeHealthCheckHttpHealthCheck[] | undefined;
    set httpHealthCheck(value: ComputeHealthCheckHttpHealthCheck[] | undefined);
    private _httpsHealthCheck?;
    get httpsHealthCheck(): ComputeHealthCheckHttpsHealthCheck[] | undefined;
    set httpsHealthCheck(value: ComputeHealthCheckHttpsHealthCheck[] | undefined);
    private _sslHealthCheck?;
    get sslHealthCheck(): ComputeHealthCheckSslHealthCheck[] | undefined;
    set sslHealthCheck(value: ComputeHealthCheckSslHealthCheck[] | undefined);
    private _tcpHealthCheck?;
    get tcpHealthCheck(): ComputeHealthCheckTcpHealthCheck[] | undefined;
    set tcpHealthCheck(value: ComputeHealthCheckTcpHealthCheck[] | undefined);
    private _timeouts?;
    get timeouts(): ComputeHealthCheckTimeouts | undefined;
    set timeouts(value: ComputeHealthCheckTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
