import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeImageConfig extends TerraformMetaArguments {
    /** An optional description of this resource. Provide this property when
  you create the resource. */
    readonly description?: string;
    /** Size of the image when restored onto a persistent disk (in GB). */
    readonly diskSizeGb?: number;
    /** The name of the image family to which this image belongs. You can
  create disks by specifying an image family instead of a specific
  image name. The image family always returns its latest image that is
  not deprecated. The name of the image family must comply with
  RFC1035. */
    readonly family?: string;
    /** Labels to apply to this Image. */
    readonly labels?: {
        [key: string]: string;
    };
    /** Any applicable license URI. */
    readonly licenses?: string[];
    /** Name of the resource; provided by the client when the resource is
  created. The name must be 1-63 characters long, and comply with
  RFC1035. Specifically, the name must be 1-63 characters long and
  match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means
  the first character must be a lowercase letter, and all following
  characters must be a dash, lowercase letter, or digit, except the
  last character, which cannot be a dash. */
    readonly name: string;
    readonly project?: string;
    /** The source disk to create this image based on.
  You must provide either this property or the
  rawDisk.source property but not both to create an image. */
    readonly sourceDisk?: string;
    /** URL of the source image used to create this image. In order to create an image, you must provide the full or partial
  URL of one of the following:
  
  The selfLink URL
  This property
  The rawDisk.source URL
  The sourceDisk URL */
    readonly sourceImage?: string;
    /** URL of the source snapshot used to create this image.
  
  In order to create an image, you must provide the full or partial URL of one of the following:
  
  The selfLink URL
  This property
  The sourceImage URL
  The rawDisk.source URL
  The sourceDisk URL */
    readonly sourceSnapshot?: string;
    /** guest_os_features block */
    readonly guestOsFeatures?: ComputeImageGuestOsFeatures[];
    /** raw_disk block */
    readonly rawDisk?: ComputeImageRawDisk[];
    /** timeouts block */
    readonly timeouts?: ComputeImageTimeouts;
}
export interface ComputeImageGuestOsFeatures {
    /** The type of supported feature. Read [Enabling guest operating system features](https://cloud.google.com/compute/docs/images/create-delete-deprecate-private-images#guest-os-features) to see a list of available options. Possible values: ["MULTI_IP_SUBNET", "SECURE_BOOT", "UEFI_COMPATIBLE", "VIRTIO_SCSI_MULTIQUEUE", "WINDOWS"] */
    readonly type: string;
}
export interface ComputeImageRawDisk {
    /** The format used to encode and transmit the block device, which
  should be TAR. This is just a container and transmission format
  and not a runtime format. Provided by the client when the disk
  image is created. Default value: "TAR" Possible values: ["TAR"] */
    readonly containerType?: string;
    /** An optional SHA1 checksum of the disk image before unpackaging.
  This is provided by the client when the disk image is created. */
    readonly sha1?: string;
    /** The full Google Cloud Storage URL where disk storage is stored
  You must provide either this property or the sourceDisk property
  but not both. */
    readonly source: string;
}
export interface ComputeImageTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeImage extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeImageConfig);
    get archiveSizeBytes(): number;
    get creationTimestamp(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _diskSizeGb?;
    get diskSizeGb(): number | undefined;
    set diskSizeGb(value: number | undefined);
    private _family?;
    get family(): string | undefined;
    set family(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get labelFingerprint(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _licenses?;
    get licenses(): string[] | undefined;
    set licenses(value: string[] | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    private _sourceDisk?;
    get sourceDisk(): string | undefined;
    set sourceDisk(value: string | undefined);
    private _sourceImage?;
    get sourceImage(): string | undefined;
    set sourceImage(value: string | undefined);
    private _sourceSnapshot?;
    get sourceSnapshot(): string | undefined;
    set sourceSnapshot(value: string | undefined);
    private _guestOsFeatures?;
    get guestOsFeatures(): ComputeImageGuestOsFeatures[] | undefined;
    set guestOsFeatures(value: ComputeImageGuestOsFeatures[] | undefined);
    private _rawDisk?;
    get rawDisk(): ComputeImageRawDisk[] | undefined;
    set rawDisk(value: ComputeImageRawDisk[] | undefined);
    private _timeouts?;
    get timeouts(): ComputeImageTimeouts | undefined;
    set timeouts(value: ComputeImageTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
