import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeInstanceGroupManagerConfig extends TerraformMetaArguments {
    /** The base instance name to use for instances in this group. The value must be a valid RFC1035 name. Supported characters are lowercase letters, numbers, and hyphens (-). Instances are named by appending a hyphen and a random four-character string to the base instance name. */
    readonly baseInstanceName: string;
    /** An optional textual description of the instance group manager. */
    readonly description?: string;
    /** The full URL to an instance template from which all new instances of this version will be created. */
    readonly instanceTemplate?: string;
    /** The name of the instance group manager. Must be 1-63 characters long and comply with RFC1035. Supported characters include lowercase letters, numbers, and hyphens. */
    readonly name: string;
    /** The ID of the project in which the resource belongs. If it is not provided, the provider project is used. */
    readonly project?: string;
    /** The full URL of all target pools to which new instances in the group are added. Updating the target pools attribute does not affect existing instances. */
    readonly targetPools?: string[];
    /** The target number of running instances for this managed instance group. This value should always be explicitly set unless this resource is attached to an autoscaler, in which case it should never be set. Defaults to 0. */
    readonly targetSize?: number;
    /** Whether to wait for all instances to be created/updated before returning. Note that if this is set to true and the operation does not succeed, Terraform will continue trying until it times out. */
    readonly waitForInstances?: boolean;
    /** The zone that instances in this group should be created in. */
    readonly zone?: string;
    /** auto_healing_policies block */
    readonly autoHealingPolicies?: ComputeInstanceGroupManagerAutoHealingPolicies[];
    /** named_port block */
    readonly namedPort?: ComputeInstanceGroupManagerNamedPort[];
    /** timeouts block */
    readonly timeouts?: ComputeInstanceGroupManagerTimeouts;
    /** update_policy block */
    readonly updatePolicy?: ComputeInstanceGroupManagerUpdatePolicy[];
    /** version block */
    readonly version: ComputeInstanceGroupManagerVersion[];
}
export interface ComputeInstanceGroupManagerAutoHealingPolicies {
    /** The health check resource that signals autohealing. */
    readonly healthCheck: string;
    /** The number of seconds that the managed instance group waits before it applies autohealing policies to new instances or recently recreated instances. Between 0 and 3600. */
    readonly initialDelaySec: number;
}
export interface ComputeInstanceGroupManagerNamedPort {
    /** The name of the port. */
    readonly name: string;
    /** The port number. */
    readonly port: number;
}
export interface ComputeInstanceGroupManagerTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export interface ComputeInstanceGroupManagerUpdatePolicy {
    /** The maximum number of instances that can be created above the specified targetSize during the update process. Conflicts with max_surge_percent. If neither is set, defaults to 1 */
    readonly maxSurgeFixed?: number;
    /** The maximum number of instances(calculated as percentage) that can be created above the specified targetSize during the update process. Conflicts with max_surge_fixed. */
    readonly maxSurgePercent?: number;
    /** The maximum number of instances that can be unavailable during the update process. Conflicts with max_unavailable_percent. If neither is set, defaults to 1. */
    readonly maxUnavailableFixed?: number;
    /** The maximum number of instances(calculated as percentage) that can be unavailable during the update process. Conflicts with max_unavailable_fixed. */
    readonly maxUnavailablePercent?: number;
    /** Minimum number of seconds to wait for after a newly created instance becomes available. This value must be from range [0, 3600]. */
    readonly minReadySec?: number;
    /** Minimal action to be taken on an instance. You can specify either RESTART to restart existing instances or REPLACE to delete and create new instances from the target template. If you specify a RESTART, the Updater will attempt to perform that action only. However, if the Updater determines that the minimal action you specify is not enough to perform the update, it might perform a more disruptive action. */
    readonly minimalAction: string;
    /** The type of update process. You can specify either PROACTIVE so that the instance group manager proactively executes actions in order to bring instances to their target versions or OPPORTUNISTIC so that no action is proactively executed but the update will be performed as part of other actions (for example, resizes or recreateInstances calls). */
    readonly type: string;
}
export interface ComputeInstanceGroupManagerVersionTargetSize {
    /** The number of instances which are managed for this version. Conflicts with percent. */
    readonly fixed?: number;
    /** The number of instances (calculated as percentage) which are managed for this version. Conflicts with fixed. Note that when using percent, rounding will be in favor of explicitly set target_size values; a managed instance group with 2 instances and 2 versions, one of which has a target_size.percent of 60 will create 2 instances of that version. */
    readonly percent?: number;
}
export interface ComputeInstanceGroupManagerVersion {
    /** The full URL to an instance template from which all new instances of this version will be created. */
    readonly instanceTemplate: string;
    /** Version name. */
    readonly name?: string;
    /** target_size block */
    readonly targetSize?: ComputeInstanceGroupManagerVersionTargetSize[];
}
export declare class ComputeInstanceGroupManager extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeInstanceGroupManagerConfig);
    private _baseInstanceName;
    get baseInstanceName(): string;
    set baseInstanceName(value: string);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    get fingerprint(): string;
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get instanceGroup(): string;
    private _instanceTemplate?;
    get instanceTemplate(): string | undefined;
    set instanceTemplate(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    private _targetPools?;
    get targetPools(): string[] | undefined;
    set targetPools(value: string[] | undefined);
    private _targetSize?;
    get targetSize(): number | undefined;
    set targetSize(value: number | undefined);
    get updateStrategy(): string;
    private _waitForInstances?;
    get waitForInstances(): boolean | undefined;
    set waitForInstances(value: boolean | undefined);
    private _zone?;
    get zone(): string | undefined;
    set zone(value: string | undefined);
    private _autoHealingPolicies?;
    get autoHealingPolicies(): ComputeInstanceGroupManagerAutoHealingPolicies[] | undefined;
    set autoHealingPolicies(value: ComputeInstanceGroupManagerAutoHealingPolicies[] | undefined);
    private _namedPort?;
    get namedPort(): ComputeInstanceGroupManagerNamedPort[] | undefined;
    set namedPort(value: ComputeInstanceGroupManagerNamedPort[] | undefined);
    private _timeouts?;
    get timeouts(): ComputeInstanceGroupManagerTimeouts | undefined;
    set timeouts(value: ComputeInstanceGroupManagerTimeouts | undefined);
    private _updatePolicy?;
    get updatePolicy(): ComputeInstanceGroupManagerUpdatePolicy[] | undefined;
    set updatePolicy(value: ComputeInstanceGroupManagerUpdatePolicy[] | undefined);
    private _version;
    get version(): ComputeInstanceGroupManagerVersion[];
    set version(value: ComputeInstanceGroupManagerVersion[]);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
