import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeInstanceGroupConfig extends TerraformMetaArguments {
    /** An optional textual description of the instance group. */
    readonly description?: string;
    /** List of instances in the group. They should be given as self_link URLs. When adding instances they must all be in the same network and zone as the instance group. */
    readonly instances?: string[];
    /** The name of the instance group. Must be 1-63 characters long and comply with RFC1035. Supported characters include lowercase letters, numbers, and hyphens. */
    readonly name: string;
    /** The URL of the network the instance group is in. If this is different from the network where the instances are in, the creation fails. Defaults to the network where the instances are in (if neither network nor instances is specified, this field will be blank). */
    readonly network?: string;
    /** The ID of the project in which the resource belongs. If it is not provided, the provider project is used. */
    readonly project?: string;
    /** The zone that this instance group should be created in. */
    readonly zone?: string;
    /** named_port block */
    readonly namedPort?: ComputeInstanceGroupNamedPort[];
    /** timeouts block */
    readonly timeouts?: ComputeInstanceGroupTimeouts;
}
export interface ComputeInstanceGroupNamedPort {
    /** The name which the port will be mapped to. */
    readonly name: string;
    /** The port number to map the name to. */
    readonly port: number;
}
export interface ComputeInstanceGroupTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeInstanceGroup extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeInstanceGroupConfig);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _instances?;
    get instances(): string[] | undefined;
    set instances(value: string[] | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _network?;
    get network(): string | undefined;
    set network(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    get size(): number;
    private _zone?;
    get zone(): string | undefined;
    set zone(value: string | undefined);
    private _namedPort?;
    get namedPort(): ComputeInstanceGroupNamedPort[] | undefined;
    set namedPort(value: ComputeInstanceGroupNamedPort[] | undefined);
    private _timeouts?;
    get timeouts(): ComputeInstanceGroupTimeouts | undefined;
    set timeouts(value: ComputeInstanceGroupTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
