import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeInstanceConfig extends TerraformMetaArguments {
    /** If true, allows Terraform to stop the instance to update its properties. If you try to update a property that requires stopping the instance without setting this field, the update will fail. */
    readonly allowStoppingForUpdate?: boolean;
    /** Whether sending and receiving of packets with non-matching source or destination IPs is allowed. */
    readonly canIpForward?: boolean;
    /** Whether deletion protection is enabled on this instance. */
    readonly deletionProtection?: boolean;
    /** A brief description of the resource. */
    readonly description?: string;
    /** Desired status of the instance. Either "RUNNING" or "TERMINATED". */
    readonly desiredStatus?: string;
    /** Whether the instance has virtual displays enabled. */
    readonly enableDisplay?: boolean;
    /** List of the type and count of accelerator cards attached to the instance. */
    readonly guestAccelerator?: ComputeInstanceGuestAccelerator[];
    /** A custom hostname for the instance. Must be a fully qualified DNS name and RFC-1035-valid. Valid format is a series of labels 1-63 characters long matching the regular expression [a-z]([-a-z0-9]*[a-z0-9]), concatenated with periods. The entire hostname must not exceed 253 characters. Changing this forces a new resource to be created. */
    readonly hostname?: string;
    /** A set of key/value label pairs assigned to the instance. */
    readonly labels?: {
        [key: string]: string;
    };
    /** The machine type to create. */
    readonly machineType: string;
    /** Metadata key/value pairs made available within the instance. */
    readonly metadata?: {
        [key: string]: string;
    };
    /** Metadata startup scripts made available within the instance. */
    readonly metadataStartupScript?: string;
    /** The minimum CPU platform specified for the VM instance. */
    readonly minCpuPlatform?: string;
    /** The name of the instance. One of name or self_link must be provided. */
    readonly name: string;
    /** The ID of the project in which the resource belongs. If self_link is provided, this value is ignored. If neither self_link nor project are provided, the provider project is used. */
    readonly project?: string;
    /** A list of short names or self_links of resource policies to attach to the instance. Modifying this list will cause the instance to recreate. Currently a max of 1 resource policy is supported. */
    readonly resourcePolicies?: string[];
    /** The list of tags attached to the instance. */
    readonly tags?: string[];
    /** The zone of the instance. If self_link is provided, this value is ignored. If neither self_link nor zone are provided, the provider zone is used. */
    readonly zone?: string;
    /** attached_disk block */
    readonly attachedDisk?: ComputeInstanceAttachedDisk[];
    /** boot_disk block */
    readonly bootDisk: ComputeInstanceBootDisk[];
    /** network_interface block */
    readonly networkInterface: ComputeInstanceNetworkInterface[];
    /** scheduling block */
    readonly scheduling?: ComputeInstanceScheduling[];
    /** scratch_disk block */
    readonly scratchDisk?: ComputeInstanceScratchDisk[];
    /** service_account block */
    readonly serviceAccount?: ComputeInstanceServiceAccount[];
    /** shielded_instance_config block */
    readonly shieldedInstanceConfig?: ComputeInstanceShieldedInstanceConfig[];
    /** timeouts block */
    readonly timeouts?: ComputeInstanceTimeouts;
}
export interface ComputeInstanceGuestAccelerator {
    readonly count?: number;
    readonly type?: string;
}
export interface ComputeInstanceAttachedDisk {
    /** Name with which the attached disk is accessible under /dev/disk/by-id/ */
    readonly deviceName?: string;
    /** A 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to encrypt this disk. Only one of kms_key_self_link and disk_encryption_key_raw may be set. */
    readonly diskEncryptionKeyRaw?: string;
    /** The self_link of the encryption key that is stored in Google Cloud KMS to encrypt this disk. Only one of kms_key_self_link and disk_encryption_key_raw may be set. */
    readonly kmsKeySelfLink?: string;
    /** Read/write mode for the disk. One of "READ_ONLY" or "READ_WRITE". */
    readonly mode?: string;
    /** The name or self_link of the disk attached to this instance. */
    readonly source: string;
}
export interface ComputeInstanceBootDiskInitializeParams {
    /** The image from which this disk was initialised. */
    readonly image?: string;
    /** A set of key/value label pairs assigned to the disk. */
    readonly labels?: {
        [key: string]: string;
    };
    /** The size of the image in gigabytes. */
    readonly size?: number;
    /** The GCE disk type. One of pd-standard, pd-ssd or pd-balanced. */
    readonly type?: string;
}
export interface ComputeInstanceBootDisk {
    /** Whether the disk will be auto-deleted when the instance is deleted. */
    readonly autoDelete?: boolean;
    /** Name with which attached disk will be accessible under /dev/disk/by-id/ */
    readonly deviceName?: string;
    /** A 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to encrypt this disk. Only one of kms_key_self_link and disk_encryption_key_raw may be set. */
    readonly diskEncryptionKeyRaw?: string;
    /** The self_link of the encryption key that is stored in Google Cloud KMS to encrypt this disk. Only one of kms_key_self_link and disk_encryption_key_raw may be set. */
    readonly kmsKeySelfLink?: string;
    /** Read/write mode for the disk. One of "READ_ONLY" or "READ_WRITE". */
    readonly mode?: string;
    /** The name or self_link of the disk attached to this instance. */
    readonly source?: string;
    /** initialize_params block */
    readonly initializeParams?: ComputeInstanceBootDiskInitializeParams[];
}
export interface ComputeInstanceNetworkInterfaceAccessConfig {
    /** The IP address that is be 1:1 mapped to the instance's network ip. */
    readonly natIp?: string;
    /** The networking tier used for configuring this instance. One of PREMIUM or STANDARD. */
    readonly networkTier?: string;
    /** The DNS domain name for the public PTR record. */
    readonly publicPtrDomainName?: string;
}
export interface ComputeInstanceNetworkInterfaceAliasIpRange {
    /** The IP CIDR range represented by this alias IP range. */
    readonly ipCidrRange: string;
    /** The subnetwork secondary range name specifying the secondary range from which to allocate the IP CIDR range for this alias IP range. */
    readonly subnetworkRangeName?: string;
}
export interface ComputeInstanceNetworkInterface {
    /** The name or self_link of the network attached to this interface. */
    readonly network?: string;
    /** The private IP address assigned to the instance. */
    readonly networkIp?: string;
    /** The name or self_link of the subnetwork attached to this interface. */
    readonly subnetwork?: string;
    /** The project in which the subnetwork belongs. */
    readonly subnetworkProject?: string;
    /** access_config block */
    readonly accessConfig?: ComputeInstanceNetworkInterfaceAccessConfig[];
    /** alias_ip_range block */
    readonly aliasIpRange?: ComputeInstanceNetworkInterfaceAliasIpRange[];
}
export interface ComputeInstanceSchedulingNodeAffinities {
    readonly key: string;
    readonly operator: string;
    readonly values: string[];
}
export interface ComputeInstanceScheduling {
    /** Specifies if the instance should be restarted if it was terminated by Compute Engine (not a user). */
    readonly automaticRestart?: boolean;
    /** Describes maintenance behavior for the instance. One of MIGRATE or TERMINATE, */
    readonly onHostMaintenance?: string;
    /** Whether the instance is preemptible. */
    readonly preemptible?: boolean;
    /** node_affinities block */
    readonly nodeAffinities?: ComputeInstanceSchedulingNodeAffinities[];
}
export interface ComputeInstanceScratchDisk {
    /** The disk interface used for attaching this disk. One of SCSI or NVME. */
    readonly interface: string;
}
export interface ComputeInstanceServiceAccount {
    /** The service account e-mail address. */
    readonly email?: string;
    /** A list of service scopes. */
    readonly scopes: string[];
}
export interface ComputeInstanceShieldedInstanceConfig {
    /** Whether integrity monitoring is enabled for the instance. */
    readonly enableIntegrityMonitoring?: boolean;
    /** Whether secure boot is enabled for the instance. */
    readonly enableSecureBoot?: boolean;
    /** Whether the instance uses vTPM. */
    readonly enableVtpm?: boolean;
}
export interface ComputeInstanceTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeInstance extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeInstanceConfig);
    private _allowStoppingForUpdate?;
    get allowStoppingForUpdate(): boolean | undefined;
    set allowStoppingForUpdate(value: boolean | undefined);
    private _canIpForward?;
    get canIpForward(): boolean | undefined;
    set canIpForward(value: boolean | undefined);
    get cpuPlatform(): string;
    get currentStatus(): string;
    private _deletionProtection?;
    get deletionProtection(): boolean | undefined;
    set deletionProtection(value: boolean | undefined);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _desiredStatus?;
    get desiredStatus(): string | undefined;
    set desiredStatus(value: string | undefined);
    private _enableDisplay?;
    get enableDisplay(): boolean | undefined;
    set enableDisplay(value: boolean | undefined);
    private _guestAccelerator?;
    get guestAccelerator(): ComputeInstanceGuestAccelerator[] | undefined;
    set guestAccelerator(value: ComputeInstanceGuestAccelerator[] | undefined);
    private _hostname?;
    get hostname(): string | undefined;
    set hostname(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get instanceId(): string;
    get labelFingerprint(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _machineType;
    get machineType(): string;
    set machineType(value: string);
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    } | undefined;
    set metadata(value: {
        [key: string]: string;
    } | undefined);
    get metadataFingerprint(): string;
    private _metadataStartupScript?;
    get metadataStartupScript(): string | undefined;
    set metadataStartupScript(value: string | undefined);
    private _minCpuPlatform?;
    get minCpuPlatform(): string | undefined;
    set minCpuPlatform(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _resourcePolicies?;
    get resourcePolicies(): string[] | undefined;
    set resourcePolicies(value: string[] | undefined);
    get selfLink(): string;
    private _tags?;
    get tags(): string[] | undefined;
    set tags(value: string[] | undefined);
    get tagsFingerprint(): string;
    private _zone?;
    get zone(): string | undefined;
    set zone(value: string | undefined);
    private _attachedDisk?;
    get attachedDisk(): ComputeInstanceAttachedDisk[] | undefined;
    set attachedDisk(value: ComputeInstanceAttachedDisk[] | undefined);
    private _bootDisk;
    get bootDisk(): ComputeInstanceBootDisk[];
    set bootDisk(value: ComputeInstanceBootDisk[]);
    private _networkInterface;
    get networkInterface(): ComputeInstanceNetworkInterface[];
    set networkInterface(value: ComputeInstanceNetworkInterface[]);
    private _scheduling?;
    get scheduling(): ComputeInstanceScheduling[] | undefined;
    set scheduling(value: ComputeInstanceScheduling[] | undefined);
    private _scratchDisk?;
    get scratchDisk(): ComputeInstanceScratchDisk[] | undefined;
    set scratchDisk(value: ComputeInstanceScratchDisk[] | undefined);
    private _serviceAccount?;
    get serviceAccount(): ComputeInstanceServiceAccount[] | undefined;
    set serviceAccount(value: ComputeInstanceServiceAccount[] | undefined);
    private _shieldedInstanceConfig?;
    get shieldedInstanceConfig(): ComputeInstanceShieldedInstanceConfig[] | undefined;
    set shieldedInstanceConfig(value: ComputeInstanceShieldedInstanceConfig[] | undefined);
    private _timeouts?;
    get timeouts(): ComputeInstanceTimeouts | undefined;
    set timeouts(value: ComputeInstanceTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
