import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
export interface ComputeInterconnectAttachmentConfig extends TerraformMetaArguments {
    /** Whether the VLAN attachment is enabled or disabled.  When using
  PARTNER type this will Pre-Activate the interconnect attachment */
    readonly adminEnabled?: boolean;
    /** Provisioned bandwidth capacity for the interconnect attachment.
  For attachments of type DEDICATED, the user can set the bandwidth.
  For attachments of type PARTNER, the Google Partner that is operating the interconnect must set the bandwidth.
  Output only for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED,
  Defaults to BPS_10G Possible values: ["BPS_50M", "BPS_100M", "BPS_200M", "BPS_300M", "BPS_400M", "BPS_500M", "BPS_1G", "BPS_2G", "BPS_5G", "BPS_10G", "BPS_20G", "BPS_50G"] */
    readonly bandwidth?: string;
    /** Up to 16 candidate prefixes that can be used to restrict the allocation
  of cloudRouterIpAddress and customerRouterIpAddress for this attachment.
  All prefixes must be within link-local address space (169.254.0.0/16)
  and must be /29 or shorter (/28, /27, etc). Google will attempt to select
  an unused /29 from the supplied candidate prefix(es). The request will
  fail if all possible /29s are in use on Google's edge. If not supplied,
  Google will randomly select an unused /29 from all of link-local space. */
    readonly candidateSubnets?: string[];
    /** An optional description of this resource. */
    readonly description?: string;
    /** Desired availability domain for the attachment. Only available for type
  PARTNER, at creation time. For improved reliability, customers should
  configure a pair of attachments with one per availability domain. The
  selected availability domain will be provided to the Partner via the
  pairing key so that the provisioned circuit will lie in the specified
  domain. If not specified, the value will default to AVAILABILITY_DOMAIN_ANY. */
    readonly edgeAvailabilityDomain?: string;
    /** URL of the underlying Interconnect object that this attachment's
  traffic will traverse through. Required if type is DEDICATED, must not
  be set if type is PARTNER. */
    readonly interconnect?: string;
    /** Name of the resource. Provided by the client when the resource is created. The
  name must be 1-63 characters long, and comply with RFC1035. Specifically, the
  name must be 1-63 characters long and match the regular expression
  '[a-z]([-a-z0-9]*[a-z0-9])?' which means the first character must be a
  lowercase letter, and all following characters must be a dash, lowercase
  letter, or digit, except the last character, which cannot be a dash. */
    readonly name: string;
    readonly project?: string;
    /** Region where the regional interconnect attachment resides. */
    readonly region?: string;
    /** URL of the cloud router to be used for dynamic routing. This router must be in
  the same region as this InterconnectAttachment. The InterconnectAttachment will
  automatically connect the Interconnect to the network & region within which the
  Cloud Router is configured. */
    readonly router: string;
    /** The type of InterconnectAttachment you wish to create. Defaults to
  DEDICATED. Possible values: ["DEDICATED", "PARTNER", "PARTNER_PROVIDER"] */
    readonly type?: string;
    /** The IEEE 802.1Q VLAN tag for this attachment, in the range 2-4094. When
  using PARTNER type this will be managed upstream. */
    readonly vlanTag8021Q?: number;
    /** timeouts block */
    readonly timeouts?: ComputeInterconnectAttachmentTimeouts;
}
export declare class ComputeInterconnectAttachmentPrivateInterconnectInfo extends ComplexComputedList {
    get tag8021Q(): number;
}
export interface ComputeInterconnectAttachmentTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeInterconnectAttachment extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeInterconnectAttachmentConfig);
    private _adminEnabled?;
    get adminEnabled(): boolean | undefined;
    set adminEnabled(value: boolean | undefined);
    private _bandwidth?;
    get bandwidth(): string | undefined;
    set bandwidth(value: string | undefined);
    private _candidateSubnets?;
    get candidateSubnets(): string[] | undefined;
    set candidateSubnets(value: string[] | undefined);
    get cloudRouterIpAddress(): string;
    get creationTimestamp(): string;
    get customerRouterIpAddress(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _edgeAvailabilityDomain?;
    get edgeAvailabilityDomain(): string | undefined;
    set edgeAvailabilityDomain(value: string | undefined);
    get googleReferenceId(): string;
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _interconnect?;
    get interconnect(): string | undefined;
    set interconnect(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    get pairingKey(): string;
    get partnerAsn(): string;
    privateInterconnectInfo(index: string): ComputeInterconnectAttachmentPrivateInterconnectInfo;
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _region?;
    get region(): string | undefined;
    set region(value: string | undefined);
    private _router;
    get router(): string;
    set router(value: string);
    get selfLink(): string;
    get state(): string;
    private _type?;
    get type(): string | undefined;
    set type(value: string | undefined);
    private _vlanTag8021Q?;
    get vlanTag8021Q(): number | undefined;
    set vlanTag8021Q(value: number | undefined);
    private _timeouts?;
    get timeouts(): ComputeInterconnectAttachmentTimeouts | undefined;
    set timeouts(value: ComputeInterconnectAttachmentTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
