import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeNetworkConfig extends TerraformMetaArguments {
    /** When set to 'true', the network is created in "auto subnet mode" and
  it will create a subnet for each region automatically across the
  '10.128.0.0/9' address range.
  
  When set to 'false', the network is created in "custom subnet mode" so
  the user can explicitly connect subnetwork resources. */
    readonly autoCreateSubnetworks?: boolean;
    readonly deleteDefaultRoutesOnCreate?: boolean;
    /** An optional description of this resource. The resource must be
  recreated to modify this field. */
    readonly description?: string;
    /** Name of the resource. Provided by the client when the resource is
  created. The name must be 1-63 characters long, and comply with
  RFC1035. Specifically, the name must be 1-63 characters long and match
  the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
  first character must be a lowercase letter, and all following
  characters must be a dash, lowercase letter, or digit, except the last
  character, which cannot be a dash. */
    readonly name: string;
    readonly project?: string;
    /** The network-wide routing mode to use. If set to 'REGIONAL', this
  network's cloud routers will only advertise routes with subnetworks
  of this network in the same region as the router. If set to 'GLOBAL',
  this network's cloud routers will advertise routes with all
  subnetworks of this network, across regions. Possible values: ["REGIONAL", "GLOBAL"] */
    readonly routingMode?: string;
    /** timeouts block */
    readonly timeouts?: ComputeNetworkTimeouts;
}
export interface ComputeNetworkTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeNetwork extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeNetworkConfig);
    private _autoCreateSubnetworks?;
    get autoCreateSubnetworks(): boolean | undefined;
    set autoCreateSubnetworks(value: boolean | undefined);
    private _deleteDefaultRoutesOnCreate?;
    get deleteDefaultRoutesOnCreate(): boolean | undefined;
    set deleteDefaultRoutesOnCreate(value: boolean | undefined);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    get gatewayIpv4(): string;
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get ipv4Range(): string;
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _routingMode?;
    get routingMode(): string | undefined;
    set routingMode(value: string | undefined);
    get selfLink(): string;
    private _timeouts?;
    get timeouts(): ComputeNetworkTimeouts | undefined;
    set timeouts(value: ComputeNetworkTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
