import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeNodeTemplateConfig extends TerraformMetaArguments {
    /** An optional textual description of the resource. */
    readonly description?: string;
    /** Name of the resource. */
    readonly name?: string;
    /** Labels to use for node affinity, which will be used in
  instance scheduling. */
    readonly nodeAffinityLabels?: {
        [key: string]: string;
    };
    /** Node type to use for nodes group that are created from this template.
  Only one of nodeTypeFlexibility and nodeType can be specified. */
    readonly nodeType?: string;
    readonly project?: string;
    /** Region where nodes using the node template will be created.
  If it is not provided, the provider region is used. */
    readonly region?: string;
    /** node_type_flexibility block */
    readonly nodeTypeFlexibility?: ComputeNodeTemplateNodeTypeFlexibility[];
    /** timeouts block */
    readonly timeouts?: ComputeNodeTemplateTimeouts;
}
export interface ComputeNodeTemplateNodeTypeFlexibility {
    /** Number of virtual CPUs to use. */
    readonly cpus?: string;
    /** Physical memory available to the node, defined in MB. */
    readonly memory?: string;
}
export interface ComputeNodeTemplateTimeouts {
    readonly create?: string;
    readonly delete?: string;
}
export declare class ComputeNodeTemplate extends TerraformResource {
    constructor(scope: Construct, id: string, config?: ComputeNodeTemplateConfig);
    get creationTimestamp(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name?;
    get name(): string | undefined;
    set name(value: string | undefined);
    private _nodeAffinityLabels?;
    get nodeAffinityLabels(): {
        [key: string]: string;
    } | undefined;
    set nodeAffinityLabels(value: {
        [key: string]: string;
    } | undefined);
    private _nodeType?;
    get nodeType(): string | undefined;
    set nodeType(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _region?;
    get region(): string | undefined;
    set region(value: string | undefined);
    get selfLink(): string;
    private _nodeTypeFlexibility?;
    get nodeTypeFlexibility(): ComputeNodeTemplateNodeTypeFlexibility[] | undefined;
    set nodeTypeFlexibility(value: ComputeNodeTemplateNodeTypeFlexibility[] | undefined);
    private _timeouts?;
    get timeouts(): ComputeNodeTemplateTimeouts | undefined;
    set timeouts(value: ComputeNodeTemplateTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
