import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeReservationConfig extends TerraformMetaArguments {
    /** An optional description of this resource. */
    readonly description?: string;
    /** Name of the resource. Provided by the client when the resource is
  created. The name must be 1-63 characters long, and comply with
  RFC1035. Specifically, the name must be 1-63 characters long and match
  the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
  first character must be a lowercase letter, and all following
  characters must be a dash, lowercase letter, or digit, except the last
  character, which cannot be a dash. */
    readonly name: string;
    readonly project?: string;
    /** When set to true, only VMs that target this reservation by name can
  consume this reservation. Otherwise, it can be consumed by VMs with
  affinity for any reservation. Defaults to false. */
    readonly specificReservationRequired?: boolean;
    /** The zone where the reservation is made. */
    readonly zone: string;
    /** specific_reservation block */
    readonly specificReservation: ComputeReservationSpecificReservation[];
    /** timeouts block */
    readonly timeouts?: ComputeReservationTimeouts;
}
export interface ComputeReservationSpecificReservationInstancePropertiesGuestAccelerators {
    /** The number of the guest accelerator cards exposed to
  this instance. */
    readonly acceleratorCount: number;
    /** The full or partial URL of the accelerator type to
  attach to this instance. For example:
  'projects/my-project/zones/us-central1-c/acceleratorTypes/nvidia-tesla-p100'
  
  If you are creating an instance template, specify only the accelerator name. */
    readonly acceleratorType: string;
}
export interface ComputeReservationSpecificReservationInstancePropertiesLocalSsds {
    /** The size of the disk in base-2 GB. */
    readonly diskSizeGb: number;
    /** The disk interface to use for attaching this disk. Default value: "SCSI" Possible values: ["SCSI", "NVME"] */
    readonly interface?: string;
}
export interface ComputeReservationSpecificReservationInstanceProperties {
    /** The name of the machine type to reserve. */
    readonly machineType: string;
    /** The minimum CPU platform for the reservation. For example,
  '"Intel Skylake"'. See
  the CPU platform availability reference](https://cloud.google.com/compute/docs/instances/specify-min-cpu-platform#availablezones)
  for information on available CPU platforms. */
    readonly minCpuPlatform?: string;
    /** guest_accelerators block */
    readonly guestAccelerators?: ComputeReservationSpecificReservationInstancePropertiesGuestAccelerators[];
    /** local_ssds block */
    readonly localSsds?: ComputeReservationSpecificReservationInstancePropertiesLocalSsds[];
}
export interface ComputeReservationSpecificReservation {
    /** The number of resources that are allocated. */
    readonly count: number;
    /** instance_properties block */
    readonly instanceProperties: ComputeReservationSpecificReservationInstanceProperties[];
}
export interface ComputeReservationTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeReservation extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeReservationConfig);
    get commitment(): string;
    get creationTimestamp(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    private _specificReservationRequired?;
    get specificReservationRequired(): boolean | undefined;
    set specificReservationRequired(value: boolean | undefined);
    get status(): string;
    private _zone;
    get zone(): string;
    set zone(value: string);
    private _specificReservation;
    get specificReservation(): ComputeReservationSpecificReservation[];
    set specificReservation(value: ComputeReservationSpecificReservation[]);
    private _timeouts?;
    get timeouts(): ComputeReservationTimeouts | undefined;
    set timeouts(value: ComputeReservationTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
