import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeRouteConfig extends TerraformMetaArguments {
    /** An optional description of this resource. Provide this property
  when you create the resource. */
    readonly description?: string;
    /** The destination range of outgoing packets that this route applies to.
  Only IPv4 is supported. */
    readonly destRange: string;
    /** Name of the resource. Provided by the client when the resource is
  created. The name must be 1-63 characters long, and comply with
  RFC1035.  Specifically, the name must be 1-63 characters long and
  match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means
  the first character must be a lowercase letter, and all following
  characters must be a dash, lowercase letter, or digit, except the
  last character, which cannot be a dash. */
    readonly name: string;
    /** The network that this route applies to. */
    readonly network: string;
    /** URL to a gateway that should handle matching packets.
  Currently, you can only specify the internet gateway, using a full or
  partial valid URL:
  * 'https://www.googleapis.com/compute/v1/projects/project/global/gateways/default-internet-gateway'
  * 'projects/project/global/gateways/default-internet-gateway'
  * 'global/gateways/default-internet-gateway'
  * The string 'default-internet-gateway'. */
    readonly nextHopGateway?: string;
    /** The URL to a forwarding rule of type loadBalancingScheme=INTERNAL that should handle matching packets.
  You can only specify the forwarding rule as a partial or full URL. For example, the following are all valid URLs:
  https://www.googleapis.com/compute/v1/projects/project/regions/region/forwardingRules/forwardingRule
  regions/region/forwardingRules/forwardingRule
  Note that this can only be used when the destinationRange is a public (non-RFC 1918) IP CIDR range. */
    readonly nextHopIlb?: string;
    /** URL to an instance that should handle matching packets.
  You can specify this as a full or partial URL. For example:
  * 'https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/instance'
  * 'projects/project/zones/zone/instances/instance'
  * 'zones/zone/instances/instance'
  * Just the instance name, with the zone in 'next_hop_instance_zone'. */
    readonly nextHopInstance?: string;
    readonly nextHopInstanceZone?: string;
    /** Network IP address of an instance that should handle matching packets. */
    readonly nextHopIp?: string;
    /** URL to a VpnTunnel that should handle matching packets. */
    readonly nextHopVpnTunnel?: string;
    /** The priority of this route. Priority is used to break ties in cases
  where there is more than one matching route of equal prefix length.
  
  In the case of two routes with equal prefix length, the one with the
  lowest-numbered priority value wins.
  
  Default value is 1000. Valid range is 0 through 65535. */
    readonly priority?: number;
    readonly project?: string;
    /** A list of instance tags to which this route applies. */
    readonly tags?: string[];
    /** timeouts block */
    readonly timeouts?: ComputeRouteTimeouts;
}
export interface ComputeRouteTimeouts {
    readonly create?: string;
    readonly delete?: string;
}
export declare class ComputeRoute extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeRouteConfig);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _destRange;
    get destRange(): string;
    set destRange(value: string);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _network;
    get network(): string;
    set network(value: string);
    private _nextHopGateway?;
    get nextHopGateway(): string | undefined;
    set nextHopGateway(value: string | undefined);
    private _nextHopIlb?;
    get nextHopIlb(): string | undefined;
    set nextHopIlb(value: string | undefined);
    private _nextHopInstance?;
    get nextHopInstance(): string | undefined;
    set nextHopInstance(value: string | undefined);
    private _nextHopInstanceZone?;
    get nextHopInstanceZone(): string | undefined;
    set nextHopInstanceZone(value: string | undefined);
    private _nextHopIp?;
    get nextHopIp(): string | undefined;
    set nextHopIp(value: string | undefined);
    get nextHopNetwork(): string;
    private _nextHopVpnTunnel?;
    get nextHopVpnTunnel(): string | undefined;
    set nextHopVpnTunnel(value: string | undefined);
    private _priority?;
    get priority(): number | undefined;
    set priority(value: number | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    private _tags?;
    get tags(): string[] | undefined;
    set tags(value: string[] | undefined);
    private _timeouts?;
    get timeouts(): ComputeRouteTimeouts | undefined;
    set timeouts(value: ComputeRouteTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
