import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeRouterNatConfig extends TerraformMetaArguments {
    /** A list of URLs of the IP resources to be drained. These IPs must be
  valid static external IPs that have been assigned to the NAT. */
    readonly drainNatIps?: string[];
    /** Timeout (in seconds) for ICMP connections. Defaults to 30s if not set. */
    readonly icmpIdleTimeoutSec?: number;
    /** Minimum number of ports allocated to a VM from this NAT. */
    readonly minPortsPerVm?: number;
    /** Name of the NAT service. The name must be 1-63 characters long and
  comply with RFC1035. */
    readonly name: string;
    /** How external IPs should be allocated for this NAT. Valid values are
  'AUTO_ONLY' for only allowing NAT IPs allocated by Google Cloud
  Platform, or 'MANUAL_ONLY' for only user-allocated NAT IP addresses. Possible values: ["MANUAL_ONLY", "AUTO_ONLY"] */
    readonly natIpAllocateOption: string;
    /** Self-links of NAT IPs. Only valid if natIpAllocateOption
  is set to MANUAL_ONLY. */
    readonly natIps?: string[];
    readonly project?: string;
    /** Region where the router and NAT reside. */
    readonly region?: string;
    /** The name of the Cloud Router in which this NAT will be configured. */
    readonly router: string;
    /** How NAT should be configured per Subnetwork.
  If 'ALL_SUBNETWORKS_ALL_IP_RANGES', all of the
  IP ranges in every Subnetwork are allowed to Nat.
  If 'ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES', all of the primary IP
  ranges in every Subnetwork are allowed to Nat.
  'LIST_OF_SUBNETWORKS': A list of Subnetworks are allowed to Nat
  (specified in the field subnetwork below). Note that if this field
  contains ALL_SUBNETWORKS_ALL_IP_RANGES or
  ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES, then there should not be any
  other RouterNat section in any Router for this network in this region. Possible values: ["ALL_SUBNETWORKS_ALL_IP_RANGES", "ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES", "LIST_OF_SUBNETWORKS"] */
    readonly sourceSubnetworkIpRangesToNat: string;
    /** Timeout (in seconds) for TCP established connections.
  Defaults to 1200s if not set. */
    readonly tcpEstablishedIdleTimeoutSec?: number;
    /** Timeout (in seconds) for TCP transitory connections.
  Defaults to 30s if not set. */
    readonly tcpTransitoryIdleTimeoutSec?: number;
    /** Timeout (in seconds) for UDP connections. Defaults to 30s if not set. */
    readonly udpIdleTimeoutSec?: number;
    /** log_config block */
    readonly logConfig?: ComputeRouterNatLogConfig[];
    /** subnetwork block */
    readonly subnetwork?: ComputeRouterNatSubnetwork[];
    /** timeouts block */
    readonly timeouts?: ComputeRouterNatTimeouts;
}
export interface ComputeRouterNatLogConfig {
    /** Indicates whether or not to export logs. */
    readonly enable: boolean;
    /** Specifies the desired filtering of logs on this NAT. Possible values: ["ERRORS_ONLY", "TRANSLATIONS_ONLY", "ALL"] */
    readonly filter: string;
}
export interface ComputeRouterNatSubnetwork {
    /** Self-link of subnetwork to NAT */
    readonly name: string;
    /** List of the secondary ranges of the subnetwork that are allowed
  to use NAT. This can be populated only if
  'LIST_OF_SECONDARY_IP_RANGES' is one of the values in
  sourceIpRangesToNat */
    readonly secondaryIpRangeNames?: string[];
    /** List of options for which source IPs in the subnetwork
  should have NAT enabled. Supported values include:
  'ALL_IP_RANGES', 'LIST_OF_SECONDARY_IP_RANGES',
  'PRIMARY_IP_RANGE'. */
    readonly sourceIpRangesToNat: string[];
}
export interface ComputeRouterNatTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeRouterNat extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeRouterNatConfig);
    private _drainNatIps?;
    get drainNatIps(): string[] | undefined;
    set drainNatIps(value: string[] | undefined);
    private _icmpIdleTimeoutSec?;
    get icmpIdleTimeoutSec(): number | undefined;
    set icmpIdleTimeoutSec(value: number | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _minPortsPerVm?;
    get minPortsPerVm(): number | undefined;
    set minPortsPerVm(value: number | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _natIpAllocateOption;
    get natIpAllocateOption(): string;
    set natIpAllocateOption(value: string);
    private _natIps?;
    get natIps(): string[] | undefined;
    set natIps(value: string[] | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _region?;
    get region(): string | undefined;
    set region(value: string | undefined);
    private _router;
    get router(): string;
    set router(value: string);
    private _sourceSubnetworkIpRangesToNat;
    get sourceSubnetworkIpRangesToNat(): string;
    set sourceSubnetworkIpRangesToNat(value: string);
    private _tcpEstablishedIdleTimeoutSec?;
    get tcpEstablishedIdleTimeoutSec(): number | undefined;
    set tcpEstablishedIdleTimeoutSec(value: number | undefined);
    private _tcpTransitoryIdleTimeoutSec?;
    get tcpTransitoryIdleTimeoutSec(): number | undefined;
    set tcpTransitoryIdleTimeoutSec(value: number | undefined);
    private _udpIdleTimeoutSec?;
    get udpIdleTimeoutSec(): number | undefined;
    set udpIdleTimeoutSec(value: number | undefined);
    private _logConfig?;
    get logConfig(): ComputeRouterNatLogConfig[] | undefined;
    set logConfig(value: ComputeRouterNatLogConfig[] | undefined);
    private _subnetwork?;
    get subnetwork(): ComputeRouterNatSubnetwork[] | undefined;
    set subnetwork(value: ComputeRouterNatSubnetwork[] | undefined);
    private _timeouts?;
    get timeouts(): ComputeRouterNatTimeouts | undefined;
    set timeouts(value: ComputeRouterNatTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
