import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeRouterConfig extends TerraformMetaArguments {
    /** An optional description of this resource. */
    readonly description?: string;
    /** Name of the resource. The name must be 1-63 characters long, and
  comply with RFC1035. Specifically, the name must be 1-63 characters
  long and match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?'
  which means the first character must be a lowercase letter, and all
  following characters must be a dash, lowercase letter, or digit,
  except the last character, which cannot be a dash. */
    readonly name: string;
    /** A reference to the network to which this router belongs. */
    readonly network: string;
    readonly project?: string;
    /** Region where the router resides. */
    readonly region?: string;
    /** bgp block */
    readonly bgp?: ComputeRouterBgp[];
    /** timeouts block */
    readonly timeouts?: ComputeRouterTimeouts;
}
export interface ComputeRouterBgpAdvertisedIpRanges {
    /** User-specified description for the IP range. */
    readonly description?: string;
    /** The IP range to advertise. The value must be a
  CIDR-formatted string. */
    readonly range: string;
}
export interface ComputeRouterBgp {
    /** User-specified flag to indicate which mode to use for advertisement. Default value: "DEFAULT" Possible values: ["DEFAULT", "CUSTOM"] */
    readonly advertiseMode?: string;
    /** User-specified list of prefix groups to advertise in custom mode.
  This field can only be populated if advertiseMode is CUSTOM and
  is advertised to all peers of the router. These groups will be
  advertised in addition to any specified prefixes. Leave this field
  blank to advertise no custom groups.
  
  This enum field has the one valid value: ALL_SUBNETS */
    readonly advertisedGroups?: string[];
    /** Local BGP Autonomous System Number (ASN). Must be an RFC6996
  private ASN, either 16-bit or 32-bit. The value will be fixed for
  this router resource. All VPN tunnels that link to this router
  will have the same local ASN. */
    readonly asn: number;
    /** advertised_ip_ranges block */
    readonly advertisedIpRanges?: ComputeRouterBgpAdvertisedIpRanges[];
}
export interface ComputeRouterTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeRouter extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeRouterConfig);
    get creationTimestamp(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _network;
    get network(): string;
    set network(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _region?;
    get region(): string | undefined;
    set region(value: string | undefined);
    get selfLink(): string;
    private _bgp?;
    get bgp(): ComputeRouterBgp[] | undefined;
    set bgp(value: ComputeRouterBgp[] | undefined);
    private _timeouts?;
    get timeouts(): ComputeRouterTimeouts | undefined;
    set timeouts(value: ComputeRouterTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
