import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeSecurityPolicyConfig extends TerraformMetaArguments {
    /** An optional description of this security policy. Max size is 2048. */
    readonly description?: string;
    /** The name of the security policy. */
    readonly name: string;
    /** The project in which the resource belongs. If it is not provided, the provider project is used. */
    readonly project?: string;
    /** rule block */
    readonly rule?: ComputeSecurityPolicyRule[];
    /** timeouts block */
    readonly timeouts?: ComputeSecurityPolicyTimeouts;
}
export interface ComputeSecurityPolicyRuleMatchConfig {
    /** Set of IP addresses or ranges (IPV4 or IPV6) in CIDR notation to match against inbound traffic. There is a limit of 10 IP ranges per rule. A value of '*' matches all IPs (can be used to override the default behavior). */
    readonly srcIpRanges: string[];
}
export interface ComputeSecurityPolicyRuleMatchExpr {
    /** Textual representation of an expression in Common Expression Language syntax. The application context of the containing message determines which well-known feature set of CEL is supported. */
    readonly expression: string;
}
export interface ComputeSecurityPolicyRuleMatch {
    /** Predefined rule expression. If this field is specified, config must also be specified. Available options:   SRC_IPS_V1: Must specify the corresponding src_ip_ranges field in config. */
    readonly versionedExpr?: string;
    /** config block */
    readonly config?: ComputeSecurityPolicyRuleMatchConfig[];
    /** expr block */
    readonly expr?: ComputeSecurityPolicyRuleMatchExpr[];
}
export interface ComputeSecurityPolicyRule {
    /** Action to take when match matches the request. Valid values:   "allow" : allow access to target, "deny(status)" : deny access to target, returns the HTTP response code specified (valid values are 403, 404 and 502) */
    readonly action: string;
    /** An optional description of this rule. Max size is 64. */
    readonly description?: string;
    /** When set to true, the action specified above is not enforced. Stackdriver logs for requests that trigger a preview action are annotated as such. */
    readonly preview?: boolean;
    /** An unique positive integer indicating the priority of evaluation for a rule. Rules are evaluated from highest priority (lowest numerically) to lowest priority (highest numerically) in order. */
    readonly priority: number;
    /** match block */
    readonly match: ComputeSecurityPolicyRuleMatch[];
}
export interface ComputeSecurityPolicyTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeSecurityPolicy extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeSecurityPolicyConfig);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    get fingerprint(): string;
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    private _rule?;
    get rule(): ComputeSecurityPolicyRule[] | undefined;
    set rule(value: ComputeSecurityPolicyRule[] | undefined);
    private _timeouts?;
    get timeouts(): ComputeSecurityPolicyTimeouts | undefined;
    set timeouts(value: ComputeSecurityPolicyTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
