import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeSnapshotConfig extends TerraformMetaArguments {
    /** An optional description of this resource. */
    readonly description?: string;
    /** Labels to apply to this Snapshot. */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the resource; provided by the client when the resource is
  created. The name must be 1-63 characters long, and comply with
  RFC1035. Specifically, the name must be 1-63 characters long and match
  the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
  first character must be a lowercase letter, and all following
  characters must be a dash, lowercase letter, or digit, except the last
  character, which cannot be a dash. */
    readonly name: string;
    readonly project?: string;
    /** A reference to the disk used to create this snapshot. */
    readonly sourceDisk: string;
    /** A reference to the zone where the disk is hosted. */
    readonly zone?: string;
    /** snapshot_encryption_key block */
    readonly snapshotEncryptionKey?: ComputeSnapshotSnapshotEncryptionKey[];
    /** source_disk_encryption_key block */
    readonly sourceDiskEncryptionKey?: ComputeSnapshotSourceDiskEncryptionKey[];
    /** timeouts block */
    readonly timeouts?: ComputeSnapshotTimeouts;
}
export interface ComputeSnapshotSnapshotEncryptionKey {
    /** Specifies a 256-bit customer-supplied encryption key, encoded in
  RFC 4648 base64 to either encrypt or decrypt this resource. */
    readonly rawKey: string;
}
export interface ComputeSnapshotSourceDiskEncryptionKey {
    /** Specifies a 256-bit customer-supplied encryption key, encoded in
  RFC 4648 base64 to either encrypt or decrypt this resource. */
    readonly rawKey?: string;
}
export interface ComputeSnapshotTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeSnapshot extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeSnapshotConfig);
    get creationTimestamp(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    get diskSizeGb(): number;
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get labelFingerprint(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    get licenses(): string[];
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    get snapshotId(): number;
    private _sourceDisk;
    get sourceDisk(): string;
    set sourceDisk(value: string);
    get sourceDiskLink(): string;
    get storageBytes(): number;
    private _zone?;
    get zone(): string | undefined;
    set zone(value: string | undefined);
    private _snapshotEncryptionKey?;
    get snapshotEncryptionKey(): ComputeSnapshotSnapshotEncryptionKey[] | undefined;
    set snapshotEncryptionKey(value: ComputeSnapshotSnapshotEncryptionKey[] | undefined);
    private _sourceDiskEncryptionKey?;
    get sourceDiskEncryptionKey(): ComputeSnapshotSourceDiskEncryptionKey[] | undefined;
    set sourceDiskEncryptionKey(value: ComputeSnapshotSourceDiskEncryptionKey[] | undefined);
    private _timeouts?;
    get timeouts(): ComputeSnapshotTimeouts | undefined;
    set timeouts(value: ComputeSnapshotTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
