import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeSslPolicyConfig extends TerraformMetaArguments {
    /** Profile specifies the set of SSL features that can be used by the
  load balancer when negotiating SSL with clients. This can be one of
  'COMPATIBLE', 'MODERN', 'RESTRICTED', or 'CUSTOM'. If using 'CUSTOM',
  the set of SSL features to enable must be specified in the
  'customFeatures' field.
  
  See the [official documentation](https://cloud.google.com/compute/docs/load-balancing/ssl-policies#profilefeaturesupport)
  for which ciphers are available to use. **Note**: this argument
  *must* be present when using the 'CUSTOM' profile. This argument
  *must not* be present when using any other profile. */
    readonly customFeatures?: string[];
    /** An optional description of this resource. */
    readonly description?: string;
    /** The minimum version of SSL protocol that can be used by the clients
  to establish a connection with the load balancer. Default value: "TLS_1_0" Possible values: ["TLS_1_0", "TLS_1_1", "TLS_1_2"] */
    readonly minTlsVersion?: string;
    /** Name of the resource. Provided by the client when the resource is
  created. The name must be 1-63 characters long, and comply with
  RFC1035. Specifically, the name must be 1-63 characters long and match
  the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
  first character must be a lowercase letter, and all following
  characters must be a dash, lowercase letter, or digit, except the last
  character, which cannot be a dash. */
    readonly name: string;
    /** Profile specifies the set of SSL features that can be used by the
  load balancer when negotiating SSL with clients. If using 'CUSTOM',
  the set of SSL features to enable must be specified in the
  'customFeatures' field.
  
  See the [official documentation](https://cloud.google.com/compute/docs/load-balancing/ssl-policies#profilefeaturesupport)
  for information on what cipher suites each profile provides. If
  'CUSTOM' is used, the 'custom_features' attribute **must be set**. Default value: "COMPATIBLE" Possible values: ["COMPATIBLE", "MODERN", "RESTRICTED", "CUSTOM"] */
    readonly profile?: string;
    readonly project?: string;
    /** timeouts block */
    readonly timeouts?: ComputeSslPolicyTimeouts;
}
export interface ComputeSslPolicyTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeSslPolicy extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeSslPolicyConfig);
    get creationTimestamp(): string;
    private _customFeatures?;
    get customFeatures(): string[] | undefined;
    set customFeatures(value: string[] | undefined);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    get enabledFeatures(): string[];
    get fingerprint(): string;
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _minTlsVersion?;
    get minTlsVersion(): string | undefined;
    set minTlsVersion(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _profile?;
    get profile(): string | undefined;
    set profile(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    private _timeouts?;
    get timeouts(): ComputeSslPolicyTimeouts | undefined;
    set timeouts(value: ComputeSslPolicyTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
