import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeTargetHttpsProxyConfig extends TerraformMetaArguments {
    /** An optional description of this resource. */
    readonly description?: string;
    /** Name of the resource. Provided by the client when the resource is
  created. The name must be 1-63 characters long, and comply with
  RFC1035. Specifically, the name must be 1-63 characters long and match
  the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
  first character must be a lowercase letter, and all following
  characters must be a dash, lowercase letter, or digit, except the last
  character, which cannot be a dash. */
    readonly name: string;
    readonly project?: string;
    /** Specifies the QUIC override policy for this resource. This determines
  whether the load balancer will attempt to negotiate QUIC with clients
  or not. Can specify one of NONE, ENABLE, or DISABLE. If NONE is
  specified, uses the QUIC policy with no user overrides, which is
  equivalent to DISABLE. Default value: "NONE" Possible values: ["NONE", "ENABLE", "DISABLE"] */
    readonly quicOverride?: string;
    /** A list of SslCertificate resources that are used to authenticate
  connections between users and the load balancer. At least one SSL
  certificate must be specified. */
    readonly sslCertificates: string[];
    /** A reference to the SslPolicy resource that will be associated with
  the TargetHttpsProxy resource. If not set, the TargetHttpsProxy
  resource will not have any SSL policy configured. */
    readonly sslPolicy?: string;
    /** A reference to the UrlMap resource that defines the mapping from URL
  to the BackendService. */
    readonly urlMap: string;
    /** timeouts block */
    readonly timeouts?: ComputeTargetHttpsProxyTimeouts;
}
export interface ComputeTargetHttpsProxyTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeTargetHttpsProxy extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeTargetHttpsProxyConfig);
    get creationTimestamp(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get proxyId(): number;
    private _quicOverride?;
    get quicOverride(): string | undefined;
    set quicOverride(value: string | undefined);
    get selfLink(): string;
    private _sslCertificates;
    get sslCertificates(): string[];
    set sslCertificates(value: string[]);
    private _sslPolicy?;
    get sslPolicy(): string | undefined;
    set sslPolicy(value: string | undefined);
    private _urlMap;
    get urlMap(): string;
    set urlMap(value: string);
    private _timeouts?;
    get timeouts(): ComputeTargetHttpsProxyTimeouts | undefined;
    set timeouts(value: ComputeTargetHttpsProxyTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
