import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeTargetInstanceConfig extends TerraformMetaArguments {
    /** An optional description of this resource. */
    readonly description?: string;
    /** The Compute instance VM handling traffic for this target instance.
  Accepts the instance self-link, relative path
  (e.g. 'projects/project/zones/zone/instances/instance') or name. If
  name is given, the zone will default to the given zone or
  the provider-default zone and the project will default to the
  provider-level project. */
    readonly instance: string;
    /** Name of the resource. Provided by the client when the resource is
  created. The name must be 1-63 characters long, and comply with
  RFC1035. Specifically, the name must be 1-63 characters long and match
  the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
  first character must be a lowercase letter, and all following
  characters must be a dash, lowercase letter, or digit, except the last
  character, which cannot be a dash. */
    readonly name: string;
    /** NAT option controlling how IPs are NAT'ed to the instance.
  Currently only NO_NAT (default value) is supported. Default value: "NO_NAT" Possible values: ["NO_NAT"] */
    readonly natPolicy?: string;
    readonly project?: string;
    /** URL of the zone where the target instance resides. */
    readonly zone?: string;
    /** timeouts block */
    readonly timeouts?: ComputeTargetInstanceTimeouts;
}
export interface ComputeTargetInstanceTimeouts {
    readonly create?: string;
    readonly delete?: string;
}
export declare class ComputeTargetInstance extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeTargetInstanceConfig);
    get creationTimestamp(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _instance;
    get instance(): string;
    set instance(value: string);
    private _name;
    get name(): string;
    set name(value: string);
    private _natPolicy?;
    get natPolicy(): string | undefined;
    set natPolicy(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    private _zone?;
    get zone(): string | undefined;
    set zone(value: string | undefined);
    private _timeouts?;
    get timeouts(): ComputeTargetInstanceTimeouts | undefined;
    set timeouts(value: ComputeTargetInstanceTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
