import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ComputeTargetPoolConfig extends TerraformMetaArguments {
    /** URL to the backup target pool. Must also set failover_ratio. */
    readonly backupPool?: string;
    /** Textual description field. */
    readonly description?: string;
    /** Ratio (0 to 1) of failed nodes before using the backup pool (which must also be set). */
    readonly failoverRatio?: number;
    /** List of zero or one health check name or self_link. Only legacy google_compute_http_health_check is supported. */
    readonly healthChecks?: string[];
    /** List of instances in the pool. They can be given as URLs, or in the form of "zone/name". Note that the instances need not exist at the time of target pool creation, so there is no need to use the Terraform interpolators to create a dependency on the instances from the target pool. */
    readonly instances?: string[];
    /** A unique name for the resource, required by GCE. Changing this forces a new resource to be created. */
    readonly name: string;
    /** The ID of the project in which the resource belongs. If it is not provided, the provider project is used. */
    readonly project?: string;
    /** Where the target pool resides. Defaults to project region. */
    readonly region?: string;
    /** How to distribute load. Options are "NONE" (no affinity). "CLIENT_IP" (hash of the source/dest addresses / ports), and "CLIENT_IP_PROTO" also includes the protocol (default "NONE"). */
    readonly sessionAffinity?: string;
    /** timeouts block */
    readonly timeouts?: ComputeTargetPoolTimeouts;
}
export interface ComputeTargetPoolTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class ComputeTargetPool extends TerraformResource {
    constructor(scope: Construct, id: string, config: ComputeTargetPoolConfig);
    private _backupPool?;
    get backupPool(): string | undefined;
    set backupPool(value: string | undefined);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _failoverRatio?;
    get failoverRatio(): number | undefined;
    set failoverRatio(value: number | undefined);
    private _healthChecks?;
    get healthChecks(): string[] | undefined;
    set healthChecks(value: string[] | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _instances?;
    get instances(): string[] | undefined;
    set instances(value: string[] | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _region?;
    get region(): string | undefined;
    set region(value: string | undefined);
    get selfLink(): string;
    private _sessionAffinity?;
    get sessionAffinity(): string | undefined;
    set sessionAffinity(value: string | undefined);
    private _timeouts?;
    get timeouts(): ComputeTargetPoolTimeouts | undefined;
    set timeouts(value: ComputeTargetPoolTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
