import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ContainerNodePoolConfig extends TerraformMetaArguments {
    /** The cluster to create the node pool for. Cluster must be present in location provided for zonal clusters. */
    readonly cluster: string;
    /** The initial number of nodes for the pool. In regional or multi-zonal clusters, this is the number of nodes per zone. Changing this will force recreation of the resource. */
    readonly initialNodeCount?: number;
    /** The location (region or zone) of the cluster. */
    readonly location?: string;
    /** The maximum number of pods per node in this node pool. Note that this does not work on node pools which are "route-based" - that is, node pools belonging to clusters that do not have IP Aliasing enabled. */
    readonly maxPodsPerNode?: number;
    /** The name of the node pool. If left blank, Terraform will auto-generate a unique name. */
    readonly name?: string;
    /** Creates a unique name for the node pool beginning with the specified prefix. Conflicts with name. */
    readonly namePrefix?: string;
    /** The number of nodes per instance group. This field can be used to update the number of nodes per instance group but should not be used alongside autoscaling. */
    readonly nodeCount?: number;
    /** The list of zones in which the node pool's nodes should be located. Nodes must be in the region of their regional cluster or in the same region as their cluster's zone for zonal clusters. If unspecified, the cluster-level node_locations will be used. */
    readonly nodeLocations?: string[];
    /** The ID of the project in which to create the node pool. If blank, the provider-configured project will be used. */
    readonly project?: string;
    /** The region of the cluster */
    readonly region?: string;
    /** The Kubernetes version for the nodes in this pool. Note that if this field and auto_upgrade are both specified, they will fight each other for what the node version should be, so setting both is highly discouraged. While a fuzzy version can be specified, it's recommended that you specify explicit versions as Terraform will see spurious diffs when fuzzy versions are used. See the google_container_engine_versions data source's version_prefix field to approximate fuzzy versions in a Terraform-compatible way. */
    readonly version?: string;
    /** The zone of the cluster */
    readonly zone?: string;
    /** autoscaling block */
    readonly autoscaling?: ContainerNodePoolAutoscaling[];
    /** management block */
    readonly management?: ContainerNodePoolManagement[];
    /** node_config block */
    readonly nodeConfig?: ContainerNodePoolNodeConfig[];
    /** timeouts block */
    readonly timeouts?: ContainerNodePoolTimeouts;
    /** upgrade_settings block */
    readonly upgradeSettings?: ContainerNodePoolUpgradeSettings[];
}
export interface ContainerNodePoolAutoscaling {
    /** Maximum number of nodes in the NodePool. Must be >= min_node_count. */
    readonly maxNodeCount: number;
    /** Minimum number of nodes in the NodePool. Must be >=0 and <= max_node_count. */
    readonly minNodeCount: number;
}
export interface ContainerNodePoolManagement {
    /** Whether the nodes will be automatically repaired. */
    readonly autoRepair?: boolean;
    /** Whether the nodes will be automatically upgraded. */
    readonly autoUpgrade?: boolean;
}
export interface ContainerNodePoolNodeConfigGuestAccelerator {
    readonly count?: number;
    readonly type?: string;
}
export interface ContainerNodePoolNodeConfigTaint {
    readonly effect?: string;
    readonly key?: string;
    readonly value?: string;
}
export interface ContainerNodePoolNodeConfigSandboxConfig {
    readonly sandboxType: string;
}
export interface ContainerNodePoolNodeConfigShieldedInstanceConfig {
    readonly enableIntegrityMonitoring?: boolean;
    readonly enableSecureBoot?: boolean;
}
export interface ContainerNodePoolNodeConfigWorkloadMetadataConfig {
    readonly nodeMetadata: string;
}
export interface ContainerNodePoolNodeConfig {
    readonly diskSizeGb?: number;
    readonly diskType?: string;
    readonly guestAccelerator?: ContainerNodePoolNodeConfigGuestAccelerator[];
    readonly imageType?: string;
    readonly labels?: {
        [key: string]: string;
    };
    readonly localSsdCount?: number;
    readonly machineType?: string;
    readonly metadata?: {
        [key: string]: string;
    };
    readonly minCpuPlatform?: string;
    readonly oauthScopes?: string[];
    readonly preemptible?: boolean;
    readonly serviceAccount?: string;
    readonly tags?: string[];
    readonly taint?: ContainerNodePoolNodeConfigTaint[];
    /** sandbox_config block */
    readonly sandboxConfig?: ContainerNodePoolNodeConfigSandboxConfig[];
    /** shielded_instance_config block */
    readonly shieldedInstanceConfig?: ContainerNodePoolNodeConfigShieldedInstanceConfig[];
    /** workload_metadata_config block */
    readonly workloadMetadataConfig?: ContainerNodePoolNodeConfigWorkloadMetadataConfig[];
}
export interface ContainerNodePoolTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export interface ContainerNodePoolUpgradeSettings {
    /** The number of additional nodes that can be added to the node pool during an upgrade. Increasing max_surge raises the number of nodes that can be upgraded simultaneously. Can be set to 0 or greater. */
    readonly maxSurge: number;
    /** The number of nodes that can be simultaneously unavailable during an upgrade. Increasing max_unavailable raises the number of nodes that can be upgraded in parallel. Can be set to 0 or greater. */
    readonly maxUnavailable: number;
}
export declare class ContainerNodePool extends TerraformResource {
    constructor(scope: Construct, id: string, config: ContainerNodePoolConfig);
    private _cluster;
    get cluster(): string;
    set cluster(value: string);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _initialNodeCount?;
    get initialNodeCount(): number | undefined;
    set initialNodeCount(value: number | undefined);
    get instanceGroupUrls(): string[];
    private _location?;
    get location(): string | undefined;
    set location(value: string | undefined);
    private _maxPodsPerNode?;
    get maxPodsPerNode(): number | undefined;
    set maxPodsPerNode(value: number | undefined);
    private _name?;
    get name(): string | undefined;
    set name(value: string | undefined);
    private _namePrefix?;
    get namePrefix(): string | undefined;
    set namePrefix(value: string | undefined);
    private _nodeCount?;
    get nodeCount(): number | undefined;
    set nodeCount(value: number | undefined);
    private _nodeLocations?;
    get nodeLocations(): string[] | undefined;
    set nodeLocations(value: string[] | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _region?;
    get region(): string | undefined;
    set region(value: string | undefined);
    private _version?;
    get version(): string | undefined;
    set version(value: string | undefined);
    private _zone?;
    get zone(): string | undefined;
    set zone(value: string | undefined);
    private _autoscaling?;
    get autoscaling(): ContainerNodePoolAutoscaling[] | undefined;
    set autoscaling(value: ContainerNodePoolAutoscaling[] | undefined);
    private _management?;
    get management(): ContainerNodePoolManagement[] | undefined;
    set management(value: ContainerNodePoolManagement[] | undefined);
    private _nodeConfig?;
    get nodeConfig(): ContainerNodePoolNodeConfig[] | undefined;
    set nodeConfig(value: ContainerNodePoolNodeConfig[] | undefined);
    private _timeouts?;
    get timeouts(): ContainerNodePoolTimeouts | undefined;
    set timeouts(value: ContainerNodePoolTimeouts | undefined);
    private _upgradeSettings?;
    get upgradeSettings(): ContainerNodePoolUpgradeSettings[] | undefined;
    set upgradeSettings(value: ContainerNodePoolUpgradeSettings[] | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
