import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
export interface DataCatalogEntryConfig extends TerraformMetaArguments {
    /** Entry description, which can consist of several sentences or paragraphs that describe entry contents. */
    readonly description?: string;
    /** Display information such as title and description. A short name to identify the entry,
  for example, "Analytics Data - Jan 2011". */
    readonly displayName?: string;
    /** The name of the entry group this entry is in. */
    readonly entryGroup: string;
    /** The id of the entry to create. */
    readonly entryId: string;
    /** The resource this metadata entry refers to.
  For Google Cloud Platform resources, linkedResource is the full name of the resource.
  For example, the linkedResource for a table resource from BigQuery is:
  //bigquery.googleapis.com/projects/projectId/datasets/datasetId/tables/tableId
  Output only when Entry is of type in the EntryType enum. For entries with userSpecifiedType,
  this field is optional and defaults to an empty string. */
    readonly linkedResource?: string;
    /** Schema of the entry (e.g. BigQuery, GoogleSQL, Avro schema), as a json string. An entry might not have any schema
  attached to it. See
  https://cloud.google.com/data-catalog/docs/reference/rest/v1/projects.locations.entryGroups.entries#schema
  for what fields this schema can contain. */
    readonly schema?: string;
    /** The type of the entry. Only used for Entries with types in the EntryType enum.
  Currently, only FILESET enum value is allowed. All other entries created through Data Catalog must use userSpecifiedType. Possible values: ["FILESET"] */
    readonly type?: string;
    /** This field indicates the entry's source system that Data Catalog does not integrate with.
  userSpecifiedSystem strings must begin with a letter or underscore and can only contain letters, numbers,
  and underscores; are case insensitive; must be at least 1 character and at most 64 characters long. */
    readonly userSpecifiedSystem?: string;
    /** Entry type if it does not fit any of the input-allowed values listed in EntryType enum above.
  When creating an entry, users should check the enum values first, if nothing matches the entry
  to be created, then provide a custom value, for example "my_special_type".
  userSpecifiedType strings must begin with a letter or underscore and can only contain letters,
  numbers, and underscores; are case insensitive; must be at least 1 character and at most 64 characters long. */
    readonly userSpecifiedType?: string;
    /** gcs_fileset_spec block */
    readonly gcsFilesetSpec?: DataCatalogEntryGcsFilesetSpec[];
    /** timeouts block */
    readonly timeouts?: DataCatalogEntryTimeouts;
}
export declare class DataCatalogEntryBigqueryDateShardedSpec extends ComplexComputedList {
    get dataset(): string;
    get shardCount(): number;
    get tablePrefix(): string;
}
export declare class DataCatalogEntryBigqueryTableSpecTableSpec extends ComplexComputedList {
    get groupedEntry(): string;
}
export declare class DataCatalogEntryBigqueryTableSpecViewSpec extends ComplexComputedList {
    get viewQuery(): string;
}
export declare class DataCatalogEntryBigqueryTableSpec extends ComplexComputedList {
    get tableSourceType(): string;
    get tableSpec(): any;
    get viewSpec(): any;
}
export interface DataCatalogEntryGcsFilesetSpec {
    /** Patterns to identify a set of files in Google Cloud Storage.
  See [Cloud Storage documentation](https://cloud.google.com/storage/docs/gsutil/addlhelp/WildcardNames)
  for more information. Note that bucket wildcards are currently not supported. Examples of valid filePatterns:
  
  * gs://bucket_name/dir/*: matches all files within bucket_name/dir directory.
  * gs://bucket_name/dir/**: matches all files in bucket_name/dir spanning all subdirectories.
  * gs://bucket_name/file*: matches files prefixed by file in bucket_name
  * gs://bucket_name/??.txt: matches files with two characters followed by .txt in bucket_name
  * gs://bucket_name/[aeiou].txt: matches files that contain a single vowel character followed by .txt in bucket_name
  * gs://bucket_name/[a-m].txt: matches files that contain a, b, ... or m followed by .txt in bucket_name
  * gs://bucket_name/a/*\/b: matches all files in bucket_name that match a/*\/b pattern, such as a/c/b, a/d/b
  * gs://another_bucket/a.txt: matches gs://another_bucket/a.txt */
    readonly filePatterns: string[];
}
export interface DataCatalogEntryTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class DataCatalogEntry extends TerraformResource {
    constructor(scope: Construct, id: string, config: DataCatalogEntryConfig);
    bigqueryDateShardedSpec(index: string): DataCatalogEntryBigqueryDateShardedSpec;
    bigqueryTableSpec(index: string): DataCatalogEntryBigqueryTableSpec;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _displayName?;
    get displayName(): string | undefined;
    set displayName(value: string | undefined);
    private _entryGroup;
    get entryGroup(): string;
    set entryGroup(value: string);
    private _entryId;
    get entryId(): string;
    set entryId(value: string);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get integratedSystem(): string;
    private _linkedResource?;
    get linkedResource(): string | undefined;
    set linkedResource(value: string | undefined);
    get name(): string;
    private _schema?;
    get schema(): string | undefined;
    set schema(value: string | undefined);
    private _type?;
    get type(): string | undefined;
    set type(value: string | undefined);
    private _userSpecifiedSystem?;
    get userSpecifiedSystem(): string | undefined;
    set userSpecifiedSystem(value: string | undefined);
    private _userSpecifiedType?;
    get userSpecifiedType(): string | undefined;
    set userSpecifiedType(value: string | undefined);
    private _gcsFilesetSpec?;
    get gcsFilesetSpec(): DataCatalogEntryGcsFilesetSpec[] | undefined;
    set gcsFilesetSpec(value: DataCatalogEntryGcsFilesetSpec[] | undefined);
    private _timeouts?;
    get timeouts(): DataCatalogEntryTimeouts | undefined;
    set timeouts(value: DataCatalogEntryTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
