import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface DataCatalogTagConfig extends TerraformMetaArguments {
    /** Resources like Entry can have schemas associated with them. This scope allows users to attach tags to an
  individual column based on that schema.
  
  For attaching a tag to a nested column, use '.' to separate the column names. Example:
  'outer_column.inner_column' */
    readonly column?: string;
    /** The name of the parent this tag is attached to. This can be the name of an entry or an entry group. If an entry group, the tag will be attached to
  all entries in that group. */
    readonly parent?: string;
    /** The resource name of the tag template that this tag uses. Example:
  projects/{project_id}/locations/{location}/tagTemplates/{tagTemplateId}
  This field cannot be modified after creation. */
    readonly template: string;
    /** fields block */
    readonly fields: DataCatalogTagFields[];
    /** timeouts block */
    readonly timeouts?: DataCatalogTagTimeouts;
}
export interface DataCatalogTagFields {
    /** Holds the value for a tag field with boolean type. */
    readonly boolValue?: boolean;
    /** Holds the value for a tag field with double type. */
    readonly doubleValue?: number;
    /** The display name of the enum value. */
    readonly enumValue?: string;
    readonly fieldName: string;
    /** Holds the value for a tag field with string type. */
    readonly stringValue?: string;
    /** Holds the value for a tag field with timestamp type. */
    readonly timestampValue?: string;
}
export interface DataCatalogTagTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class DataCatalogTag extends TerraformResource {
    constructor(scope: Construct, id: string, config: DataCatalogTagConfig);
    private _column?;
    get column(): string | undefined;
    set column(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get name(): string;
    private _parent?;
    get parent(): string | undefined;
    set parent(value: string | undefined);
    private _template;
    get template(): string;
    set template(value: string);
    get templateDisplayname(): string;
    private _fields;
    get fields(): DataCatalogTagFields[];
    set fields(value: DataCatalogTagFields[]);
    private _timeouts?;
    get timeouts(): DataCatalogTagTimeouts | undefined;
    set timeouts(value: DataCatalogTagTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
