import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
export interface DataprocJobConfig extends TerraformMetaArguments {
    /** By default, you can only delete inactive jobs within Dataproc. Setting this to true, and calling destroy, will ensure that the job is first cancelled before issuing the delete. */
    readonly forceDelete?: boolean;
    /** Optional. The labels to associate with this job. */
    readonly labels?: {
        [key: string]: string;
    };
    /** The project in which the cluster can be found and jobs subsequently run against. If it is not provided, the provider project is used. */
    readonly project?: string;
    /** The Cloud Dataproc region. This essentially determines which clusters are available for this job to be submitted to. If not specified, defaults to global. */
    readonly region?: string;
    /** hadoop_config block */
    readonly hadoopConfig?: DataprocJobHadoopConfig[];
    /** hive_config block */
    readonly hiveConfig?: DataprocJobHiveConfig[];
    /** pig_config block */
    readonly pigConfig?: DataprocJobPigConfig[];
    /** placement block */
    readonly placement: DataprocJobPlacement[];
    /** pyspark_config block */
    readonly pysparkConfig?: DataprocJobPysparkConfig[];
    /** reference block */
    readonly reference?: DataprocJobReference[];
    /** scheduling block */
    readonly scheduling?: DataprocJobScheduling[];
    /** spark_config block */
    readonly sparkConfig?: DataprocJobSparkConfig[];
    /** sparksql_config block */
    readonly sparksqlConfig?: DataprocJobSparksqlConfig[];
    /** timeouts block */
    readonly timeouts?: DataprocJobTimeouts;
}
export declare class DataprocJobStatus extends ComplexComputedList {
    get details(): string;
    get state(): string;
    get stateStartTime(): string;
    get substate(): string;
}
export interface DataprocJobHadoopConfigLoggingConfig {
    /** Optional. The per-package log levels for the driver. This may include 'root' package name to configure rootLogger. Examples: 'com.google = FATAL', 'root = INFO', 'org.apache = DEBUG'. */
    readonly driverLogLevels: {
        [key: string]: string;
    };
}
export interface DataprocJobHadoopConfig {
    /** HCFS URIs of archives to be extracted in the working directory of .jar, .tar, .tar.gz, .tgz, and .zip. */
    readonly archiveUris?: string[];
    /** The arguments to pass to the driver. */
    readonly args?: string[];
    /** HCFS URIs of files to be copied to the working directory of Spark drivers and distributed tasks. Useful for naively parallel tasks. */
    readonly fileUris?: string[];
    /** HCFS URIs of jar files to add to the CLASSPATHs of the Spark driver and tasks. */
    readonly jarFileUris?: string[];
    /** The class containing the main method of the driver. Must be in a provided jar or jar that is already on the classpath. Conflicts with main_jar_file_uri */
    readonly mainClass?: string;
    /** The HCFS URI of jar file containing the driver jar. Conflicts with main_class */
    readonly mainJarFileUri?: string;
    /** A mapping of property names to values, used to configure Spark. Properties that conflict with values set by the Cloud Dataproc API may be overwritten. Can include properties set in /etc/spark/conf/spark-defaults.conf and classes in user code. */
    readonly properties?: {
        [key: string]: string;
    };
    /** logging_config block */
    readonly loggingConfig?: DataprocJobHadoopConfigLoggingConfig[];
}
export interface DataprocJobHiveConfig {
    /** Whether to continue executing queries if a query fails. The default value is false. Setting to true can be useful when executing independent parallel queries. Defaults to false. */
    readonly continueOnFailure?: boolean;
    /** HCFS URIs of jar files to add to the CLASSPATH of the Hive server and Hadoop MapReduce (MR) tasks. Can contain Hive SerDes and UDFs. */
    readonly jarFileUris?: string[];
    /** A mapping of property names and values, used to configure Hive. Properties that conflict with values set by the Cloud Dataproc API may be overwritten. Can include properties set in /etc/hadoop/conf/*-site.xml, /etc/hive/conf/hive-site.xml, and classes in user code. */
    readonly properties?: {
        [key: string]: string;
    };
    /** HCFS URI of file containing Hive script to execute as the job. Conflicts with query_list */
    readonly queryFileUri?: string;
    /** The list of Hive queries or statements to execute as part of the job. Conflicts with query_file_uri */
    readonly queryList?: string[];
    /** Mapping of query variable names to values (equivalent to the Hive command: SET name="value";). */
    readonly scriptVariables?: {
        [key: string]: string;
    };
}
export interface DataprocJobPigConfigLoggingConfig {
    /** Optional. The per-package log levels for the driver. This may include 'root' package name to configure rootLogger. Examples: 'com.google = FATAL', 'root = INFO', 'org.apache = DEBUG'. */
    readonly driverLogLevels: {
        [key: string]: string;
    };
}
export interface DataprocJobPigConfig {
    /** Whether to continue executing queries if a query fails. The default value is false. Setting to true can be useful when executing independent parallel queries. Defaults to false. */
    readonly continueOnFailure?: boolean;
    /** HCFS URIs of jar files to add to the CLASSPATH of the Pig Client and Hadoop MapReduce (MR) tasks. Can contain Pig UDFs. */
    readonly jarFileUris?: string[];
    /** A mapping of property names to values, used to configure Pig. Properties that conflict with values set by the Cloud Dataproc API may be overwritten. Can include properties set in /etc/hadoop/conf/*-site.xml, /etc/pig/conf/pig.properties, and classes in user code. */
    readonly properties?: {
        [key: string]: string;
    };
    /** HCFS URI of file containing Hive script to execute as the job. Conflicts with query_list */
    readonly queryFileUri?: string;
    /** The list of Hive queries or statements to execute as part of the job. Conflicts with query_file_uri */
    readonly queryList?: string[];
    /** Mapping of query variable names to values (equivalent to the Pig command: name=[value]). */
    readonly scriptVariables?: {
        [key: string]: string;
    };
    /** logging_config block */
    readonly loggingConfig?: DataprocJobPigConfigLoggingConfig[];
}
export interface DataprocJobPlacement {
    /** The name of the cluster where the job will be submitted */
    readonly clusterName: string;
}
export interface DataprocJobPysparkConfigLoggingConfig {
    /** Optional. The per-package log levels for the driver. This may include 'root' package name to configure rootLogger. Examples: 'com.google = FATAL', 'root = INFO', 'org.apache = DEBUG'. */
    readonly driverLogLevels: {
        [key: string]: string;
    };
}
export interface DataprocJobPysparkConfig {
    /** Optional. HCFS URIs of archives to be extracted in the working directory of .jar, .tar, .tar.gz, .tgz, and .zip */
    readonly archiveUris?: string[];
    /** Optional. The arguments to pass to the driver. Do not include arguments, such as --conf, that can be set as job properties, since a collision may occur that causes an incorrect job submission */
    readonly args?: string[];
    /** Optional. HCFS URIs of files to be copied to the working directory of Python drivers and distributed tasks. Useful for naively parallel tasks */
    readonly fileUris?: string[];
    /** Optional. HCFS URIs of jar files to add to the CLASSPATHs of the Python driver and tasks */
    readonly jarFileUris?: string[];
    /** Required. The HCFS URI of the main Python file to use as the driver. Must be a .py file */
    readonly mainPythonFileUri: string;
    /** Optional. A mapping of property names to values, used to configure PySpark. Properties that conflict with values set by the Cloud Dataproc API may be overwritten. Can include properties set in /etc/spark/conf/spark-defaults.conf and classes in user code */
    readonly properties?: {
        [key: string]: string;
    };
    /** Optional. HCFS file URIs of Python files to pass to the PySpark framework. Supported file types: .py, .egg, and .zip */
    readonly pythonFileUris?: string[];
    /** logging_config block */
    readonly loggingConfig?: DataprocJobPysparkConfigLoggingConfig[];
}
export interface DataprocJobReference {
    /** The job ID, which must be unique within the project. The job ID is generated by the server upon job submission or provided by the user as a means to perform retries without creating duplicate jobs */
    readonly jobId?: string;
}
export interface DataprocJobScheduling {
    /** Maximum number of times per hour a driver may be restarted as a result of driver terminating with non-zero code before job is reported failed. */
    readonly maxFailuresPerHour: number;
}
export interface DataprocJobSparkConfigLoggingConfig {
    /** Optional. The per-package log levels for the driver. This may include 'root' package name to configure rootLogger. Examples: 'com.google = FATAL', 'root = INFO', 'org.apache = DEBUG'. */
    readonly driverLogLevels: {
        [key: string]: string;
    };
}
export interface DataprocJobSparkConfig {
    /** HCFS URIs of archives to be extracted in the working directory of .jar, .tar, .tar.gz, .tgz, and .zip. */
    readonly archiveUris?: string[];
    /** The arguments to pass to the driver. */
    readonly args?: string[];
    /** HCFS URIs of files to be copied to the working directory of Spark drivers and distributed tasks. Useful for naively parallel tasks. */
    readonly fileUris?: string[];
    /** HCFS URIs of jar files to add to the CLASSPATHs of the Spark driver and tasks. */
    readonly jarFileUris?: string[];
    /** The class containing the main method of the driver. Must be in a provided jar or jar that is already on the classpath. Conflicts with main_jar_file_uri */
    readonly mainClass?: string;
    /** The HCFS URI of jar file containing the driver jar. Conflicts with main_class */
    readonly mainJarFileUri?: string;
    /** A mapping of property names to values, used to configure Spark. Properties that conflict with values set by the Cloud Dataproc API may be overwritten. Can include properties set in /etc/spark/conf/spark-defaults.conf and classes in user code. */
    readonly properties?: {
        [key: string]: string;
    };
    /** logging_config block */
    readonly loggingConfig?: DataprocJobSparkConfigLoggingConfig[];
}
export interface DataprocJobSparksqlConfigLoggingConfig {
    /** Optional. The per-package log levels for the driver. This may include 'root' package name to configure rootLogger. Examples: 'com.google = FATAL', 'root = INFO', 'org.apache = DEBUG'. */
    readonly driverLogLevels: {
        [key: string]: string;
    };
}
export interface DataprocJobSparksqlConfig {
    /** HCFS URIs of jar files to be added to the Spark CLASSPATH. */
    readonly jarFileUris?: string[];
    /** A mapping of property names to values, used to configure Spark SQL's SparkConf. Properties that conflict with values set by the Cloud Dataproc API may be overwritten. */
    readonly properties?: {
        [key: string]: string;
    };
    /** The HCFS URI of the script that contains SQL queries. Conflicts with query_list */
    readonly queryFileUri?: string;
    /** The list of SQL queries or statements to execute as part of the job. Conflicts with query_file_uri */
    readonly queryList?: string[];
    /** Mapping of query variable names to values (equivalent to the Spark SQL command: SET name="value";). */
    readonly scriptVariables?: {
        [key: string]: string;
    };
    /** logging_config block */
    readonly loggingConfig?: DataprocJobSparksqlConfigLoggingConfig[];
}
export interface DataprocJobTimeouts {
    readonly create?: string;
    readonly delete?: string;
}
export declare class DataprocJob extends TerraformResource {
    constructor(scope: Construct, id: string, config: DataprocJobConfig);
    get driverControlsFilesUri(): string;
    get driverOutputResourceUri(): string;
    private _forceDelete?;
    get forceDelete(): boolean | undefined;
    set forceDelete(value: boolean | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _region?;
    get region(): string | undefined;
    set region(value: string | undefined);
    status(index: string): DataprocJobStatus;
    private _hadoopConfig?;
    get hadoopConfig(): DataprocJobHadoopConfig[] | undefined;
    set hadoopConfig(value: DataprocJobHadoopConfig[] | undefined);
    private _hiveConfig?;
    get hiveConfig(): DataprocJobHiveConfig[] | undefined;
    set hiveConfig(value: DataprocJobHiveConfig[] | undefined);
    private _pigConfig?;
    get pigConfig(): DataprocJobPigConfig[] | undefined;
    set pigConfig(value: DataprocJobPigConfig[] | undefined);
    private _placement;
    get placement(): DataprocJobPlacement[];
    set placement(value: DataprocJobPlacement[]);
    private _pysparkConfig?;
    get pysparkConfig(): DataprocJobPysparkConfig[] | undefined;
    set pysparkConfig(value: DataprocJobPysparkConfig[] | undefined);
    private _reference?;
    get reference(): DataprocJobReference[] | undefined;
    set reference(value: DataprocJobReference[] | undefined);
    private _scheduling?;
    get scheduling(): DataprocJobScheduling[] | undefined;
    set scheduling(value: DataprocJobScheduling[] | undefined);
    private _sparkConfig?;
    get sparkConfig(): DataprocJobSparkConfig[] | undefined;
    set sparkConfig(value: DataprocJobSparkConfig[] | undefined);
    private _sparksqlConfig?;
    get sparksqlConfig(): DataprocJobSparksqlConfig[] | undefined;
    set sparksqlConfig(value: DataprocJobSparksqlConfig[] | undefined);
    private _timeouts?;
    get timeouts(): DataprocJobTimeouts | undefined;
    set timeouts(value: DataprocJobTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
