import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface DialogflowAgentConfig extends TerraformMetaArguments {
    /** API version displayed in Dialogflow console. If not specified, V2 API is assumed. Clients are free to query
  different service endpoints for different API versions. However, bots connectors and webhook calls will follow
  the specified API version.
  * API_VERSION_V1: Legacy V1 API.
  * API_VERSION_V2: V2 API.
  * API_VERSION_V2_BETA_1: V2beta1 API. Possible values: ["API_VERSION_V1", "API_VERSION_V2", "API_VERSION_V2_BETA_1"] */
    readonly apiVersion?: string;
    /** The URI of the agent's avatar, which are used throughout the Dialogflow console. When an image URL is entered
  into this field, the Dialogflow will save the image in the backend. The address of the backend image returned
  from the API will be shown in the [avatarUriBackend] field. */
    readonly avatarUri?: string;
    /** To filter out false positive results and still get variety in matched natural language inputs for your agent,
  you can tune the machine learning classification threshold. If the returned score value is less than the threshold
  value, then a fallback intent will be triggered or, if there are no fallback intents defined, no intent will be
  triggered. The score values range from 0.0 (completely uncertain) to 1.0 (completely certain). If set to 0.0, the
  default of 0.3 is used. */
    readonly classificationThreshold?: number;
    /** The default language of the agent as a language tag. [See Language Support](https://cloud.google.com/dialogflow/docs/reference/language)
  for a list of the currently supported language codes. This field cannot be updated after creation. */
    readonly defaultLanguageCode: string;
    /** The description of this agent. The maximum length is 500 characters. If exceeded, the request is rejected. */
    readonly description?: string;
    /** The name of this agent. */
    readonly displayName: string;
    /** Determines whether this agent should log conversation queries. */
    readonly enableLogging?: boolean;
    /** Determines how intents are detected from user queries.
  * MATCH_MODE_HYBRID: Best for agents with a small number of examples in intents and/or wide use of templates
  syntax and composite entities.
  * MATCH_MODE_ML_ONLY: Can be used for agents with a large number of examples in intents, especially the ones
  using @sys.any or very large developer entities. Possible values: ["MATCH_MODE_HYBRID", "MATCH_MODE_ML_ONLY"] */
    readonly matchMode?: string;
    readonly project?: string;
    /** The list of all languages supported by this agent (except for the defaultLanguageCode). */
    readonly supportedLanguageCodes?: string[];
    /** The agent tier. If not specified, TIER_STANDARD is assumed.
  * TIER_STANDARD: Standard tier.
  * TIER_ENTERPRISE: Enterprise tier (Essentials).
  * TIER_ENTERPRISE_PLUS: Enterprise tier (Plus).
  NOTE: Due to consistency issues, the provider will not read this field from the API. Drift is possible between
  the Terraform state and Dialogflow if the agent tier is changed outside of Terraform. Possible values: ["TIER_STANDARD", "TIER_ENTERPRISE", "TIER_ENTERPRISE_PLUS"] */
    readonly tier?: string;
    /** The time zone of this agent from the [time zone database](https://www.iana.org/time-zones), e.g., America/New_York,
  Europe/Paris. */
    readonly timeZone: string;
    /** timeouts block */
    readonly timeouts?: DialogflowAgentTimeouts;
}
export interface DialogflowAgentTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class DialogflowAgent extends TerraformResource {
    constructor(scope: Construct, id: string, config: DialogflowAgentConfig);
    private _apiVersion?;
    get apiVersion(): string | undefined;
    set apiVersion(value: string | undefined);
    private _avatarUri?;
    get avatarUri(): string | undefined;
    set avatarUri(value: string | undefined);
    get avatarUriBackend(): string;
    private _classificationThreshold?;
    get classificationThreshold(): number | undefined;
    set classificationThreshold(value: number | undefined);
    private _defaultLanguageCode;
    get defaultLanguageCode(): string;
    set defaultLanguageCode(value: string);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _displayName;
    get displayName(): string;
    set displayName(value: string);
    private _enableLogging?;
    get enableLogging(): boolean | undefined;
    set enableLogging(value: boolean | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _matchMode?;
    get matchMode(): string | undefined;
    set matchMode(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _supportedLanguageCodes?;
    get supportedLanguageCodes(): string[] | undefined;
    set supportedLanguageCodes(value: string[] | undefined);
    private _tier?;
    get tier(): string | undefined;
    set tier(value: string | undefined);
    private _timeZone;
    get timeZone(): string;
    set timeZone(value: string);
    private _timeouts?;
    get timeouts(): DialogflowAgentTimeouts | undefined;
    set timeouts(value: DialogflowAgentTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
