import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface DialogflowEntityTypeConfig extends TerraformMetaArguments {
    /** The name of this entity type to be displayed on the console. */
    readonly displayName: string;
    /** Enables fuzzy entity extraction during classification. */
    readonly enableFuzzyExtraction?: boolean;
    /** Indicates the kind of entity type.
  * KIND_MAP: Map entity types allow mapping of a group of synonyms to a reference value.
  * KIND_LIST: List entity types contain a set of entries that do not map to reference values. However, list entity
  types can contain references to other entity types (with or without aliases).
  * KIND_REGEXP: Regexp entity types allow to specify regular expressions in entries values. Possible values: ["KIND_MAP", "KIND_LIST", "KIND_REGEXP"] */
    readonly kind: string;
    readonly project?: string;
    /** entities block */
    readonly entities?: DialogflowEntityTypeEntities[];
    /** timeouts block */
    readonly timeouts?: DialogflowEntityTypeTimeouts;
}
export interface DialogflowEntityTypeEntities {
    /** A collection of value synonyms. For example, if the entity type is vegetable, and value is scallions, a synonym
  could be green onions.
  For KIND_LIST entity types:
  * This collection must contain exactly one synonym equal to value. */
    readonly synonyms: string[];
    /** The primary value associated with this entity entry. For example, if the entity type is vegetable, the value
  could be scallions.
  For KIND_MAP entity types:
  * A reference value to be used in place of synonyms.
  For KIND_LIST entity types:
  * A string that can contain references to other entity types (with or without aliases). */
    readonly value: string;
}
export interface DialogflowEntityTypeTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class DialogflowEntityType extends TerraformResource {
    constructor(scope: Construct, id: string, config: DialogflowEntityTypeConfig);
    private _displayName;
    get displayName(): string;
    set displayName(value: string);
    private _enableFuzzyExtraction?;
    get enableFuzzyExtraction(): boolean | undefined;
    set enableFuzzyExtraction(value: boolean | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _kind;
    get kind(): string;
    set kind(value: string);
    get name(): string;
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _entities?;
    get entities(): DialogflowEntityTypeEntities[] | undefined;
    set entities(value: DialogflowEntityTypeEntities[] | undefined);
    private _timeouts?;
    get timeouts(): DialogflowEntityTypeTimeouts | undefined;
    set timeouts(value: DialogflowEntityTypeTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
