import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface DnsManagedZoneConfig extends TerraformMetaArguments {
    /** A textual description field. Defaults to 'Managed by Terraform'. */
    readonly description?: string;
    /** The DNS name of this managed zone, for instance "example.com.". */
    readonly dnsName: string;
    /** A set of key/value label pairs to assign to this ManagedZone. */
    readonly labels?: {
        [key: string]: string;
    };
    /** User assigned name for this resource.
  Must be unique within the project. */
    readonly name: string;
    readonly project?: string;
    /** The zone's visibility: public zones are exposed to the Internet,
  while private zones are visible only to Virtual Private Cloud resources. Default value: "public" Possible values: ["private", "public"] */
    readonly visibility?: string;
    /** dnssec_config block */
    readonly dnssecConfig?: DnsManagedZoneDnssecConfig[];
    /** forwarding_config block */
    readonly forwardingConfig?: DnsManagedZoneForwardingConfig[];
    /** peering_config block */
    readonly peeringConfig?: DnsManagedZonePeeringConfig[];
    /** private_visibility_config block */
    readonly privateVisibilityConfig?: DnsManagedZonePrivateVisibilityConfig[];
    /** timeouts block */
    readonly timeouts?: DnsManagedZoneTimeouts;
}
export interface DnsManagedZoneDnssecConfigDefaultKeySpecs {
    /** String mnemonic specifying the DNSSEC algorithm of this key Possible values: ["ecdsap256sha256", "ecdsap384sha384", "rsasha1", "rsasha256", "rsasha512"] */
    readonly algorithm?: string;
    /** Length of the keys in bits */
    readonly keyLength?: number;
    /** Specifies whether this is a key signing key (KSK) or a zone
  signing key (ZSK). Key signing keys have the Secure Entry
  Point flag set and, when active, will only be used to sign
  resource record sets of type DNSKEY. Zone signing keys do
  not have the Secure Entry Point flag set and will be used
  to sign all other types of resource record sets. Possible values: ["keySigning", "zoneSigning"] */
    readonly keyType?: string;
    /** Identifies what kind of resource this is */
    readonly kind?: string;
}
export interface DnsManagedZoneDnssecConfig {
    /** Identifies what kind of resource this is */
    readonly kind?: string;
    /** Specifies the mechanism used to provide authenticated denial-of-existence responses.
  non_existence can only be updated when the state is 'off'. Possible values: ["nsec", "nsec3"] */
    readonly nonExistence?: string;
    /** Specifies whether DNSSEC is enabled, and what mode it is in Possible values: ["off", "on", "transfer"] */
    readonly state?: string;
    /** default_key_specs block */
    readonly defaultKeySpecs?: DnsManagedZoneDnssecConfigDefaultKeySpecs[];
}
export interface DnsManagedZoneForwardingConfigTargetNameServers {
    /** Forwarding path for this TargetNameServer. If unset or 'default' Cloud DNS will make forwarding
  decision based on address ranges, i.e. RFC1918 addresses go to the VPC, Non-RFC1918 addresses go
  to the Internet. When set to 'private', Cloud DNS will always send queries through VPC for this target Possible values: ["default", "private"] */
    readonly forwardingPath?: string;
    /** IPv4 address of a target name server. */
    readonly ipv4Address: string;
}
export interface DnsManagedZoneForwardingConfig {
    /** target_name_servers block */
    readonly targetNameServers: DnsManagedZoneForwardingConfigTargetNameServers[];
}
export interface DnsManagedZonePeeringConfigTargetNetwork {
    /** The id or fully qualified URL of the VPC network to forward queries to.
  This should be formatted like 'projects/{project}/global/networks/{network}' or
  'https://www.googleapis.com/compute/v1/projects/{project}/global/networks/{network}' */
    readonly networkUrl: string;
}
export interface DnsManagedZonePeeringConfig {
    /** target_network block */
    readonly targetNetwork: DnsManagedZonePeeringConfigTargetNetwork[];
}
export interface DnsManagedZonePrivateVisibilityConfigNetworks {
    /** The id or fully qualified URL of the VPC network to bind to.
  This should be formatted like 'projects/{project}/global/networks/{network}' or
  'https://www.googleapis.com/compute/v1/projects/{project}/global/networks/{network}' */
    readonly networkUrl: string;
}
export interface DnsManagedZonePrivateVisibilityConfig {
    /** networks block */
    readonly networks: DnsManagedZonePrivateVisibilityConfigNetworks[];
}
export interface DnsManagedZoneTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class DnsManagedZone extends TerraformResource {
    constructor(scope: Construct, id: string, config: DnsManagedZoneConfig);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _dnsName;
    get dnsName(): string;
    set dnsName(value: string);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    get nameServers(): string[];
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _visibility?;
    get visibility(): string | undefined;
    set visibility(value: string | undefined);
    private _dnssecConfig?;
    get dnssecConfig(): DnsManagedZoneDnssecConfig[] | undefined;
    set dnssecConfig(value: DnsManagedZoneDnssecConfig[] | undefined);
    private _forwardingConfig?;
    get forwardingConfig(): DnsManagedZoneForwardingConfig[] | undefined;
    set forwardingConfig(value: DnsManagedZoneForwardingConfig[] | undefined);
    private _peeringConfig?;
    get peeringConfig(): DnsManagedZonePeeringConfig[] | undefined;
    set peeringConfig(value: DnsManagedZonePeeringConfig[] | undefined);
    private _privateVisibilityConfig?;
    get privateVisibilityConfig(): DnsManagedZonePrivateVisibilityConfig[] | undefined;
    set privateVisibilityConfig(value: DnsManagedZonePrivateVisibilityConfig[] | undefined);
    private _timeouts?;
    get timeouts(): DnsManagedZoneTimeouts | undefined;
    set timeouts(value: DnsManagedZoneTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
