import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface DnsPolicyConfig extends TerraformMetaArguments {
    /** A textual description field. Defaults to 'Managed by Terraform'. */
    readonly description?: string;
    /** Allows networks bound to this policy to receive DNS queries sent
  by VMs or applications over VPN connections. When enabled, a
  virtual IP address will be allocated from each of the sub-networks
  that are bound to this policy. */
    readonly enableInboundForwarding?: boolean;
    /** Controls whether logging is enabled for the networks bound to this policy.
  Defaults to no logging if not set. */
    readonly enableLogging?: boolean;
    /** User assigned name for this policy. */
    readonly name: string;
    readonly project?: string;
    /** alternative_name_server_config block */
    readonly alternativeNameServerConfig?: DnsPolicyAlternativeNameServerConfig[];
    /** networks block */
    readonly networks?: DnsPolicyNetworks[];
    /** timeouts block */
    readonly timeouts?: DnsPolicyTimeouts;
}
export interface DnsPolicyAlternativeNameServerConfigTargetNameServers {
    /** IPv4 address to forward to. */
    readonly ipv4Address: string;
}
export interface DnsPolicyAlternativeNameServerConfig {
    /** target_name_servers block */
    readonly targetNameServers: DnsPolicyAlternativeNameServerConfigTargetNameServers[];
}
export interface DnsPolicyNetworks {
    /** The id or fully qualified URL of the VPC network to forward queries to.
  This should be formatted like 'projects/{project}/global/networks/{network}' or
  'https://www.googleapis.com/compute/v1/projects/{project}/global/networks/{network}' */
    readonly networkUrl: string;
}
export interface DnsPolicyTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class DnsPolicy extends TerraformResource {
    constructor(scope: Construct, id: string, config: DnsPolicyConfig);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _enableInboundForwarding?;
    get enableInboundForwarding(): boolean | undefined;
    set enableInboundForwarding(value: boolean | undefined);
    private _enableLogging?;
    get enableLogging(): boolean | undefined;
    set enableLogging(value: boolean | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _alternativeNameServerConfig?;
    get alternativeNameServerConfig(): DnsPolicyAlternativeNameServerConfig[] | undefined;
    set alternativeNameServerConfig(value: DnsPolicyAlternativeNameServerConfig[] | undefined);
    private _networks?;
    get networks(): DnsPolicyNetworks[] | undefined;
    set networks(value: DnsPolicyNetworks[] | undefined);
    private _timeouts?;
    get timeouts(): DnsPolicyTimeouts | undefined;
    set timeouts(value: DnsPolicyTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
