import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
export interface EndpointsServiceConfig extends TerraformMetaArguments {
    /** The full text of the Service Config YAML file (Example located here). If provided, must also provide protoc_output_base64. open_api config must not be provided. */
    readonly grpcConfig?: string;
    /** The full text of the OpenAPI YAML configuration as described here. Either this, or both of grpc_config and protoc_output_base64 must be specified. */
    readonly openapiConfig?: string;
    /** The project ID that the service belongs to. If not provided, provider project is used. */
    readonly project?: string;
    /** The full contents of the Service Descriptor File generated by protoc. This should be a compiled .pb file, base64-encoded. */
    readonly protocOutputBase64?: string;
    /** The name of the service. Usually of the form $apiname.endpoints.$projectid.cloud.goog. */
    readonly serviceName: string;
    /** timeouts block */
    readonly timeouts?: EndpointsServiceTimeouts;
}
export declare class EndpointsServiceApisMethods extends ComplexComputedList {
    get name(): string;
    get requestType(): string;
    get responseType(): string;
    get syntax(): string;
}
export declare class EndpointsServiceApis extends ComplexComputedList {
    get methods(): any;
    get name(): string;
    get syntax(): string;
    get version(): string;
}
export declare class EndpointsServiceEndpoints extends ComplexComputedList {
    get address(): string;
    get name(): string;
}
export interface EndpointsServiceTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class EndpointsService extends TerraformResource {
    constructor(scope: Construct, id: string, config: EndpointsServiceConfig);
    apis(index: string): EndpointsServiceApis;
    get configId(): string;
    get dnsAddress(): string;
    endpoints(index: string): EndpointsServiceEndpoints;
    private _grpcConfig?;
    get grpcConfig(): string | undefined;
    set grpcConfig(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _openapiConfig?;
    get openapiConfig(): string | undefined;
    set openapiConfig(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _protocOutputBase64?;
    get protocOutputBase64(): string | undefined;
    set protocOutputBase64(value: string | undefined);
    private _serviceName;
    get serviceName(): string;
    set serviceName(value: string);
    private _timeouts?;
    get timeouts(): EndpointsServiceTimeouts | undefined;
    set timeouts(value: EndpointsServiceTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
