import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface FilestoreInstanceConfig extends TerraformMetaArguments {
    /** A description of the instance. */
    readonly description?: string;
    /** Resource labels to represent user-provided metadata. */
    readonly labels?: {
        [key: string]: string;
    };
    /** The resource name of the instance. */
    readonly name: string;
    readonly project?: string;
    /** The service tier of the instance. Possible values: ["TIER_UNSPECIFIED", "STANDARD", "PREMIUM", "BASIC_HDD", "BASIC_SSD", "HIGH_SCALE_SSD"] */
    readonly tier: string;
    /** The name of the Filestore zone of the instance. */
    readonly zone: string;
    /** file_shares block */
    readonly fileShares: FilestoreInstanceFileShares[];
    /** networks block */
    readonly networks: FilestoreInstanceNetworks[];
    /** timeouts block */
    readonly timeouts?: FilestoreInstanceTimeouts;
}
export interface FilestoreInstanceFileShares {
    /** File share capacity in GiB. This must be at least 1024 GiB
  for the standard tier, or 2560 GiB for the premium tier. */
    readonly capacityGb: number;
    /** The name of the fileshare (16 characters or less) */
    readonly name: string;
}
export interface FilestoreInstanceNetworks {
    /** IP versions for which the instance has
  IP addresses assigned. Possible values: ["ADDRESS_MODE_UNSPECIFIED", "MODE_IPV4", "MODE_IPV6"] */
    readonly modes: string[];
    /** The name of the GCE VPC network to which the
  instance is connected. */
    readonly network: string;
    /** A /29 CIDR block that identifies the range of IP
  addresses reserved for this instance. */
    readonly reservedIpRange?: string;
}
export interface FilestoreInstanceTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class FilestoreInstance extends TerraformResource {
    constructor(scope: Construct, id: string, config: FilestoreInstanceConfig);
    get createTime(): string;
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    get etag(): string;
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _tier;
    get tier(): string;
    set tier(value: string);
    private _zone;
    get zone(): string;
    set zone(value: string);
    private _fileShares;
    get fileShares(): FilestoreInstanceFileShares[];
    set fileShares(value: FilestoreInstanceFileShares[]);
    private _networks;
    get networks(): FilestoreInstanceNetworks[];
    set networks(value: FilestoreInstanceNetworks[]);
    private _timeouts?;
    get timeouts(): FilestoreInstanceTimeouts | undefined;
    set timeouts(value: FilestoreInstanceTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
