import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface FirestoreIndexConfig extends TerraformMetaArguments {
    /** The collection being indexed. */
    readonly collection: string;
    /** The Firestore database id. Defaults to '"(default)"'. */
    readonly database?: string;
    readonly project?: string;
    /** The scope at which a query is run. Default value: "COLLECTION" Possible values: ["COLLECTION", "COLLECTION_GROUP"] */
    readonly queryScope?: string;
    /** fields block */
    readonly fields: FirestoreIndexFields[];
    /** timeouts block */
    readonly timeouts?: FirestoreIndexTimeouts;
}
export interface FirestoreIndexFields {
    /** Indicates that this field supports operations on arrayValues. Only one of 'order' and 'arrayConfig' can
  be specified. Possible values: ["CONTAINS"] */
    readonly arrayConfig?: string;
    /** Name of the field. */
    readonly fieldPath?: string;
    /** Indicates that this field supports ordering by the specified order or comparing using =, <, <=, >, >=.
  Only one of 'order' and 'arrayConfig' can be specified. Possible values: ["ASCENDING", "DESCENDING"] */
    readonly order?: string;
}
export interface FirestoreIndexTimeouts {
    readonly create?: string;
    readonly delete?: string;
}
export declare class FirestoreIndex extends TerraformResource {
    constructor(scope: Construct, id: string, config: FirestoreIndexConfig);
    private _collection;
    get collection(): string;
    set collection(value: string);
    private _database?;
    get database(): string | undefined;
    set database(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get name(): string;
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _queryScope?;
    get queryScope(): string | undefined;
    set queryScope(value: string | undefined);
    private _fields;
    get fields(): FirestoreIndexFields[];
    set fields(value: FirestoreIndexFields[]);
    private _timeouts?;
    get timeouts(): FirestoreIndexTimeouts | undefined;
    set timeouts(value: FirestoreIndexTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
