import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface FolderAccessApprovalSettingsConfig extends TerraformMetaArguments {
    /** ID of the folder of the access approval settings. */
    readonly folderId: string;
    /** A list of email addresses to which notifications relating to approval requests should be sent.
  Notifications relating to a resource will be sent to all emails in the settings of ancestor
  resources of that resource. A maximum of 50 email addresses are allowed. */
    readonly notificationEmails?: string[];
    /** enrolled_services block */
    readonly enrolledServices: FolderAccessApprovalSettingsEnrolledServices[];
    /** timeouts block */
    readonly timeouts?: FolderAccessApprovalSettingsTimeouts;
}
export interface FolderAccessApprovalSettingsEnrolledServices {
    /** The product for which Access Approval will be enrolled. Allowed values are listed (case-sensitive):
    all
    appengine.googleapis.com
    bigquery.googleapis.com
    bigtable.googleapis.com
    cloudkms.googleapis.com
    compute.googleapis.com
    dataflow.googleapis.com
    iam.googleapis.com
    pubsub.googleapis.com
    storage.googleapis.com */
    readonly cloudProduct: string;
    /** The enrollment level of the service. Default value: "BLOCK_ALL" Possible values: ["BLOCK_ALL"] */
    readonly enrollmentLevel?: string;
}
export interface FolderAccessApprovalSettingsTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class FolderAccessApprovalSettings extends TerraformResource {
    constructor(scope: Construct, id: string, config: FolderAccessApprovalSettingsConfig);
    get enrolledAncestor(): boolean;
    private _folderId;
    get folderId(): string;
    set folderId(value: string);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get name(): string;
    private _notificationEmails?;
    get notificationEmails(): string[] | undefined;
    set notificationEmails(value: string[] | undefined);
    private _enrolledServices;
    get enrolledServices(): FolderAccessApprovalSettingsEnrolledServices[];
    set enrolledServices(value: FolderAccessApprovalSettingsEnrolledServices[]);
    private _timeouts?;
    get timeouts(): FolderAccessApprovalSettingsTimeouts | undefined;
    set timeouts(value: FolderAccessApprovalSettingsTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
