import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface FolderOrganizationPolicyConfig extends TerraformMetaArguments {
    /** The name of the Constraint the Policy is configuring, for example, serviceuser.services. */
    readonly constraint: string;
    /** The resource name of the folder to set the policy for. Its format is folders/{folder_id}. */
    readonly folder: string;
    /** Version of the Policy. Default version is 0. */
    readonly version?: number;
    /** boolean_policy block */
    readonly booleanPolicy?: FolderOrganizationPolicyBooleanPolicy[];
    /** list_policy block */
    readonly listPolicy?: FolderOrganizationPolicyListPolicy[];
    /** restore_policy block */
    readonly restorePolicy?: FolderOrganizationPolicyRestorePolicy[];
    /** timeouts block */
    readonly timeouts?: FolderOrganizationPolicyTimeouts;
}
export interface FolderOrganizationPolicyBooleanPolicy {
    /** If true, then the Policy is enforced. If false, then any configuration is acceptable. */
    readonly enforced: boolean;
}
export interface FolderOrganizationPolicyListPolicyAllow {
    /** The policy allows or denies all values. */
    readonly all?: boolean;
    /** The policy can define specific values that are allowed or denied. */
    readonly values?: string[];
}
export interface FolderOrganizationPolicyListPolicyDeny {
    /** The policy allows or denies all values. */
    readonly all?: boolean;
    /** The policy can define specific values that are allowed or denied. */
    readonly values?: string[];
}
export interface FolderOrganizationPolicyListPolicy {
    /** If set to true, the values from the effective Policy of the parent resource are inherited, meaning the values set in this Policy are added to the values inherited up the hierarchy. */
    readonly inheritFromParent?: boolean;
    /** The Google Cloud Console will try to default to a configuration that matches the value specified in this field. */
    readonly suggestedValue?: string;
    /** allow block */
    readonly allow?: FolderOrganizationPolicyListPolicyAllow[];
    /** deny block */
    readonly deny?: FolderOrganizationPolicyListPolicyDeny[];
}
export interface FolderOrganizationPolicyRestorePolicy {
    /** May only be set to true. If set, then the default Policy is restored. */
    readonly default: boolean;
}
export interface FolderOrganizationPolicyTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class FolderOrganizationPolicy extends TerraformResource {
    constructor(scope: Construct, id: string, config: FolderOrganizationPolicyConfig);
    private _constraint;
    get constraint(): string;
    set constraint(value: string);
    get etag(): string;
    private _folder;
    get folder(): string;
    set folder(value: string);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get updateTime(): string;
    private _version?;
    get version(): number | undefined;
    set version(value: number | undefined);
    private _booleanPolicy?;
    get booleanPolicy(): FolderOrganizationPolicyBooleanPolicy[] | undefined;
    set booleanPolicy(value: FolderOrganizationPolicyBooleanPolicy[] | undefined);
    private _listPolicy?;
    get listPolicy(): FolderOrganizationPolicyListPolicy[] | undefined;
    set listPolicy(value: FolderOrganizationPolicyListPolicy[] | undefined);
    private _restorePolicy?;
    get restorePolicy(): FolderOrganizationPolicyRestorePolicy[] | undefined;
    set restorePolicy(value: FolderOrganizationPolicyRestorePolicy[] | undefined);
    private _timeouts?;
    get timeouts(): FolderOrganizationPolicyTimeouts | undefined;
    set timeouts(value: FolderOrganizationPolicyTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
