import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface GameServicesGameServerClusterConfig extends TerraformMetaArguments {
    /** Required. The resource name of the game server cluster */
    readonly clusterId: string;
    /** Human readable description of the cluster. */
    readonly description?: string;
    /** The labels associated with this game server cluster. Each label is a
  key-value pair. */
    readonly labels?: {
        [key: string]: string;
    };
    /** Location of the Cluster. */
    readonly location?: string;
    readonly project?: string;
    /** The realm id of the game server realm. */
    readonly realmId: string;
    /** connection_info block */
    readonly connectionInfo: GameServicesGameServerClusterConnectionInfo[];
    /** timeouts block */
    readonly timeouts?: GameServicesGameServerClusterTimeouts;
}
export interface GameServicesGameServerClusterConnectionInfoGkeClusterReference {
    /** The full or partial name of a GKE cluster, using one of the following
  forms:
  
  * 'projects/{project_id}/locations/{location}/clusters/{cluster_id}'
  * 'locations/{location}/clusters/{cluster_id}'
  * '{cluster_id}'
  
  If project and location are not specified, the project and location of the
  GameServerCluster resource are used to generate the full name of the
  GKE cluster. */
    readonly cluster: string;
}
export interface GameServicesGameServerClusterConnectionInfo {
    /** Namespace designated on the game server cluster where the game server
  instances will be created. The namespace existence will be validated
  during creation. */
    readonly namespace: string;
    /** gke_cluster_reference block */
    readonly gkeClusterReference: GameServicesGameServerClusterConnectionInfoGkeClusterReference[];
}
export interface GameServicesGameServerClusterTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class GameServicesGameServerCluster extends TerraformResource {
    constructor(scope: Construct, id: string, config: GameServicesGameServerClusterConfig);
    private _clusterId;
    get clusterId(): string;
    set clusterId(value: string);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _location?;
    get location(): string | undefined;
    set location(value: string | undefined);
    get name(): string;
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _realmId;
    get realmId(): string;
    set realmId(value: string);
    private _connectionInfo;
    get connectionInfo(): GameServicesGameServerClusterConnectionInfo[];
    set connectionInfo(value: GameServicesGameServerClusterConnectionInfo[]);
    private _timeouts?;
    get timeouts(): GameServicesGameServerClusterTimeouts | undefined;
    set timeouts(value: GameServicesGameServerClusterTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
