import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface IdentityPlatformInboundSamlConfigConfig extends TerraformMetaArguments {
    /** Human friendly display name. */
    readonly displayName: string;
    /** If this config allows users to sign in with the provider. */
    readonly enabled?: boolean;
    /** The name of the InboundSamlConfig resource. Must start with 'saml.' and can only have alphanumeric characters,
  hyphens, underscores or periods. The part after 'saml.' must also start with a lowercase letter, end with an
  alphanumeric character, and have at least 2 characters. */
    readonly name: string;
    readonly project?: string;
    /** idp_config block */
    readonly idpConfig: IdentityPlatformInboundSamlConfigIdpConfig[];
    /** sp_config block */
    readonly spConfig: IdentityPlatformInboundSamlConfigSpConfig[];
    /** timeouts block */
    readonly timeouts?: IdentityPlatformInboundSamlConfigTimeouts;
}
export interface IdentityPlatformInboundSamlConfigIdpConfigIdpCertificates {
    /** The IdP's x509 certificate. */
    readonly x509Certificate?: string;
}
export interface IdentityPlatformInboundSamlConfigIdpConfig {
    /** Unique identifier for all SAML entities */
    readonly idpEntityId: string;
    /** Indicates if outbounding SAMLRequest should be signed. */
    readonly signRequest?: boolean;
    /** URL to send Authentication request to. */
    readonly ssoUrl: string;
    /** idp_certificates block */
    readonly idpCertificates: IdentityPlatformInboundSamlConfigIdpConfigIdpCertificates[];
}
export interface IdentityPlatformInboundSamlConfigSpConfig {
    /** Callback URI where responses from IDP are handled. Must start with 'https://'. */
    readonly callbackUri?: string;
    /** Unique identifier for all SAML entities. */
    readonly spEntityId?: string;
}
export interface IdentityPlatformInboundSamlConfigTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class IdentityPlatformInboundSamlConfig extends TerraformResource {
    constructor(scope: Construct, id: string, config: IdentityPlatformInboundSamlConfigConfig);
    private _displayName;
    get displayName(): string;
    set displayName(value: string);
    private _enabled?;
    get enabled(): boolean | undefined;
    set enabled(value: boolean | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _idpConfig;
    get idpConfig(): IdentityPlatformInboundSamlConfigIdpConfig[];
    set idpConfig(value: IdentityPlatformInboundSamlConfigIdpConfig[]);
    private _spConfig;
    get spConfig(): IdentityPlatformInboundSamlConfigSpConfig[];
    set spConfig(value: IdentityPlatformInboundSamlConfigSpConfig[]);
    private _timeouts?;
    get timeouts(): IdentityPlatformInboundSamlConfigTimeouts | undefined;
    set timeouts(value: IdentityPlatformInboundSamlConfigTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
