import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface KmsCryptoKeyConfig extends TerraformMetaArguments {
    /** The KeyRing that this key belongs to.
  Format: ''projects/{{project}}/locations/{{location}}/keyRings/{{keyRing}}''. */
    readonly keyRing: string;
    /** Labels with user-defined metadata to apply to this resource. */
    readonly labels?: {
        [key: string]: string;
    };
    /** The resource name for the CryptoKey. */
    readonly name: string;
    /** The immutable purpose of this CryptoKey. See the
  [purpose reference](https://cloud.google.com/kms/docs/reference/rest/v1/projects.locations.keyRings.cryptoKeys#CryptoKeyPurpose)
  for possible inputs. Default value: "ENCRYPT_DECRYPT" Possible values: ["ENCRYPT_DECRYPT", "ASYMMETRIC_SIGN", "ASYMMETRIC_DECRYPT"] */
    readonly purpose?: string;
    /** Every time this period passes, generate a new CryptoKeyVersion and set it as the primary.
  The first rotation will take place after the specified period. The rotation period has
  the format of a decimal number with up to 9 fractional digits, followed by the
  letter 's' (seconds). It must be greater than a day (ie, 86400). */
    readonly rotationPeriod?: string;
    /** timeouts block */
    readonly timeouts?: KmsCryptoKeyTimeouts;
    /** version_template block */
    readonly versionTemplate?: KmsCryptoKeyVersionTemplate[];
}
export interface KmsCryptoKeyTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export interface KmsCryptoKeyVersionTemplate {
    /** The algorithm to use when creating a version based on this template.
  See the [algorithm reference](https://cloud.google.com/kms/docs/reference/rest/v1/CryptoKeyVersionAlgorithm) for possible inputs. */
    readonly algorithm: string;
    /** The protection level to use when creating a version based on this template. Default value: "SOFTWARE" Possible values: ["SOFTWARE", "HSM"] */
    readonly protectionLevel?: string;
}
export declare class KmsCryptoKey extends TerraformResource {
    constructor(scope: Construct, id: string, config: KmsCryptoKeyConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _keyRing;
    get keyRing(): string;
    set keyRing(value: string);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _purpose?;
    get purpose(): string | undefined;
    set purpose(value: string | undefined);
    private _rotationPeriod?;
    get rotationPeriod(): string | undefined;
    set rotationPeriod(value: string | undefined);
    get selfLink(): string;
    private _timeouts?;
    get timeouts(): KmsCryptoKeyTimeouts | undefined;
    set timeouts(value: KmsCryptoKeyTimeouts | undefined);
    private _versionTemplate?;
    get versionTemplate(): KmsCryptoKeyVersionTemplate[] | undefined;
    set versionTemplate(value: KmsCryptoKeyVersionTemplate[] | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
