import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface LoggingBillingAccountSinkConfig extends TerraformMetaArguments {
    /** The billing account exported to the sink. */
    readonly billingAccount: string;
    /** The destination of the sink (or, in other words, where logs are written to). Can be a Cloud Storage bucket, a PubSub topic, or a BigQuery dataset. Examples: "storage.googleapis.com/[GCS_BUCKET]" "bigquery.googleapis.com/projects/[PROJECT_ID]/datasets/[DATASET]" "pubsub.googleapis.com/projects/[PROJECT_ID]/topics/[TOPIC_ID]" The writer associated with the sink must have access to write to the above resource. */
    readonly destination: string;
    /** The filter to apply when exporting logs. Only log entries that match the filter are exported. */
    readonly filter?: string;
    /** The name of the logging sink. */
    readonly name: string;
    /** bigquery_options block */
    readonly bigqueryOptions?: LoggingBillingAccountSinkBigqueryOptions[];
}
export interface LoggingBillingAccountSinkBigqueryOptions {
    /** Whether to use BigQuery's partition tables. By default, Logging creates dated tables based on the log entries' timestamps, e.g. syslog_20170523. With partitioned tables the date suffix is no longer present and special query syntax has to be used instead. In both cases, tables are sharded based on UTC timezone. */
    readonly usePartitionedTables: boolean;
}
export declare class LoggingBillingAccountSink extends TerraformResource {
    constructor(scope: Construct, id: string, config: LoggingBillingAccountSinkConfig);
    private _billingAccount;
    get billingAccount(): string;
    set billingAccount(value: string);
    private _destination;
    get destination(): string;
    set destination(value: string);
    private _filter?;
    get filter(): string | undefined;
    set filter(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    get writerIdentity(): string;
    private _bigqueryOptions?;
    get bigqueryOptions(): LoggingBillingAccountSinkBigqueryOptions[] | undefined;
    set bigqueryOptions(value: LoggingBillingAccountSinkBigqueryOptions[] | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
