import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface LoggingFolderSinkConfig extends TerraformMetaArguments {
    /** The destination of the sink (or, in other words, where logs are written to). Can be a Cloud Storage bucket, a PubSub topic, or a BigQuery dataset. Examples: "storage.googleapis.com/[GCS_BUCKET]" "bigquery.googleapis.com/projects/[PROJECT_ID]/datasets/[DATASET]" "pubsub.googleapis.com/projects/[PROJECT_ID]/topics/[TOPIC_ID]" The writer associated with the sink must have access to write to the above resource. */
    readonly destination: string;
    /** The filter to apply when exporting logs. Only log entries that match the filter are exported. */
    readonly filter?: string;
    /** The folder to be exported to the sink. Note that either [FOLDER_ID] or "folders/[FOLDER_ID]" is accepted. */
    readonly folder: string;
    /** Whether or not to include children folders in the sink export. If true, logs associated with child projects are also exported; otherwise only logs relating to the provided folder are included. */
    readonly includeChildren?: boolean;
    /** The name of the logging sink. */
    readonly name: string;
    /** bigquery_options block */
    readonly bigqueryOptions?: LoggingFolderSinkBigqueryOptions[];
}
export interface LoggingFolderSinkBigqueryOptions {
    /** Whether to use BigQuery's partition tables. By default, Logging creates dated tables based on the log entries' timestamps, e.g. syslog_20170523. With partitioned tables the date suffix is no longer present and special query syntax has to be used instead. In both cases, tables are sharded based on UTC timezone. */
    readonly usePartitionedTables: boolean;
}
export declare class LoggingFolderSink extends TerraformResource {
    constructor(scope: Construct, id: string, config: LoggingFolderSinkConfig);
    private _destination;
    get destination(): string;
    set destination(value: string);
    private _filter?;
    get filter(): string | undefined;
    set filter(value: string | undefined);
    private _folder;
    get folder(): string;
    set folder(value: string);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _includeChildren?;
    get includeChildren(): boolean | undefined;
    set includeChildren(value: boolean | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    get writerIdentity(): string;
    private _bigqueryOptions?;
    get bigqueryOptions(): LoggingFolderSinkBigqueryOptions[] | undefined;
    set bigqueryOptions(value: LoggingFolderSinkBigqueryOptions[] | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
