import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface LoggingOrganizationSinkConfig extends TerraformMetaArguments {
    /** The destination of the sink (or, in other words, where logs are written to). Can be a Cloud Storage bucket, a PubSub topic, or a BigQuery dataset. Examples: "storage.googleapis.com/[GCS_BUCKET]" "bigquery.googleapis.com/projects/[PROJECT_ID]/datasets/[DATASET]" "pubsub.googleapis.com/projects/[PROJECT_ID]/topics/[TOPIC_ID]" The writer associated with the sink must have access to write to the above resource. */
    readonly destination: string;
    /** The filter to apply when exporting logs. Only log entries that match the filter are exported. */
    readonly filter?: string;
    /** Whether or not to include children organizations in the sink export. If true, logs associated with child projects are also exported; otherwise only logs relating to the provided organization are included. */
    readonly includeChildren?: boolean;
    /** The name of the logging sink. */
    readonly name: string;
    /** The numeric ID of the organization to be exported to the sink. */
    readonly orgId: string;
    /** bigquery_options block */
    readonly bigqueryOptions?: LoggingOrganizationSinkBigqueryOptions[];
}
export interface LoggingOrganizationSinkBigqueryOptions {
    /** Whether to use BigQuery's partition tables. By default, Logging creates dated tables based on the log entries' timestamps, e.g. syslog_20170523. With partitioned tables the date suffix is no longer present and special query syntax has to be used instead. In both cases, tables are sharded based on UTC timezone. */
    readonly usePartitionedTables: boolean;
}
export declare class LoggingOrganizationSink extends TerraformResource {
    constructor(scope: Construct, id: string, config: LoggingOrganizationSinkConfig);
    private _destination;
    get destination(): string;
    set destination(value: string);
    private _filter?;
    get filter(): string | undefined;
    set filter(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _includeChildren?;
    get includeChildren(): boolean | undefined;
    set includeChildren(value: boolean | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _orgId;
    get orgId(): string;
    set orgId(value: string);
    get writerIdentity(): string;
    private _bigqueryOptions?;
    get bigqueryOptions(): LoggingOrganizationSinkBigqueryOptions[] | undefined;
    set bigqueryOptions(value: LoggingOrganizationSinkBigqueryOptions[] | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
