import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface LoggingProjectSinkConfig extends TerraformMetaArguments {
    /** The destination of the sink (or, in other words, where logs are written to). Can be a Cloud Storage bucket, a PubSub topic, or a BigQuery dataset. Examples: "storage.googleapis.com/[GCS_BUCKET]" "bigquery.googleapis.com/projects/[PROJECT_ID]/datasets/[DATASET]" "pubsub.googleapis.com/projects/[PROJECT_ID]/topics/[TOPIC_ID]" The writer associated with the sink must have access to write to the above resource. */
    readonly destination: string;
    /** The filter to apply when exporting logs. Only log entries that match the filter are exported. */
    readonly filter?: string;
    /** The name of the logging sink. */
    readonly name: string;
    /** The ID of the project to create the sink in. If omitted, the project associated with the provider is used. */
    readonly project?: string;
    /** Whether or not to create a unique identity associated with this sink. If false (the default), then the writer_identity used is serviceAccount:cloud-logs@system.gserviceaccount.com. If true, then a unique service account is created and used for this sink. If you wish to publish logs across projects, you must set unique_writer_identity to true. */
    readonly uniqueWriterIdentity?: boolean;
    /** bigquery_options block */
    readonly bigqueryOptions?: LoggingProjectSinkBigqueryOptions[];
}
export interface LoggingProjectSinkBigqueryOptions {
    /** Whether to use BigQuery's partition tables. By default, Logging creates dated tables based on the log entries' timestamps, e.g. syslog_20170523. With partitioned tables the date suffix is no longer present and special query syntax has to be used instead. In both cases, tables are sharded based on UTC timezone. */
    readonly usePartitionedTables: boolean;
}
export declare class LoggingProjectSink extends TerraformResource {
    constructor(scope: Construct, id: string, config: LoggingProjectSinkConfig);
    private _destination;
    get destination(): string;
    set destination(value: string);
    private _filter?;
    get filter(): string | undefined;
    set filter(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _uniqueWriterIdentity?;
    get uniqueWriterIdentity(): boolean | undefined;
    set uniqueWriterIdentity(value: boolean | undefined);
    get writerIdentity(): string;
    private _bigqueryOptions?;
    get bigqueryOptions(): LoggingProjectSinkBigqueryOptions[] | undefined;
    set bigqueryOptions(value: LoggingProjectSinkBigqueryOptions[] | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
