import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface MlEngineModelConfig extends TerraformMetaArguments {
    /** The description specified for the model when it was created. */
    readonly description?: string;
    /** One or more labels that you can add, to organize your models. */
    readonly labels?: {
        [key: string]: string;
    };
    /** The name specified for the model. */
    readonly name: string;
    /** If true, online prediction nodes send stderr and stdout streams to Stackdriver Logging */
    readonly onlinePredictionConsoleLogging?: boolean;
    /** If true, online prediction access logs are sent to StackDriver Logging. */
    readonly onlinePredictionLogging?: boolean;
    readonly project?: string;
    /** The list of regions where the model is going to be deployed.
  Currently only one region per model is supported */
    readonly regions?: string[];
    /** default_version block */
    readonly defaultVersion?: MlEngineModelDefaultVersion[];
    /** timeouts block */
    readonly timeouts?: MlEngineModelTimeouts;
}
export interface MlEngineModelDefaultVersion {
    /** The name specified for the version when it was created. */
    readonly name: string;
}
export interface MlEngineModelTimeouts {
    readonly create?: string;
    readonly delete?: string;
}
export declare class MlEngineModel extends TerraformResource {
    constructor(scope: Construct, id: string, config: MlEngineModelConfig);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _onlinePredictionConsoleLogging?;
    get onlinePredictionConsoleLogging(): boolean | undefined;
    set onlinePredictionConsoleLogging(value: boolean | undefined);
    private _onlinePredictionLogging?;
    get onlinePredictionLogging(): boolean | undefined;
    set onlinePredictionLogging(value: boolean | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _regions?;
    get regions(): string[] | undefined;
    set regions(value: string[] | undefined);
    private _defaultVersion?;
    get defaultVersion(): MlEngineModelDefaultVersion[] | undefined;
    set defaultVersion(value: MlEngineModelDefaultVersion[] | undefined);
    private _timeouts?;
    get timeouts(): MlEngineModelTimeouts | undefined;
    set timeouts(value: MlEngineModelTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
