import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface MonitoringUptimeCheckConfigConfig extends TerraformMetaArguments {
    /** A human-friendly name for the uptime check configuration. The display name should be unique within a Stackdriver Workspace in order to make it easier to identify; however, uniqueness is not enforced. */
    readonly displayName: string;
    readonly isInternal?: boolean;
    /** How often, in seconds, the uptime check is performed. Currently, the only supported values are 60s (1 minute), 300s (5 minutes), 600s (10 minutes), and 900s (15 minutes). Optional, defaults to 300s. */
    readonly period?: string;
    readonly project?: string;
    /** The list of regions from which the check will be run. Some regions contain one location, and others contain more than one. If this field is specified, enough regions to include a minimum of 3 locations must be provided, or an error message is returned. Not specifying this field will result in uptime checks running from all regions. */
    readonly selectedRegions?: string[];
    /** The maximum amount of time to wait for the request to complete (must be between 1 and 60 seconds). Accepted formats https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#google.protobuf.Duration */
    readonly timeout: string;
    /** content_matchers block */
    readonly contentMatchers?: MonitoringUptimeCheckConfigContentMatchers[];
    /** http_check block */
    readonly httpCheck?: MonitoringUptimeCheckConfigHttpCheck[];
    /** internal_checkers block */
    readonly internalCheckers?: MonitoringUptimeCheckConfigInternalCheckers[];
    /** monitored_resource block */
    readonly monitoredResource?: MonitoringUptimeCheckConfigMonitoredResource[];
    /** resource_group block */
    readonly resourceGroup?: MonitoringUptimeCheckConfigResourceGroup[];
    /** tcp_check block */
    readonly tcpCheck?: MonitoringUptimeCheckConfigTcpCheck[];
    /** timeouts block */
    readonly timeouts?: MonitoringUptimeCheckConfigTimeouts;
}
export interface MonitoringUptimeCheckConfigContentMatchers {
    /** String or regex content to match (max 1024 bytes) */
    readonly content: string;
    /** The type of content matcher that will be applied to the server output, compared to the content string when the check is run. Default value: "CONTAINS_STRING" Possible values: ["CONTAINS_STRING", "NOT_CONTAINS_STRING", "MATCHES_REGEX", "NON_MATCHES_REGEX"] */
    readonly matcher?: string;
}
export interface MonitoringUptimeCheckConfigHttpCheckAuthInfo {
    /** The password to authenticate. */
    readonly password: string;
    /** The username to authenticate. */
    readonly username: string;
}
export interface MonitoringUptimeCheckConfigHttpCheck {
    /** The request body associated with the HTTP POST request. If contentType is URL_ENCODED, the body passed in must be URL-encoded. Users can provide a Content-Length header via the headers field or the API will do so. If the requestMethod is GET and body is not empty, the API will return an error. The maximum byte size is 1 megabyte. Note - As with all bytes fields JSON representations are base64 encoded. e.g. "foo=bar" in URL-encoded form is "foo%3Dbar" and in base64 encoding is "Zm9vJTI1M0RiYXI=". */
    readonly body?: string;
    /** The content type to use for the check. Possible values: ["TYPE_UNSPECIFIED", "URL_ENCODED"] */
    readonly contentType?: string;
    /** The list of headers to send as part of the uptime check request. If two headers have the same key and different values, they should be entered as a single header, with the value being a comma-separated list of all the desired values as described at https://www.w3.org/Protocols/rfc2616/rfc2616.txt (page 31). Entering two separate headers with the same key in a Create call will cause the first to be overwritten by the second. The maximum number of headers allowed is 100. */
    readonly headers?: {
        [key: string]: string;
    };
    /** Boolean specifying whether to encrypt the header information. Encryption should be specified for any headers related to authentication that you do not wish to be seen when retrieving the configuration. The server will be responsible for encrypting the headers. On Get/List calls, if mask_headers is set to True then the headers will be obscured with ******. */
    readonly maskHeaders?: boolean;
    /** The path to the page to run the check against. Will be combined with the host (specified within the MonitoredResource) and port to construct the full URL. Optional (defaults to "/"). */
    readonly path?: string;
    /** The port to the page to run the check against. Will be combined with host (specified within the MonitoredResource) and path to construct the full URL. Optional (defaults to 80 without SSL, or 443 with SSL). */
    readonly port?: number;
    /** The HTTP request method to use for the check. If set to METHOD_UNSPECIFIED then requestMethod defaults to GET. Default value: "GET" Possible values: ["METHOD_UNSPECIFIED", "GET", "POST"] */
    readonly requestMethod?: string;
    /** If true, use HTTPS instead of HTTP to run the check. */
    readonly useSsl?: boolean;
    /** Boolean specifying whether to include SSL certificate validation as a part of the Uptime check. Only applies to checks where monitoredResource is set to uptime_url. If useSsl is false, setting validateSsl to true has no effect. */
    readonly validateSsl?: boolean;
    /** auth_info block */
    readonly authInfo?: MonitoringUptimeCheckConfigHttpCheckAuthInfo[];
}
export interface MonitoringUptimeCheckConfigInternalCheckers {
    readonly displayName?: string;
    readonly gcpZone?: string;
    readonly name?: string;
    readonly network?: string;
    readonly peerProjectId?: string;
}
export interface MonitoringUptimeCheckConfigMonitoredResource {
    /** Values for all of the labels listed in the associated monitored resource descriptor. For example, Compute Engine VM instances use the labels "project_id", "instance_id", and "zone". */
    readonly labels: {
        [key: string]: string;
    };
    /** The monitored resource type. This field must match the type field of a MonitoredResourceDescriptor (https://cloud.google.com/monitoring/api/ref_v3/rest/v3/projects.monitoredResourceDescriptors#MonitoredResourceDescriptor) object. For example, the type of a Compute Engine VM instance is gce_instance. For a list of types, see Monitoring resource types (https://cloud.google.com/monitoring/api/resources) and Logging resource types (https://cloud.google.com/logging/docs/api/v2/resource-list). */
    readonly type: string;
}
export interface MonitoringUptimeCheckConfigResourceGroup {
    /** The group of resources being monitored. Should be the 'name' of a group */
    readonly groupId?: string;
    /** The resource type of the group members. Possible values: ["RESOURCE_TYPE_UNSPECIFIED", "INSTANCE", "AWS_ELB_LOAD_BALANCER"] */
    readonly resourceType?: string;
}
export interface MonitoringUptimeCheckConfigTcpCheck {
    /** The port to the page to run the check against. Will be combined with host (specified within the MonitoredResource) to construct the full URL. */
    readonly port: number;
}
export interface MonitoringUptimeCheckConfigTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class MonitoringUptimeCheckConfig extends TerraformResource {
    constructor(scope: Construct, id: string, config: MonitoringUptimeCheckConfigConfig);
    private _displayName;
    get displayName(): string;
    set displayName(value: string);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _isInternal?;
    get isInternal(): boolean | undefined;
    set isInternal(value: boolean | undefined);
    get name(): string;
    private _period?;
    get period(): string | undefined;
    set period(value: string | undefined);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _selectedRegions?;
    get selectedRegions(): string[] | undefined;
    set selectedRegions(value: string[] | undefined);
    private _timeout;
    get timeout(): string;
    set timeout(value: string);
    get uptimeCheckId(): string;
    private _contentMatchers?;
    get contentMatchers(): MonitoringUptimeCheckConfigContentMatchers[] | undefined;
    set contentMatchers(value: MonitoringUptimeCheckConfigContentMatchers[] | undefined);
    private _httpCheck?;
    get httpCheck(): MonitoringUptimeCheckConfigHttpCheck[] | undefined;
    set httpCheck(value: MonitoringUptimeCheckConfigHttpCheck[] | undefined);
    private _internalCheckers?;
    get internalCheckers(): MonitoringUptimeCheckConfigInternalCheckers[] | undefined;
    set internalCheckers(value: MonitoringUptimeCheckConfigInternalCheckers[] | undefined);
    private _monitoredResource?;
    get monitoredResource(): MonitoringUptimeCheckConfigMonitoredResource[] | undefined;
    set monitoredResource(value: MonitoringUptimeCheckConfigMonitoredResource[] | undefined);
    private _resourceGroup?;
    get resourceGroup(): MonitoringUptimeCheckConfigResourceGroup[] | undefined;
    set resourceGroup(value: MonitoringUptimeCheckConfigResourceGroup[] | undefined);
    private _tcpCheck?;
    get tcpCheck(): MonitoringUptimeCheckConfigTcpCheck[] | undefined;
    set tcpCheck(value: MonitoringUptimeCheckConfigTcpCheck[] | undefined);
    private _timeouts?;
    get timeouts(): MonitoringUptimeCheckConfigTimeouts | undefined;
    set timeouts(value: MonitoringUptimeCheckConfigTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
