import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ProjectConfig extends TerraformMetaArguments {
    /** Create the 'default' network automatically.  Default true. If set to false, the default network will be deleted.  Note that, for quota purposes, you will still need to have 1 network slot available to create the project successfully, even if you set auto_create_network to false, since the network will exist momentarily. */
    readonly autoCreateNetwork?: boolean;
    /** The alphanumeric ID of the billing account this project belongs to. The user or service account performing this operation with Terraform must have Billing Account Administrator privileges (roles/billing.admin) in the organization. See Google Cloud Billing API Access Control for more details. */
    readonly billingAccount?: string;
    /** The numeric ID of the folder this project should be created under. Only one of org_id or folder_id may be specified. If the folder_id is specified, then the project is created under the specified folder. Changing this forces the project to be migrated to the newly specified folder. */
    readonly folderId?: string;
    /** A set of key/value label pairs to assign to the project. */
    readonly labels?: {
        [key: string]: string;
    };
    /** The display name of the project. */
    readonly name: string;
    /** The numeric ID of the organization this project belongs to. Changing this forces a new project to be created.  Only one of org_id or folder_id may be specified. If the org_id is specified then the project is created at the top level. Changing this forces the project to be migrated to the newly specified organization. */
    readonly orgId?: string;
    /** The project ID. Changing this forces a new project to be created. */
    readonly projectId: string;
    /** If true, the Terraform resource can be deleted without deleting the Project via the Google API. */
    readonly skipDelete?: boolean;
    /** timeouts block */
    readonly timeouts?: ProjectTimeouts;
}
export interface ProjectTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly read?: string;
    readonly update?: string;
}
export declare class Project extends TerraformResource {
    constructor(scope: Construct, id: string, config: ProjectConfig);
    private _autoCreateNetwork?;
    get autoCreateNetwork(): boolean | undefined;
    set autoCreateNetwork(value: boolean | undefined);
    private _billingAccount?;
    get billingAccount(): string | undefined;
    set billingAccount(value: string | undefined);
    private _folderId?;
    get folderId(): string | undefined;
    set folderId(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    get number(): string;
    private _orgId?;
    get orgId(): string | undefined;
    set orgId(value: string | undefined);
    private _projectId;
    get projectId(): string;
    set projectId(value: string);
    private _skipDelete?;
    get skipDelete(): boolean | undefined;
    set skipDelete(value: boolean | undefined);
    private _timeouts?;
    get timeouts(): ProjectTimeouts | undefined;
    set timeouts(value: ProjectTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
