import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface PubsubTopicConfig extends TerraformMetaArguments {
    /** The resource name of the Cloud KMS CryptoKey to be used to protect access
  to messages published on this topic. Your project's PubSub service account
  ('service-{{PROJECT_NUMBER}}@gcp-sa-pubsub.iam.gserviceaccount.com') must have
  'roles/cloudkms.cryptoKeyEncrypterDecrypter' to use this feature.
  The expected format is 'projects/*\/locations/*\/keyRings/*\/cryptoKeys/*' */
    readonly kmsKeyName?: string;
    /** A set of key/value label pairs to assign to this Topic. */
    readonly labels?: {
        [key: string]: string;
    };
    /** Name of the topic. */
    readonly name: string;
    readonly project?: string;
    /** message_storage_policy block */
    readonly messageStoragePolicy?: PubsubTopicMessageStoragePolicy[];
    /** timeouts block */
    readonly timeouts?: PubsubTopicTimeouts;
}
export interface PubsubTopicMessageStoragePolicy {
    /** A list of IDs of GCP regions where messages that are published to
  the topic may be persisted in storage. Messages published by
  publishers running in non-allowed GCP regions (or running outside
  of GCP altogether) will be routed for storage in one of the
  allowed regions. An empty list means that no regions are allowed,
  and is not a valid configuration. */
    readonly allowedPersistenceRegions: string[];
}
export interface PubsubTopicTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class PubsubTopic extends TerraformResource {
    constructor(scope: Construct, id: string, config: PubsubTopicConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _kmsKeyName?;
    get kmsKeyName(): string | undefined;
    set kmsKeyName(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _messageStoragePolicy?;
    get messageStoragePolicy(): PubsubTopicMessageStoragePolicy[] | undefined;
    set messageStoragePolicy(value: PubsubTopicMessageStoragePolicy[] | undefined);
    private _timeouts?;
    get timeouts(): PubsubTopicTimeouts | undefined;
    set timeouts(value: PubsubTopicTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
