import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface RedisInstanceConfig extends TerraformMetaArguments {
    /** Only applicable to STANDARD_HA tier which protects the instance
  against zonal failures by provisioning it across two zones.
  If provided, it must be a different zone from the one provided in
  [locationId]. */
    readonly alternativeLocationId?: string;
    /** The full name of the Google Compute Engine network to which the
  instance is connected. If left unspecified, the default network
  will be used. */
    readonly authorizedNetwork?: string;
    /** The connection mode of the Redis instance. Default value: "DIRECT_PEERING" Possible values: ["DIRECT_PEERING", "PRIVATE_SERVICE_ACCESS"] */
    readonly connectMode?: string;
    /** An arbitrary and optional user-provided name for the instance. */
    readonly displayName?: string;
    /** Resource labels to represent user provided metadata. */
    readonly labels?: {
        [key: string]: string;
    };
    /** The zone where the instance will be provisioned. If not provided,
  the service will choose a zone for the instance. For STANDARD_HA tier,
  instances will be created across two zones for protection against
  zonal failures. If [alternativeLocationId] is also provided, it must
  be different from [locationId]. */
    readonly locationId?: string;
    /** Redis memory size in GiB. */
    readonly memorySizeGb: number;
    /** The ID of the instance or a fully qualified identifier for the instance. */
    readonly name: string;
    readonly project?: string;
    /** Redis configuration parameters, according to http://redis.io/topics/config.
  Please check Memorystore documentation for the list of supported parameters:
  https://cloud.google.com/memorystore/docs/redis/reference/rest/v1/projects.locations.instances#Instance.FIELDS.redis_configs */
    readonly redisConfigs?: {
        [key: string]: string;
    };
    /** The version of Redis software. If not provided, latest supported
  version will be used. Currently, the supported values are:
  
  - REDIS_5_0 for Redis 5.0 compatibility
  - REDIS_4_0 for Redis 4.0 compatibility
  - REDIS_3_2 for Redis 3.2 compatibility */
    readonly redisVersion?: string;
    /** The name of the Redis region of the instance. */
    readonly region?: string;
    /** The CIDR range of internal addresses that are reserved for this
  instance. If not provided, the service will choose an unused /29
  block, for example, 10.0.0.0/29 or 192.168.0.0/29. Ranges must be
  unique and non-overlapping with existing subnets in an authorized
  network. */
    readonly reservedIpRange?: string;
    /** The service tier of the instance. Must be one of these values:
  
  - BASIC: standalone instance
  - STANDARD_HA: highly available primary/replica instances Default value: "BASIC" Possible values: ["BASIC", "STANDARD_HA"] */
    readonly tier?: string;
    /** timeouts block */
    readonly timeouts?: RedisInstanceTimeouts;
}
export interface RedisInstanceTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class RedisInstance extends TerraformResource {
    constructor(scope: Construct, id: string, config: RedisInstanceConfig);
    private _alternativeLocationId?;
    get alternativeLocationId(): string | undefined;
    set alternativeLocationId(value: string | undefined);
    private _authorizedNetwork?;
    get authorizedNetwork(): string | undefined;
    set authorizedNetwork(value: string | undefined);
    private _connectMode?;
    get connectMode(): string | undefined;
    set connectMode(value: string | undefined);
    get createTime(): string;
    get currentLocationId(): string;
    private _displayName?;
    get displayName(): string | undefined;
    set displayName(value: string | undefined);
    get host(): string;
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _locationId?;
    get locationId(): string | undefined;
    set locationId(value: string | undefined);
    private _memorySizeGb;
    get memorySizeGb(): number;
    set memorySizeGb(value: number);
    private _name;
    get name(): string;
    set name(value: string);
    get persistenceIamIdentity(): string;
    get port(): number;
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _redisConfigs?;
    get redisConfigs(): {
        [key: string]: string;
    } | undefined;
    set redisConfigs(value: {
        [key: string]: string;
    } | undefined);
    private _redisVersion?;
    get redisVersion(): string | undefined;
    set redisVersion(value: string | undefined);
    private _region?;
    get region(): string | undefined;
    set region(value: string | undefined);
    private _reservedIpRange?;
    get reservedIpRange(): string | undefined;
    set reservedIpRange(value: string | undefined);
    private _tier?;
    get tier(): string | undefined;
    set tier(value: string | undefined);
    private _timeouts?;
    get timeouts(): RedisInstanceTimeouts | undefined;
    set timeouts(value: RedisInstanceTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
