import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface SecretManagerSecretConfig extends TerraformMetaArguments {
    /** The labels assigned to this Secret.
  
  Label keys must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes,
  and must conform to the following PCRE regular expression: [\p{Ll}\p{Lo}][\p{Ll}\p{Lo}\p{N}_-]{0,62}
  
  Label values must be between 0 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes,
  and must conform to the following PCRE regular expression: [\p{Ll}\p{Lo}\p{N}_-]{0,63}
  
  No more than 64 labels can be assigned to a given resource.
  
  An object containing a list of "key": value pairs. Example:
  { "name": "wrench", "mass": "1.3kg", "count": "3" }. */
    readonly labels?: {
        [key: string]: string;
    };
    readonly project?: string;
    /** This must be unique within the project. */
    readonly secretId: string;
    /** replication block */
    readonly replication: SecretManagerSecretReplication[];
    /** timeouts block */
    readonly timeouts?: SecretManagerSecretTimeouts;
}
export interface SecretManagerSecretReplicationUserManagedReplicas {
    /** The canonical IDs of the location to replicate data. For example: "us-east1". */
    readonly location: string;
}
export interface SecretManagerSecretReplicationUserManaged {
    /** replicas block */
    readonly replicas: SecretManagerSecretReplicationUserManagedReplicas[];
}
export interface SecretManagerSecretReplication {
    /** The Secret will automatically be replicated without any restrictions. */
    readonly automatic?: boolean;
    /** user_managed block */
    readonly userManaged?: SecretManagerSecretReplicationUserManaged[];
}
export interface SecretManagerSecretTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class SecretManagerSecret extends TerraformResource {
    constructor(scope: Construct, id: string, config: SecretManagerSecretConfig);
    get createTime(): string;
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    get name(): string;
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _secretId;
    get secretId(): string;
    set secretId(value: string);
    private _replication;
    get replication(): SecretManagerSecretReplication[];
    set replication(value: SecretManagerSecretReplication[]);
    private _timeouts?;
    get timeouts(): SecretManagerSecretTimeouts | undefined;
    set timeouts(value: SecretManagerSecretTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
