import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ServiceAccountKeyConfig extends TerraformMetaArguments {
    /** The algorithm used to generate the key, used only on create. KEY_ALG_RSA_2048 is the default algorithm. Valid values are: "KEY_ALG_RSA_1024", "KEY_ALG_RSA_2048". */
    readonly keyAlgorithm?: string;
    readonly pgpKey?: string;
    readonly privateKeyType?: string;
    /** A field that allows clients to upload their own public key. If set, use this public key data to create a service account key for given service account. Please note, the expected format for this field is a base64 encoded X509_PEM. */
    readonly publicKeyData?: string;
    readonly publicKeyType?: string;
    /** The ID of the parent service account of the key. This can be a string in the format {ACCOUNT} or projects/{PROJECT_ID}/serviceAccounts/{ACCOUNT}, where {ACCOUNT} is the email address or unique id of the service account. If the {ACCOUNT} syntax is used, the project will be inferred from the account. */
    readonly serviceAccountId: string;
}
export declare class ServiceAccountKey extends TerraformResource {
    constructor(scope: Construct, id: string, config: ServiceAccountKeyConfig);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _keyAlgorithm?;
    get keyAlgorithm(): string | undefined;
    set keyAlgorithm(value: string | undefined);
    get name(): string;
    private _pgpKey?;
    get pgpKey(): string | undefined;
    set pgpKey(value: string | undefined);
    get privateKey(): string;
    get privateKeyEncrypted(): string;
    get privateKeyFingerprint(): string;
    private _privateKeyType?;
    get privateKeyType(): string | undefined;
    set privateKeyType(value: string | undefined);
    get publicKey(): string;
    private _publicKeyData?;
    get publicKeyData(): string | undefined;
    set publicKeyData(value: string | undefined);
    private _publicKeyType?;
    get publicKeyType(): string | undefined;
    set publicKeyType(value: string | undefined);
    private _serviceAccountId;
    get serviceAccountId(): string;
    set serviceAccountId(value: string);
    get validAfter(): string;
    get validBefore(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
