import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface ServiceAccountConfig extends TerraformMetaArguments {
    /** The account id that is used to generate the service account email address and a stable unique id. It is unique within a project, must be 6-30 characters long, and match the regular expression [a-z]([-a-z0-9]*[a-z0-9]) to comply with RFC1035. Changing this forces a new service account to be created. */
    readonly accountId: string;
    /** A text description of the service account. Must be less than or equal to 256 UTF-8 bytes. */
    readonly description?: string;
    /** The display name for the service account. Can be updated without creating a new resource. */
    readonly displayName?: string;
    /** The ID of the project that the service account will be created in. Defaults to the provider project configuration. */
    readonly project?: string;
    /** timeouts block */
    readonly timeouts?: ServiceAccountTimeouts;
}
export interface ServiceAccountTimeouts {
    readonly create?: string;
}
export declare class ServiceAccount extends TerraformResource {
    constructor(scope: Construct, id: string, config: ServiceAccountConfig);
    private _accountId;
    get accountId(): string;
    set accountId(value: string);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _displayName?;
    get displayName(): string | undefined;
    set displayName(value: string | undefined);
    get email(): string;
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get name(): string;
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get uniqueId(): string;
    private _timeouts?;
    get timeouts(): ServiceAccountTimeouts | undefined;
    set timeouts(value: ServiceAccountTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
