import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface SqlDatabaseConfig extends TerraformMetaArguments {
    /** The charset value. See MySQL's
  [Supported Character Sets and Collations](https://dev.mysql.com/doc/refman/5.7/en/charset-charsets.html)
  and Postgres' [Character Set Support](https://www.postgresql.org/docs/9.6/static/multibyte.html)
  for more details and supported values. Postgres databases only support
  a value of 'UTF8' at creation time. */
    readonly charset?: string;
    /** The collation value. See MySQL's
  [Supported Character Sets and Collations](https://dev.mysql.com/doc/refman/5.7/en/charset-charsets.html)
  and Postgres' [Collation Support](https://www.postgresql.org/docs/9.6/static/collation.html)
  for more details and supported values. Postgres databases only support
  a value of 'en_US.UTF8' at creation time. */
    readonly collation?: string;
    /** The name of the Cloud SQL instance. This does not include the project
  ID. */
    readonly instance: string;
    /** The name of the database in the Cloud SQL instance.
  This does not include the project ID or instance name. */
    readonly name: string;
    readonly project?: string;
    /** timeouts block */
    readonly timeouts?: SqlDatabaseTimeouts;
}
export interface SqlDatabaseTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class SqlDatabase extends TerraformResource {
    constructor(scope: Construct, id: string, config: SqlDatabaseConfig);
    private _charset?;
    get charset(): string | undefined;
    set charset(value: string | undefined);
    private _collation?;
    get collation(): string | undefined;
    set collation(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _instance;
    get instance(): string;
    set instance(value: string);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get selfLink(): string;
    private _timeouts?;
    get timeouts(): SqlDatabaseTimeouts | undefined;
    set timeouts(value: SqlDatabaseTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
