import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface StorageBucketObjectConfig extends TerraformMetaArguments {
    /** The name of the containing bucket. */
    readonly bucket: string;
    /** Cache-Control directive to specify caching behavior of object data. If omitted and object is accessible to all anonymous users, the default will be public, max-age=3600 */
    readonly cacheControl?: string;
    /** Data as string to be uploaded. Must be defined if source is not. Note: The content field is marked as sensitive. To view the raw contents of the object, please define an output. */
    readonly content?: string;
    /** Content-Disposition of the object data. */
    readonly contentDisposition?: string;
    /** Content-Encoding of the object data. */
    readonly contentEncoding?: string;
    /** Content-Language of the object data. */
    readonly contentLanguage?: string;
    /** Content-Type of the object data. Defaults to "application/octet-stream" or "text/plain; charset=utf-8". */
    readonly contentType?: string;
    readonly detectMd5Hash?: string;
    /** User-provided metadata, in key/value pairs. */
    readonly metadata?: {
        [key: string]: string;
    };
    /** The name of the object. If you're interpolating the name of this object, see output_name instead. */
    readonly name: string;
    /** A path to the data you want to upload. Must be defined if content is not. */
    readonly source?: string;
    /** The StorageClass of the new bucket object. Supported values include: MULTI_REGIONAL, REGIONAL, NEARLINE, COLDLINE, ARCHIVE. If not provided, this defaults to the bucket's default storage class or to a standard class. */
    readonly storageClass?: string;
}
export declare class StorageBucketObject extends TerraformResource {
    constructor(scope: Construct, id: string, config: StorageBucketObjectConfig);
    private _bucket;
    get bucket(): string;
    set bucket(value: string);
    private _cacheControl?;
    get cacheControl(): string | undefined;
    set cacheControl(value: string | undefined);
    private _content?;
    get content(): string | undefined;
    set content(value: string | undefined);
    private _contentDisposition?;
    get contentDisposition(): string | undefined;
    set contentDisposition(value: string | undefined);
    private _contentEncoding?;
    get contentEncoding(): string | undefined;
    set contentEncoding(value: string | undefined);
    private _contentLanguage?;
    get contentLanguage(): string | undefined;
    set contentLanguage(value: string | undefined);
    private _contentType?;
    get contentType(): string | undefined;
    set contentType(value: string | undefined);
    get crc32C(): string;
    private _detectMd5Hash?;
    get detectMd5Hash(): string | undefined;
    set detectMd5Hash(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get md5Hash(): string;
    get mediaLink(): string;
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    } | undefined;
    set metadata(value: {
        [key: string]: string;
    } | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    get outputName(): string;
    get selfLink(): string;
    private _source?;
    get source(): string | undefined;
    set source(value: string | undefined);
    private _storageClass?;
    get storageClass(): string | undefined;
    set storageClass(value: string | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
