import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface StorageBucketConfig extends TerraformMetaArguments {
    /** Enables Bucket Policy Only access to a bucket. */
    readonly bucketPolicyOnly?: boolean;
    readonly defaultEventBasedHold?: boolean;
    /** When deleting a bucket, this boolean option will delete all contained objects. If you try to delete a bucket that contains objects, Terraform will fail that run. */
    readonly forceDestroy?: boolean;
    /** A set of key/value label pairs to assign to the bucket. */
    readonly labels?: {
        [key: string]: string;
    };
    /** The GCS location */
    readonly location?: string;
    /** The name of the bucket. */
    readonly name: string;
    /** The ID of the project in which the resource belongs. If it is not provided, the provider project is used. */
    readonly project?: string;
    /** Enables Requester Pays on a storage bucket. */
    readonly requesterPays?: boolean;
    /** The Storage Class of the new bucket. Supported values include: STANDARD, MULTI_REGIONAL, REGIONAL, NEARLINE, COLDLINE, ARCHIVE. */
    readonly storageClass?: string;
    /** cors block */
    readonly cors?: StorageBucketCors[];
    /** encryption block */
    readonly encryption?: StorageBucketEncryption[];
    /** lifecycle_rule block */
    readonly lifecycleRule?: StorageBucketLifecycleRule[];
    /** logging block */
    readonly logging?: StorageBucketLogging[];
    /** retention_policy block */
    readonly retentionPolicy?: StorageBucketRetentionPolicy[];
    /** versioning block */
    readonly versioning?: StorageBucketVersioning[];
    /** website block */
    readonly website?: StorageBucketWebsite[];
}
export interface StorageBucketCors {
    /** The value, in seconds, to return in the Access-Control-Max-Age header used in preflight responses. */
    readonly maxAgeSeconds?: number;
    /** The list of HTTP methods on which to include CORS response headers, (GET, OPTIONS, POST, etc) Note: "*" is permitted in the list of methods, and means "any method". */
    readonly method?: string[];
    /** The list of Origins eligible to receive CORS response headers. Note: "*" is permitted in the list of origins, and means "any Origin". */
    readonly origin?: string[];
    /** The list of HTTP headers other than the simple response headers to give permission for the user-agent to share across domains. */
    readonly responseHeader?: string[];
}
export interface StorageBucketEncryption {
    /** A Cloud KMS key that will be used to encrypt objects inserted into this bucket, if no encryption method is specified. You must pay attention to whether the crypto key is available in the location that this bucket is created in. See the docs for more details. */
    readonly defaultKmsKeyName: string;
}
export interface StorageBucketLifecycleRuleAction {
    /** The target Storage Class of objects affected by this Lifecycle Rule. Supported values include: MULTI_REGIONAL, REGIONAL, NEARLINE, COLDLINE, ARCHIVE. */
    readonly storageClass?: string;
    /** The type of the action of this Lifecycle Rule. Supported values include: Delete and SetStorageClass. */
    readonly type: string;
}
export interface StorageBucketLifecycleRuleCondition {
    /** Minimum age of an object in days to satisfy this condition. */
    readonly age?: number;
    /** Creation date of an object in RFC 3339 (e.g. 2017-06-13) to satisfy this condition. */
    readonly createdBefore?: string;
    readonly isLive?: boolean;
    /** Storage Class of objects to satisfy this condition. Supported values include: MULTI_REGIONAL, REGIONAL, NEARLINE, COLDLINE, ARCHIVE, STANDARD, DURABLE_REDUCED_AVAILABILITY. */
    readonly matchesStorageClass?: string[];
    /** Relevant only for versioned objects. The number of newer versions of an object to satisfy this condition. */
    readonly numNewerVersions?: number;
    /** Match to live and/or archived objects. Unversioned buckets have only live objects. Supported values include: "LIVE", "ARCHIVED", "ANY". */
    readonly withState?: string;
}
export interface StorageBucketLifecycleRule {
    /** action block */
    readonly action: StorageBucketLifecycleRuleAction[];
    /** condition block */
    readonly condition: StorageBucketLifecycleRuleCondition[];
}
export interface StorageBucketLogging {
    /** The bucket that will receive log objects. */
    readonly logBucket: string;
    /** The object prefix for log objects. If it's not provided, by default GCS sets this to this bucket's name. */
    readonly logObjectPrefix?: string;
}
export interface StorageBucketRetentionPolicy {
    /** If set to true, the bucket will be locked and permanently restrict edits to the bucket's retention policy.  Caution: Locking a bucket is an irreversible action. */
    readonly isLocked?: boolean;
    /** The period of time, in seconds, that objects in the bucket must be retained and cannot be deleted, overwritten, or archived. The value must be less than 3,155,760,000 seconds. */
    readonly retentionPeriod: number;
}
export interface StorageBucketVersioning {
    /** While set to true, versioning is fully enabled for this bucket. */
    readonly enabled: boolean;
}
export interface StorageBucketWebsite {
    /** Behaves as the bucket's directory index where missing objects are treated as potential directories. */
    readonly mainPageSuffix?: string;
    /** The custom object to return when a requested resource is not found. */
    readonly notFoundPage?: string;
}
export declare class StorageBucket extends TerraformResource {
    constructor(scope: Construct, id: string, config: StorageBucketConfig);
    private _bucketPolicyOnly?;
    get bucketPolicyOnly(): boolean | undefined;
    set bucketPolicyOnly(value: boolean | undefined);
    private _defaultEventBasedHold?;
    get defaultEventBasedHold(): boolean | undefined;
    set defaultEventBasedHold(value: boolean | undefined);
    private _forceDestroy?;
    get forceDestroy(): boolean | undefined;
    set forceDestroy(value: boolean | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _location?;
    get location(): string | undefined;
    set location(value: string | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    private _requesterPays?;
    get requesterPays(): boolean | undefined;
    set requesterPays(value: boolean | undefined);
    get selfLink(): string;
    private _storageClass?;
    get storageClass(): string | undefined;
    set storageClass(value: string | undefined);
    get url(): string;
    private _cors?;
    get cors(): StorageBucketCors[] | undefined;
    set cors(value: StorageBucketCors[] | undefined);
    private _encryption?;
    get encryption(): StorageBucketEncryption[] | undefined;
    set encryption(value: StorageBucketEncryption[] | undefined);
    private _lifecycleRule?;
    get lifecycleRule(): StorageBucketLifecycleRule[] | undefined;
    set lifecycleRule(value: StorageBucketLifecycleRule[] | undefined);
    private _logging?;
    get logging(): StorageBucketLogging[] | undefined;
    set logging(value: StorageBucketLogging[] | undefined);
    private _retentionPolicy?;
    get retentionPolicy(): StorageBucketRetentionPolicy[] | undefined;
    set retentionPolicy(value: StorageBucketRetentionPolicy[] | undefined);
    private _versioning?;
    get versioning(): StorageBucketVersioning[] | undefined;
    set versioning(value: StorageBucketVersioning[] | undefined);
    private _website?;
    get website(): StorageBucketWebsite[] | undefined;
    set website(value: StorageBucketWebsite[] | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
