import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
export interface StorageNotificationConfig extends TerraformMetaArguments {
    /** The name of the bucket. */
    readonly bucket: string;
    /**  A set of key/value attribute pairs to attach to each Cloud PubSub message published for this notification subscription */
    readonly customAttributes?: {
        [key: string]: string;
    };
    /** List of event type filters for this notification config. If not specified, Cloud Storage will send notifications for all event types. The valid types are: "OBJECT_FINALIZE", "OBJECT_METADATA_UPDATE", "OBJECT_DELETE", "OBJECT_ARCHIVE" */
    readonly eventTypes?: string[];
    /** Specifies a prefix path filter for this notification config. Cloud Storage will only send notifications for objects in this bucket whose names begin with the specified prefix. */
    readonly objectNamePrefix?: string;
    /** The desired content of the Payload. One of "JSON_API_V1" or "NONE". */
    readonly payloadFormat: string;
    /** The Cloud PubSub topic to which this subscription publishes. Expects either the  topic name, assumed to belong to the default GCP provider project, or the project-level name,  i.e. projects/my-gcp-project/topics/my-topic or my-topic. If the project is not set in the provider, you will need to use the project-level name. */
    readonly topic: string;
}
export declare class StorageNotification extends TerraformResource {
    constructor(scope: Construct, id: string, config: StorageNotificationConfig);
    private _bucket;
    get bucket(): string;
    set bucket(value: string);
    private _customAttributes?;
    get customAttributes(): {
        [key: string]: string;
    } | undefined;
    set customAttributes(value: {
        [key: string]: string;
    } | undefined);
    private _eventTypes?;
    get eventTypes(): string[] | undefined;
    set eventTypes(value: string[] | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    get notificationId(): string;
    private _objectNamePrefix?;
    get objectNamePrefix(): string | undefined;
    set objectNamePrefix(value: string | undefined);
    private _payloadFormat;
    get payloadFormat(): string;
    set payloadFormat(value: string);
    get selfLink(): string;
    private _topic;
    get topic(): string;
    set topic(value: string);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
