import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
export interface TpuNodeConfig extends TerraformMetaArguments {
    /** The type of hardware accelerators associated with this node. */
    readonly acceleratorType: string;
    /** The CIDR block that the TPU node will use when selecting an IP
  address. This CIDR block must be a /29 block; the Compute Engine
  networks API forbids a smaller block, and using a larger block would
  be wasteful (a node can only consume one IP address).
  
  Errors will occur if the CIDR block has already been used for a
  currently existing TPU node, the CIDR block conflicts with any
  subnetworks in the user's provided network, or the provided network
  is peered with another network that is using that CIDR block. */
    readonly cidrBlock: string;
    /** The user-supplied description of the TPU. Maximum of 512 characters. */
    readonly description?: string;
    /** Resource labels to represent user provided metadata. */
    readonly labels?: {
        [key: string]: string;
    };
    /** The immutable name of the TPU. */
    readonly name: string;
    /** The name of a network to peer the TPU node to. It must be a
  preexisting Compute Engine network inside of the project on which
  this API has been activated. If none is provided, "default" will be
  used. */
    readonly network?: string;
    readonly project?: string;
    /** The version of Tensorflow running in the Node. */
    readonly tensorflowVersion: string;
    /** The GCP location for the TPU. */
    readonly zone: string;
    /** scheduling_config block */
    readonly schedulingConfig?: TpuNodeSchedulingConfig[];
    /** timeouts block */
    readonly timeouts?: TpuNodeTimeouts;
}
export declare class TpuNodeNetworkEndpoints extends ComplexComputedList {
    get ipAddress(): string;
    get port(): number;
}
export interface TpuNodeSchedulingConfig {
    /** Defines whether the TPU instance is preemptible. */
    readonly preemptible: boolean;
}
export interface TpuNodeTimeouts {
    readonly create?: string;
    readonly delete?: string;
    readonly update?: string;
}
export declare class TpuNode extends TerraformResource {
    constructor(scope: Construct, id: string, config: TpuNodeConfig);
    private _acceleratorType;
    get acceleratorType(): string;
    set acceleratorType(value: string);
    private _cidrBlock;
    get cidrBlock(): string;
    set cidrBlock(value: string);
    private _description?;
    get description(): string | undefined;
    set description(value: string | undefined);
    private _id?;
    get id(): string | undefined;
    set id(value: string | undefined);
    private _labels?;
    get labels(): {
        [key: string]: string;
    } | undefined;
    set labels(value: {
        [key: string]: string;
    } | undefined);
    private _name;
    get name(): string;
    set name(value: string);
    private _network?;
    get network(): string | undefined;
    set network(value: string | undefined);
    networkEndpoints(index: string): TpuNodeNetworkEndpoints;
    private _project?;
    get project(): string | undefined;
    set project(value: string | undefined);
    get serviceAccount(): string;
    private _tensorflowVersion;
    get tensorflowVersion(): string;
    set tensorflowVersion(value: string);
    private _zone;
    get zone(): string;
    set zone(value: string);
    private _schedulingConfig?;
    get schedulingConfig(): TpuNodeSchedulingConfig[] | undefined;
    set schedulingConfig(value: TpuNodeSchedulingConfig[] | undefined);
    private _timeouts?;
    get timeouts(): TpuNodeTimeouts | undefined;
    set timeouts(value: TpuNodeTimeouts | undefined);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
